'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_app(CreateApplicationRequest=None):
    """
    Creates an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_app(
        CreateApplicationRequest={
            'Name': 'string',
            'tags': {
                'string': 'string'
            }
        }
    )
    
    
    :type CreateApplicationRequest: dict
    :param CreateApplicationRequest: [REQUIRED]\nSpecifies the display name of an application and the tags to associate with the application.\n\nName (string) -- [REQUIRED]The display name of the application. This name is displayed as the Project name on the Amazon Pinpoint console.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the application. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'ApplicationResponse': {
        'Arn': 'string',
        'Id': 'string',
        'Name': 'string',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --The request succeeded and the specified resource was created.

ApplicationResponse (dict) --Provides information about an application.

Arn (string) --The Amazon Resource Name (ARN) of the application.

Id (string) --The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

Name (string) --The display name of the application. This name is displayed as the Project name on the Amazon Pinpoint console.

tags (dict) --A string-to-string map of key-value pairs that identifies the tags that are associated with the application. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --











Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationResponse': {
            'Arn': 'string',
            'Id': 'string',
            'Name': 'string',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def create_campaign(ApplicationId=None, WriteCampaignRequest=None):
    """
    Creates a new campaign for an application or updates the settings of an existing campaign for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_campaign(
        ApplicationId='string',
        WriteCampaignRequest={
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'IsPaused': True|False,
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type WriteCampaignRequest: dict
    :param WriteCampaignRequest: [REQUIRED]\nSpecifies the configuration and other settings for a campaign.\n\nAdditionalTreatments (list) --An array of requests that defines additional treatments for the campaign, in addition to the default treatment for the campaign.\n\n(dict) --Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.\n\nCustomDeliveryConfiguration (dict) --The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.\n\nDeliveryUri (string) -- [REQUIRED]The destination to send the campaign or treatment to. This value can be one of the following:\n\nThe name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.\nThe URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.\n\n\nEndpointTypes (list) --The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.\n\n(string) --\n\n\n\n\nMessageConfiguration (dict) --The message configuration settings for the treatment.\n\nADMMessage (dict) --The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nAPNSMessage (dict) --The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nBaiduMessage (dict) --The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nCustomMessage (dict) --The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.\n\nData (string) --The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.\n\n\n\nDefaultMessage (dict) --The default message that the campaign sends through all the channels that are configured for the campaign.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nEmailMessage (dict) --The message that the campaign sends through the email channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the email for recipients whose email clients don\'t render HTML content.\n\nFromAddress (string) --The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.\n\nHtmlBody (string) --The body of the email, in HTML format, for recipients whose email clients render HTML content.\n\nTitle (string) --The subject line, or title, of the email.\n\n\n\nGCMMessage (dict) --The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nSMSMessage (dict) --The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the SMS message.\n\nMessageType (string) --The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.\n\nSenderId (string) --The sender ID to display on recipients\' devices when they receive the SMS message.\n\n\n\n\n\nSchedule (dict) --The schedule settings for the treatment.\n\nEndTime (string) --The scheduled time, in ISO 8601 format, when the campaign ended or will end.\n\nEventFilter (dict) --The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.\n\nDimensions (dict) -- [REQUIRED]The dimension settings of the event filter for the campaign.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nFilterType (string) -- [REQUIRED]The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.\n\n\n\nFrequency (string) --Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.\n\nIsLocalTime (boolean) --Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.\n\nQuietTime (dict) --The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint is set to a valid value.\nThe current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.\nThe current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.\n\nIf any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\nStartTime (string) -- [REQUIRED]The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.\n\nTimezone (string) --The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.\n\n\n\nSizePercent (integer) -- [REQUIRED]The allocated percentage of users (segment members) to send the treatment to.\n\nTemplateConfiguration (dict) --The message template to use for the treatment.\n\nEmailTemplate (dict) --The email template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nPushTemplate (dict) --The push notification template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nSMSTemplate (dict) --The SMS template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nVoiceTemplate (dict) --The voice template to use for the message. This object isn\'t supported for campaigns.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\n\n\nTreatmentDescription (string) --A custom description of the treatment.\n\nTreatmentName (string) --A custom name for the treatment.\n\n\n\n\n\nCustomDeliveryConfiguration (dict) --The delivery configuration settings for sending the campaign through a custom channel. This object is required if the MessageConfiguration object for the campaign specifies a CustomMessage object.\n\nDeliveryUri (string) -- [REQUIRED]The destination to send the campaign or treatment to. This value can be one of the following:\n\nThe name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.\nThe URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.\n\n\nEndpointTypes (list) --The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.\n\n(string) --\n\n\n\n\nDescription (string) --A custom description of the campaign.\n\nHoldoutPercent (integer) --The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.\n\nHook (dict) --The settings for the AWS Lambda function to invoke as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.\n\nLambdaFunctionName (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.\n\nMode (string) --The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:\n\nFILTER - Invoke the function to customize the segment that\'s used by a campaign.\nDELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.\n\n\nWebUrl (string) --The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.\n\n\n\nIsPaused (boolean) --Specifies whether to pause the campaign. A paused campaign doesn\'t run unless you resume it by changing this value to false.\n\nLimits (dict) --The messaging limits for the campaign.\n\nDaily (integer) --The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.\n\nMaximumDuration (integer) --The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.\n\nMessagesPerSecond (integer) --The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.\n\nTotal (integer) --The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.\n\n\n\nMessageConfiguration (dict) --The message configuration settings for the campaign.\n\nADMMessage (dict) --The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nAPNSMessage (dict) --The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nBaiduMessage (dict) --The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nCustomMessage (dict) --The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.\n\nData (string) --The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.\n\n\n\nDefaultMessage (dict) --The default message that the campaign sends through all the channels that are configured for the campaign.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nEmailMessage (dict) --The message that the campaign sends through the email channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the email for recipients whose email clients don\'t render HTML content.\n\nFromAddress (string) --The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.\n\nHtmlBody (string) --The body of the email, in HTML format, for recipients whose email clients render HTML content.\n\nTitle (string) --The subject line, or title, of the email.\n\n\n\nGCMMessage (dict) --The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nSMSMessage (dict) --The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the SMS message.\n\nMessageType (string) --The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.\n\nSenderId (string) --The sender ID to display on recipients\' devices when they receive the SMS message.\n\n\n\n\n\nName (string) --A custom name for the campaign.\n\nSchedule (dict) --The schedule settings for the campaign.\n\nEndTime (string) --The scheduled time, in ISO 8601 format, when the campaign ended or will end.\n\nEventFilter (dict) --The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.\n\nDimensions (dict) -- [REQUIRED]The dimension settings of the event filter for the campaign.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nFilterType (string) -- [REQUIRED]The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.\n\n\n\nFrequency (string) --Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.\n\nIsLocalTime (boolean) --Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.\n\nQuietTime (dict) --The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint is set to a valid value.\nThe current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.\nThe current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.\n\nIf any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\nStartTime (string) -- [REQUIRED]The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.\n\nTimezone (string) --The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.\n\n\n\nSegmentId (string) --The unique identifier for the segment to associate with the campaign.\n\nSegmentVersion (integer) --The version of the segment to associate with the campaign.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the campaign. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateConfiguration (dict) --The message template to use for the campaign.\n\nEmailTemplate (dict) --The email template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nPushTemplate (dict) --The push notification template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nSMSTemplate (dict) --The SMS template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nVoiceTemplate (dict) --The voice template to use for the message. This object isn\'t supported for campaigns.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\n\n\nTreatmentDescription (string) --A custom description of the default treatment for the campaign.\n\nTreatmentName (string) --A custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignResponse': {
        'AdditionalTreatments': [
            {
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'Id': 'string',
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SizePercent': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string'
            },
        ],
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'CustomDeliveryConfiguration': {
            'DeliveryUri': 'string',
            'EndpointTypes': [
                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            ]
        },
        'DefaultState': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'Description': 'string',
        'HoldoutPercent': 123,
        'Hook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'Id': 'string',
        'IsPaused': True|False,
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'MessageConfiguration': {
            'ADMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'APNSMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'BaiduMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'CustomMessage': {
                'Data': 'string'
            },
            'DefaultMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'EmailMessage': {
                'Body': 'string',
                'FromAddress': 'string',
                'HtmlBody': 'string',
                'Title': 'string'
            },
            'GCMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'SMSMessage': {
                'Body': 'string',
                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                'SenderId': 'string'
            }
        },
        'Name': 'string',
        'Schedule': {
            'EndTime': 'string',
            'EventFilter': {
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'EventType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    }
                },
                'FilterType': 'SYSTEM'|'ENDPOINT'
            },
            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
            'IsLocalTime': True|False,
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'StartTime': 'string',
            'Timezone': 'string'
        },
        'SegmentId': 'string',
        'SegmentVersion': 123,
        'State': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'tags': {
            'string': 'string'
        },
        'TemplateConfiguration': {
            'EmailTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'PushTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'SMSTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'VoiceTemplate': {
                'Name': 'string',
                'Version': 'string'
            }
        },
        'TreatmentDescription': 'string',
        'TreatmentName': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

CampaignResponse (dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignResponse': {
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'Id': 'string',
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'DefaultState': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'Id': 'string',
            'IsPaused': True|False,
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'State': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def create_email_template(EmailTemplateRequest=None, TemplateName=None):
    """
    Creates a message template for messages that are sent through the email channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_email_template(
        EmailTemplateRequest={
            'DefaultSubstitutions': 'string',
            'HtmlPart': 'string',
            'RecommenderId': 'string',
            'Subject': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'TextPart': 'string'
        },
        TemplateName='string'
    )
    
    
    :type EmailTemplateRequest: dict
    :param EmailTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in messages that are sent through the email channel.\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nHtmlPart (string) --The message body, in HTML format, to use in email messages that are based on the message template. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.\n\nRecommenderId (string) --The unique identifier for the recommender model to use for the message template. Amazon Pinpoint uses this value to determine how to retrieve and process data from a recommender model when it sends messages that use the template, if the template contains message variables for recommendation data.\n\nSubject (string) --The subject line, or title, to use in email messages that are based on the message template.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\nTextPart (string) --The message body, in plain text format, to use in email messages that are based on the message template. We recommend using plain text format for email clients that don\'t render HTML content and clients that are connected to high-latency networks, such as mobile devices.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CreateTemplateMessageBody': {
        'Arn': 'string',
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

CreateTemplateMessageBody (dict) --
Provides information about a request to create a message template.

Arn (string) --
The Amazon Resource Name (ARN) of the message template that was created.

Message (string) --
The message that\'s returned from the API for the request to create the message template.

RequestID (string) --
The unique identifier for the request to create the message template.









Exceptions

Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException
Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.ForbiddenException


    :return: {
        'CreateTemplateMessageBody': {
            'Arn': 'string',
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.ForbiddenException
    
    """
    pass

def create_export_job(ApplicationId=None, ExportJobRequest=None):
    """
    Creates an export job for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_export_job(
        ApplicationId='string',
        ExportJobRequest={
            'RoleArn': 'string',
            'S3UrlPrefix': 'string',
            'SegmentId': 'string',
            'SegmentVersion': 123
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type ExportJobRequest: dict
    :param ExportJobRequest: [REQUIRED]\nSpecifies the settings for a job that exports endpoint definitions to an Amazon Simple Storage Service (Amazon S3) bucket.\n\nRoleArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location where you want to export endpoint definitions to.\n\nS3UrlPrefix (string) -- [REQUIRED]The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket where you want to export endpoint definitions to. This location is typically a folder that contains multiple files. The URL should be in the following format: s3://bucket-name/folder-name/.\n\nSegmentId (string) --The identifier for the segment to export endpoint definitions from. If you don\'t specify this value, Amazon Pinpoint exports definitions for all the endpoints that are associated with the application.\n\nSegmentVersion (integer) --The version of the segment to export endpoint definitions from, if specified.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ExportJobResponse': {
        'ApplicationId': 'string',
        'CompletedPieces': 123,
        'CompletionDate': 'string',
        'CreationDate': 'string',
        'Definition': {
            'RoleArn': 'string',
            'S3UrlPrefix': 'string',
            'SegmentId': 'string',
            'SegmentVersion': 123
        },
        'FailedPieces': 123,
        'Failures': [
            'string',
        ],
        'Id': 'string',
        'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
        'TotalFailures': 123,
        'TotalPieces': 123,
        'TotalProcessed': 123,
        'Type': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

ExportJobResponse (dict) --
Provides information about the status and settings of a job that exports endpoint definitions to a file. The file can be added directly to an Amazon Simple Storage Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly to a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the export job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the export job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the export job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the export job was created.

Definition (dict) --
The resource settings that apply to the export job.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location where the endpoint definitions were exported to.

S3UrlPrefix (string) --
The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket where the endpoint definitions were exported to. This location is typically a folder that contains multiple files. The URL should be in the following format: s3://bucket-name/folder-name/.

SegmentId (string) --
The identifier for the segment that the endpoint definitions were exported from. If this value isn\'t present, Amazon Pinpoint exported definitions for all the endpoints that are associated with the application.

SegmentVersion (integer) --
The version of the segment that the endpoint definitions were exported from.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the export job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the export job, if any.

(string) --


Id (string) --
The unique identifier for the export job.

JobStatus (string) --
The status of the export job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the export job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the export job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the export job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the export job.

Type (string) --
The job type. This value is EXPORT for export jobs.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ExportJobResponse': {
            'ApplicationId': 'string',
            'CompletedPieces': 123,
            'CompletionDate': 'string',
            'CreationDate': 'string',
            'Definition': {
                'RoleArn': 'string',
                'S3UrlPrefix': 'string',
                'SegmentId': 'string',
                'SegmentVersion': 123
            },
            'FailedPieces': 123,
            'Failures': [
                'string',
            ],
            'Id': 'string',
            'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
            'TotalFailures': 123,
            'TotalPieces': 123,
            'TotalProcessed': 123,
            'Type': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def create_import_job(ApplicationId=None, ImportJobRequest=None):
    """
    Creates an import job for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_import_job(
        ApplicationId='string',
        ImportJobRequest={
            'DefineSegment': True|False,
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RegisterEndpoints': True|False,
            'RoleArn': 'string',
            'S3Url': 'string',
            'SegmentId': 'string',
            'SegmentName': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type ImportJobRequest: dict
    :param ImportJobRequest: [REQUIRED]\nSpecifies the settings for a job that imports endpoint definitions from an Amazon Simple Storage Service (Amazon S3) bucket.\n\nDefineSegment (boolean) --Specifies whether to create a segment that contains the endpoints, when the endpoint definitions are imported.\n\nExternalId (string) --(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.\n\nFormat (string) -- [REQUIRED]The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format. If the Amazon S3 location stores multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.\n\nRegisterEndpoints (boolean) --Specifies whether to register the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.\n\nRoleArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.\n\nS3Url (string) -- [REQUIRED]The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.\nThe URL should be in the following format: s3://bucket-name/folder-name/file-name. The location can end with the key for an individual object or a prefix that qualifies multiple objects.\n\nSegmentId (string) --The identifier for the segment to update or add the imported endpoint definitions to, if the import job is meant to update an existing segment.\n\nSegmentName (string) --A custom name for the segment that\'s created by the import job, if the value of the DefineSegment property is true.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ImportJobResponse': {
        'ApplicationId': 'string',
        'CompletedPieces': 123,
        'CompletionDate': 'string',
        'CreationDate': 'string',
        'Definition': {
            'DefineSegment': True|False,
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RegisterEndpoints': True|False,
            'RoleArn': 'string',
            'S3Url': 'string',
            'SegmentId': 'string',
            'SegmentName': 'string'
        },
        'FailedPieces': 123,
        'Failures': [
            'string',
        ],
        'Id': 'string',
        'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
        'TotalFailures': 123,
        'TotalPieces': 123,
        'TotalProcessed': 123,
        'Type': 'string'
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

ImportJobResponse (dict) --
Provides information about the status and settings of a job that imports endpoint definitions from one or more files. The files can be stored in an Amazon Simple Storage Service (Amazon S3) bucket or uploaded directly from a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the import job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the import job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the import job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the import job was created.

Definition (dict) --
The resource settings that apply to the import job.

DefineSegment (boolean) --
Specifies whether the import job creates a segment that contains the endpoints, when the endpoint definitions are imported.

ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.
If the files are stored in an Amazon S3 location and that location contains multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.

RegisterEndpoints (boolean) --
Specifies whether the import job registers the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.
The URL should be in the following format: s3://bucket-name/folder-name/file-name. The location can end with the key for an individual object or a prefix that qualifies multiple objects.

SegmentId (string) --
The identifier for the segment that the import job updates or adds endpoint definitions to, if the import job updates an existing segment.

SegmentName (string) --
The custom name for the segment that\'s created by the import job, if the value of the DefineSegment property is true.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the import job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the import job, if any.

(string) --


Id (string) --
The unique identifier for the import job.

JobStatus (string) --
The status of the import job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the import job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the import job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the import job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the import job.

Type (string) --
The job type. This value is IMPORT for import jobs.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ImportJobResponse': {
            'ApplicationId': 'string',
            'CompletedPieces': 123,
            'CompletionDate': 'string',
            'CreationDate': 'string',
            'Definition': {
                'DefineSegment': True|False,
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RegisterEndpoints': True|False,
                'RoleArn': 'string',
                'S3Url': 'string',
                'SegmentId': 'string',
                'SegmentName': 'string'
            },
            'FailedPieces': 123,
            'Failures': [
                'string',
            ],
            'Id': 'string',
            'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
            'TotalFailures': 123,
            'TotalPieces': 123,
            'TotalProcessed': 123,
            'Type': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def create_journey(ApplicationId=None, WriteJourneyRequest=None):
    """
    Creates a journey for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_journey(
        ApplicationId='string',
        WriteJourneyRequest={
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'CreationDate': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type WriteJourneyRequest: dict
    :param WriteJourneyRequest: [REQUIRED]\nSpecifies the configuration and other settings for a journey.\n\nActivities (dict) --A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity. An activity identifier can contain a maximum of 100 characters. The characters must be alphanumeric characters.\n\n(string) --\n(dict) --Specifies the configuration and other settings for an activity in a journey.\n\nConditionalSplit (dict) --The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.\n\nCondition (dict) --The conditions that define the paths for the activity, and the relationship between the conditions.\n\nConditions (list) --The conditions to evaluate for the activity.\n\n(dict) --Specifies a condition to evaluate for an activity in a journey.\n\nEventCondition (dict) --The dimension settings for the event that\'s associated with the activity.\n\nDimensions (dict) --The dimensions for the event filter to use for the activity.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nMessageActivity (string) --The message identifier (message_id) for the message to use when determining whether message events meet the condition.\n\n\n\nSegmentCondition (dict) --The segment that\'s associated with the activity.\n\nSegmentId (string) -- [REQUIRED]The unique identifier for the segment to associate with the activity.\n\n\n\nSegmentDimensions (dict) --The dimension settings for the segment that\'s associated with the activity.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nOperator (string) --Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.\n\n\n\nEvaluationWaitTime (dict) --The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.\n\nWaitFor (string) --The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.\n\nWaitUntil (string) --The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.\n\n\n\nFalseActivity (string) --The unique identifier for the activity to perform if the conditions aren\'t met.\n\nTrueActivity (string) --The unique identifier for the activity to perform if the conditions are met.\n\n\n\nDescription (string) --The custom description of the activity.\n\nEMAIL (dict) --The settings for an email activity. This type of activity sends an email message to participants.\n\nMessageConfig (dict) --The 'From' address to use for the message.\n\nFromAddress (string) --The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.\n\n\n\nNextActivity (string) --The unique identifier for the next activity to perform, after the message is sent.\n\nTemplateName (string) --The name of the email template to use for the message.\n\nTemplateVersion (string) --The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nHoldout (dict) --The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.\n\nNextActivity (string) --The unique identifier for the next activity to perform, after performing the holdout activity.\n\nPercentage (integer) -- [REQUIRED]The percentage of participants who shouldn\'t continue the journey.\nTo determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.\n\n\n\nMultiCondition (dict) --The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.\n\nBranches (list) --The paths for the activity, including the conditions for entering each path and the activity to perform for each path.\n\n(dict) --Specifies a condition to evaluate for an activity path in a journey.\n\nCondition (dict) --The condition to evaluate for the activity path.\n\nEventCondition (dict) --The dimension settings for the event that\'s associated with the activity.\n\nDimensions (dict) --The dimensions for the event filter to use for the activity.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nMessageActivity (string) --The message identifier (message_id) for the message to use when determining whether message events meet the condition.\n\n\n\nSegmentCondition (dict) --The segment that\'s associated with the activity.\n\nSegmentId (string) -- [REQUIRED]The unique identifier for the segment to associate with the activity.\n\n\n\nSegmentDimensions (dict) --The dimension settings for the segment that\'s associated with the activity.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n\nNextActivity (string) --The unique identifier for the next activity to perform, after completing the activity for the path.\n\n\n\n\n\nDefaultActivity (string) --The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.\n\nEvaluationWaitTime (dict) --The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.\n\nWaitFor (string) --The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.\n\nWaitUntil (string) --The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.\n\n\n\n\n\nRandomSplit (dict) --The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.\n\nBranches (list) --The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.\n\n(dict) --Specifies the settings for a path in a random split activity in a journey.\n\nNextActivity (string) --The unique identifier for the next activity to perform, after completing the activity for the path.\n\nPercentage (integer) --The percentage of participants to send down the activity path.\nTo determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.\n\n\n\n\n\n\n\nWait (dict) --The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.\n\nNextActivity (string) --The unique identifier for the next activity to perform, after performing the wait activity.\n\nWaitTime (dict) --The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.\n\nWaitFor (string) --The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.\n\nWaitUntil (string) --The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.\n\n\n\n\n\n\n\n\n\n\n\nCreationDate (string) --The date, in ISO 8601 format, when the journey was created.\n\nLastModifiedDate (string) --The date, in ISO 8601 format, when the journey was last modified.\n\nLimits (dict) --The messaging and entry limits for the journey.\n\nDailyCap (integer) --The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.\n\nEndpointReentryCap (integer) --The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.\n\nMessagesPerSecond (integer) --The maximum number of messages that the journey can send each second.\n\n\n\nLocalTime (boolean) --Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. To base the schedule on each participant\'s local time, set this value to true.\n\nName (string) -- [REQUIRED]The name of the journey. A journey name can contain a maximum of 150 characters. The characters can be alphanumeric characters or symbols, such as underscores (_) or hyphens (-). A journey name can\'t contain any spaces.\n\nQuietTime (dict) --The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.\nThe current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.\nThe current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.\n\nIf any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\nRefreshFrequency (string) --The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.\n\nSchedule (dict) --The schedule settings for the journey.\n\nEndTime (datetime) --The scheduled time, in ISO 8601 format, when the journey ended or will end.\n\nStartTime (datetime) --The scheduled time, in ISO 8601 format, when the journey began or will begin.\n\nTimezone (string) --The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.\n\n\n\nStartActivity (string) --The unique identifier for the first activity in the journey. The identifier for this activity can contain a maximum of 128 characters. The characters must be alphanumeric characters.\n\nStartCondition (dict) --The segment that defines which users are participants in the journey.\n\nDescription (string) --The custom description of the condition.\n\nSegmentStartCondition (dict) --The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.\n\nSegmentId (string) -- [REQUIRED]The unique identifier for the segment to associate with the activity.\n\n\n\n\n\nState (string) --The status of the journey. Valid values are:\n\nDRAFT - Saves the journey and doesn\'t publish it.\nACTIVE - Saves and publishes the journey. Depending on the journey\'s schedule, the journey starts running immediately or at the scheduled start time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.\n\nThe CANCELLED, COMPLETED, and CLOSED values are not supported in requests to create or update a journey. To cancel a journey, use the Journey Stateresource.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyResponse': {
        'Activities': {
            'string': {
                'ConditionalSplit': {
                    'Condition': {
                        'Conditions': [
                            {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                        ],
                        'Operator': 'ALL'|'ANY'
                    },
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    },
                    'FalseActivity': 'string',
                    'TrueActivity': 'string'
                },
                'Description': 'string',
                'EMAIL': {
                    'MessageConfig': {
                        'FromAddress': 'string'
                    },
                    'NextActivity': 'string',
                    'TemplateName': 'string',
                    'TemplateVersion': 'string'
                },
                'Holdout': {
                    'NextActivity': 'string',
                    'Percentage': 123
                },
                'MultiCondition': {
                    'Branches': [
                        {
                            'Condition': {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                            'NextActivity': 'string'
                        },
                    ],
                    'DefaultActivity': 'string',
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                },
                'RandomSplit': {
                    'Branches': [
                        {
                            'NextActivity': 'string',
                            'Percentage': 123
                        },
                    ]
                },
                'Wait': {
                    'NextActivity': 'string',
                    'WaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                }
            }
        },
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Limits': {
            'DailyCap': 123,
            'EndpointReentryCap': 123,
            'MessagesPerSecond': 123
        },
        'LocalTime': True|False,
        'Name': 'string',
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        },
        'RefreshFrequency': 'string',
        'Schedule': {
            'EndTime': datetime(2015, 1, 1),
            'StartTime': datetime(2015, 1, 1),
            'Timezone': 'string'
        },
        'StartActivity': 'string',
        'StartCondition': {
            'Description': 'string',
            'SegmentStartCondition': {
                'SegmentId': 'string'
            }
        },
        'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

JourneyResponse (dict) --
Provides information about the status, configuration, and other settings for a journey.

Activities (dict) --
A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity.

(string) --

(dict) --
Specifies the configuration and other settings for an activity in a journey.

ConditionalSplit (dict) --
The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.

Condition (dict) --
The conditions that define the paths for the activity, and the relationship between the conditions.

Conditions (list) --
The conditions to evaluate for the activity.

(dict) --
Specifies a condition to evaluate for an activity in a journey.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --














Operator (string) --
Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.



EvaluationWaitTime (dict) --
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.



FalseActivity (string) --
The unique identifier for the activity to perform if the conditions aren\'t met.

TrueActivity (string) --
The unique identifier for the activity to perform if the conditions are met.



Description (string) --
The custom description of the activity.

EMAIL (dict) --
The settings for an email activity. This type of activity sends an email message to participants.

MessageConfig (dict) --
The "From" address to use for the message.

FromAddress (string) --
The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.



NextActivity (string) --
The unique identifier for the next activity to perform, after the message is sent.

TemplateName (string) --
The name of the email template to use for the message.

TemplateVersion (string) --
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



Holdout (dict) --
The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the holdout activity.

Percentage (integer) --
The percentage of participants who shouldn\'t continue the journey.
To determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.



MultiCondition (dict) --
The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.

(dict) --
Specifies a condition to evaluate for an activity path in a journey.

Condition (dict) --
The condition to evaluate for the activity path.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.





DefaultActivity (string) --
The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.

EvaluationWaitTime (dict) --
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.





RandomSplit (dict) --
The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.

(dict) --
Specifies the settings for a path in a random split activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.

Percentage (integer) --
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.







Wait (dict) --
The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the wait activity.

WaitTime (dict) --
The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.











ApplicationId (string) --
The unique identifier for the application that the journey applies to.

CreationDate (string) --
The date, in ISO 8601 format, when the journey was created.

Id (string) --
The unique identifier for the journey.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the journey was last modified.

Limits (dict) --
The messaging and entry limits for the journey.

DailyCap (integer) --
The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.

EndpointReentryCap (integer) --
The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.

MessagesPerSecond (integer) --
The maximum number of messages that the journey can send each second.



LocalTime (boolean) --
Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. If this value is true, the schedule uses each participant\'s local time.

Name (string) --
The name of the journey.

QuietTime (dict) --
The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.
The current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.
The current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.

If any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



RefreshFrequency (string) --
The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.

Schedule (dict) --
The schedule settings for the journey.

EndTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey ended or will end.

StartTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey began or will begin.

Timezone (string) --
The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.



StartActivity (string) --
The unique identifier for the first activity in the journey.

StartCondition (dict) --
The segment that defines which users are participants in the journey.

Description (string) --
The custom description of the condition.

SegmentStartCondition (dict) --
The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.





State (string) --
The current status of the journey. Possible values are:

DRAFT - The journey is being developed and hasn\'t been published yet.
ACTIVE - The journey has been developed and published. Depending on the journey\'s schedule, the journey may currently be running or scheduled to start running at a later time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.
COMPLETED - The journey has been published and has finished running. All participants have entered the journey and no participants are waiting to complete the journey or any activities in the journey.
CANCELLED - The journey has been stopped. If a journey\'s status is CANCELLED, you can\'t add, change, or remove activities or segment settings from the journey.
CLOSED - The journey has been published and has started running. It may have also passed its scheduled end time, or passed its scheduled start time and a refresh frequency hasn\'t been specified for it. If a journey\'s status is CLOSED, you can\'t add participants to it, and no existing participants can enter the journey for the first time. However, any existing participants who are currently waiting to start an activity may continue the journey.


tags (dict) --
This object is not used or supported.

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyResponse': {
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def create_push_template(PushNotificationTemplateRequest=None, TemplateName=None):
    """
    Creates a message template for messages that are sent through a push notification channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_push_template(
        PushNotificationTemplateRequest={
            'ADM': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'APNS': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'Baidu': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'Default': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'DefaultSubstitutions': 'string',
            'GCM': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'RecommenderId': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string'
        },
        TemplateName='string'
    )
    
    
    :type PushNotificationTemplateRequest: dict
    :param PushNotificationTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in messages that are sent through a push notification channel.\n\nADM (dict) --The message template to use for the ADM (Amazon Device Messaging) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in a push notification that\'s based on the message template.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.\n\nImageUrl (string) --The URL of an image to display in a push notification that\'s based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nTitle (string) --The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nAPNS (dict) --The message template to use for the APNs (Apple Push Notification service) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in push notifications that are based on the message template.\n\nMediaUrl (string) --The URL of an image or video to display in push notifications that are based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for push notifications that are based on the message template. If specified, this value overrides all other content for the message template.\n\nSound (string) --The key for the sound to play when the recipient receives a push notification that\'s based on the message template. The value for this key is the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.\n\nTitle (string) --The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nBaidu (dict) --The message template to use for the Baidu (Baidu Cloud Push) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in a push notification that\'s based on the message template.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.\n\nImageUrl (string) --The URL of an image to display in a push notification that\'s based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nTitle (string) --The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nDefault (dict) --The default message template to use for push notification channels.\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in push notifications that are based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\nFor an iOS platform, this value is the key for the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.\n\nTitle (string) --The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nGCM (dict) --The message template to use for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in a push notification that\'s based on the message template.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.\n\nImageUrl (string) --The URL of an image to display in a push notification that\'s based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nTitle (string) --The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nRecommenderId (string) --The unique identifier for the recommender model to use for the message template. Amazon Pinpoint uses this value to determine how to retrieve and process data from a recommender model when it sends messages that use the template, if the template contains message variables for recommendation data.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CreateTemplateMessageBody': {
        'Arn': 'string',
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

CreateTemplateMessageBody (dict) --
Provides information about a request to create a message template.

Arn (string) --
The Amazon Resource Name (ARN) of the message template that was created.

Message (string) --
The message that\'s returned from the API for the request to create the message template.

RequestID (string) --
The unique identifier for the request to create the message template.









Exceptions

Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException
Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.ForbiddenException


    :return: {
        'CreateTemplateMessageBody': {
            'Arn': 'string',
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.ForbiddenException
    
    """
    pass

def create_recommender_configuration(CreateRecommenderConfiguration=None):
    """
    Creates an Amazon Pinpoint configuration for a recommender model.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_recommender_configuration(
        CreateRecommenderConfiguration={
            'Attributes': {
                'string': 'string'
            },
            'Description': 'string',
            'Name': 'string',
            'RecommendationProviderIdType': 'string',
            'RecommendationProviderRoleArn': 'string',
            'RecommendationProviderUri': 'string',
            'RecommendationTransformerUri': 'string',
            'RecommendationsDisplayName': 'string',
            'RecommendationsPerMessage': 123
        }
    )
    
    
    :type CreateRecommenderConfiguration: dict
    :param CreateRecommenderConfiguration: [REQUIRED]\nSpecifies Amazon Pinpoint configuration settings for retrieving and processing recommendation data from a recommender model.\n\nAttributes (dict) --A map of key-value pairs that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.\nIn the map, the key is the name of a custom attribute and the value is a custom display name for that attribute. The display name appears in the Attribute finder of the template editor on the Amazon Pinpoint console. The following restrictions apply to these names:\n\nAn attribute name must start with a letter or number and it can contain up to 50 characters. The characters can be letters, numbers, underscores (_), or hyphens (-). Attribute names are case sensitive and must be unique.\nAn attribute display name must start with a letter or number and it can contain up to 25 characters. The characters can be letters, numbers, spaces, underscores (_), or hyphens (-).\n\nThis object is required if the configuration invokes an AWS Lambda function (RecommendationTransformerUri) to process recommendation data. Otherwise, don\'t include this object in your request.\n\n(string) --\n(string) --\n\n\n\n\nDescription (string) --A custom description of the configuration for the recommender model. The description can contain up to 128 characters. The characters can be letters, numbers, spaces, or the following symbols: _ ; () , \xe2\x80\x90.\n\nName (string) --A custom name of the configuration for the recommender model. The name must start with a letter or number and it can contain up to 128 characters. The characters can be letters, numbers, spaces, underscores (_), or hyphens (-).\n\nRecommendationProviderIdType (string) --The type of Amazon Pinpoint ID to associate with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Valid values are:\n\nPINPOINT_ENDPOINT_ID - Associate each user in the model with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.\nPINPOINT_USER_ID - Associate each user in the model with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If you specify this value, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.\n\n\nRecommendationProviderRoleArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.\n\nRecommendationProviderUri (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the recommender model to retrieve recommendation data from. This value must match the ARN of an Amazon Personalize campaign.\n\nRecommendationTransformerUri (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function to invoke for additional processing of recommendation data that\'s retrieved from the recommender model.\n\nRecommendationsDisplayName (string) --A custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This value is required if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.\nThis name appears in the Attribute finder of the template editor on the Amazon Pinpoint console. The name can contain up to 25 characters. The characters can be letters, numbers, spaces, underscores (_), or hyphens (-). These restrictions don\'t apply to attribute values.\n\nRecommendationsPerMessage (integer) --The number of recommended items to retrieve from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables. The minimum value is 1. The maximum value is 5. The default value is 5.\nTo use multiple recommended items and custom attributes with message variables, you have to use an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.\n\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'RecommenderConfigurationResponse': {
        'Attributes': {
            'string': 'string'
        },
        'CreationDate': 'string',
        'Description': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Name': 'string',
        'RecommendationProviderIdType': 'string',
        'RecommendationProviderRoleArn': 'string',
        'RecommendationProviderUri': 'string',
        'RecommendationTransformerUri': 'string',
        'RecommendationsDisplayName': 'string',
        'RecommendationsPerMessage': 123
    }
}


Response Structure

(dict) --The request succeeded and the specified resource was created.

RecommenderConfigurationResponse (dict) --Provides information about Amazon Pinpoint configuration settings for retrieving and processing data from a recommender model.

Attributes (dict) --A map that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

(string) --
(string) --




CreationDate (string) --The date, in extended ISO 8601 format, when the configuration was created for the recommender model.

Description (string) --The custom description of the configuration for the recommender model.

Id (string) --The unique identifier for the recommender model configuration.

LastModifiedDate (string) --The date, in extended ISO 8601 format, when the configuration for the recommender model was last modified.

Name (string) --The custom name of the configuration for the recommender model.

RecommendationProviderIdType (string) --The type of Amazon Pinpoint ID that\'s associated with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Possible values are:

PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.


RecommendationProviderRoleArn (string) --The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.

RecommendationProviderUri (string) --The Amazon Resource Name (ARN) of the recommender model that Amazon Pinpoint retrieves the recommendation data from. This value is the ARN of an Amazon Personalize campaign.

RecommendationTransformerUri (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to perform additional processing of recommendation data that it retrieves from the recommender model.

RecommendationsDisplayName (string) --The custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This name appears in the Attribute finder of the template editor on the Amazon Pinpoint console.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

RecommendationsPerMessage (integer) --The number of recommended items that are retrieved from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'RecommenderConfigurationResponse': {
            'Attributes': {
                'string': 'string'
            },
            'CreationDate': 'string',
            'Description': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Name': 'string',
            'RecommendationProviderIdType': 'string',
            'RecommendationProviderRoleArn': 'string',
            'RecommendationProviderUri': 'string',
            'RecommendationTransformerUri': 'string',
            'RecommendationsDisplayName': 'string',
            'RecommendationsPerMessage': 123
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def create_segment(ApplicationId=None, WriteSegmentRequest=None):
    """
    Creates a new segment for an application or updates the configuration, dimension, and other settings for an existing segment that\'s associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_segment(
        ApplicationId='string',
        WriteSegmentRequest={
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'tags': {
                'string': 'string'
            }
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type WriteSegmentRequest: dict
    :param WriteSegmentRequest: [REQUIRED]\nSpecifies the configuration, dimension, and other settings for a segment. A WriteSegmentRequest object can include a Dimensions object or a SegmentGroups object, but not both.\n\nDimensions (dict) --The criteria that define the dimensions for the segment.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\nName (string) --The name of the segment.\n\nSegmentGroups (dict) --The segment group to use and the dimensions to apply to the group\'s base segments in order to build the segment. A segment group can consist of zero or more base segments. Your request can include only one segment group.\n\nGroups (list) --An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.\n\n(dict) --Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.\n\nDimensions (list) --An array that defines the dimensions for the segment.\n\n(dict) --Specifies the dimension settings for a segment.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n\nSourceSegments (list) --The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.\nYou can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.\n\n(dict) --Specifies the segment identifier and version of a segment.\n\nId (string) -- [REQUIRED]The unique identifier for the segment.\n\nVersion (integer) --The version number of the segment.\n\n\n\n\n\nSourceType (string) --Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.\n\nType (string) --Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.\n\n\n\n\n\nInclude (string) --Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.\n\n\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the segment. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentResponse': {
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'Dimensions': {
            'Attributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Behavior': {
                'Recency': {
                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                    'RecencyType': 'ACTIVE'|'INACTIVE'
                }
            },
            'Demographic': {
                'AppVersion': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Channel': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'DeviceType': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Make': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Model': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Platform': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Location': {
                'Country': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'GPSPoint': {
                    'Coordinates': {
                        'Latitude': 123.0,
                        'Longitude': 123.0
                    },
                    'RangeInKilometers': 123.0
                }
            },
            'Metrics': {
                'string': {
                    'ComparisonOperator': 'string',
                    'Value': 123.0
                }
            },
            'UserAttributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            }
        },
        'Id': 'string',
        'ImportDefinition': {
            'ChannelCounts': {
                'string': 123
            },
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RoleArn': 'string',
            'S3Url': 'string',
            'Size': 123
        },
        'LastModifiedDate': 'string',
        'Name': 'string',
        'SegmentGroups': {
            'Groups': [
                {
                    'Dimensions': [
                        {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Behavior': {
                                'Recency': {
                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                }
                            },
                            'Demographic': {
                                'AppVersion': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Channel': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'DeviceType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Make': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Model': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Platform': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Location': {
                                'Country': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'GPSPoint': {
                                    'Coordinates': {
                                        'Latitude': 123.0,
                                        'Longitude': 123.0
                                    },
                                    'RangeInKilometers': 123.0
                                }
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            },
                            'UserAttributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            }
                        },
                    ],
                    'SourceSegments': [
                        {
                            'Id': 'string',
                            'Version': 123
                        },
                    ],
                    'SourceType': 'ALL'|'ANY'|'NONE',
                    'Type': 'ALL'|'ANY'|'NONE'
                },
            ],
            'Include': 'ALL'|'ANY'|'NONE'
        },
        'SegmentType': 'DIMENSIONAL'|'IMPORT',
        'tags': {
            'string': 'string'
        },
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

SegmentResponse (dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentResponse': {
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Id': 'string',
            'ImportDefinition': {
                'ChannelCounts': {
                    'string': 123
                },
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RoleArn': 'string',
                'S3Url': 'string',
                'Size': 123
            },
            'LastModifiedDate': 'string',
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'SegmentType': 'DIMENSIONAL'|'IMPORT',
            'tags': {
                'string': 'string'
            },
            'Version': 123
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def create_sms_template(SMSTemplateRequest=None, TemplateName=None):
    """
    Creates a message template for messages that are sent through the SMS channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_sms_template(
        SMSTemplateRequest={
            'Body': 'string',
            'DefaultSubstitutions': 'string',
            'RecommenderId': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string'
        },
        TemplateName='string'
    )
    
    
    :type SMSTemplateRequest: dict
    :param SMSTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in text messages that are sent through the SMS channel.\n\nBody (string) --The message body to use in text messages that are based on the message template.\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nRecommenderId (string) --The unique identifier for the recommender model to use for the message template. Amazon Pinpoint uses this value to determine how to retrieve and process data from a recommender model when it sends messages that use the template, if the template contains message variables for recommendation data.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CreateTemplateMessageBody': {
        'Arn': 'string',
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

CreateTemplateMessageBody (dict) --
Provides information about a request to create a message template.

Arn (string) --
The Amazon Resource Name (ARN) of the message template that was created.

Message (string) --
The message that\'s returned from the API for the request to create the message template.

RequestID (string) --
The unique identifier for the request to create the message template.









Exceptions

Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException
Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.ForbiddenException


    :return: {
        'CreateTemplateMessageBody': {
            'Arn': 'string',
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.ForbiddenException
    
    """
    pass

def create_voice_template(TemplateName=None, VoiceTemplateRequest=None):
    """
    Creates a message template for messages that are sent through the voice channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_voice_template(
        TemplateName='string',
        VoiceTemplateRequest={
            'Body': 'string',
            'DefaultSubstitutions': 'string',
            'LanguageCode': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'VoiceId': 'string'
        }
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type VoiceTemplateRequest: dict
    :param VoiceTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in messages that are sent through the voice channel.\n\nBody (string) --The text of the script to use in messages that are based on the message template, in plain text format.\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nLanguageCode (string) --The code for the language to use when synthesizing the text of the script in messages that are based on the message template. For a list of supported languages and the code for each one, see the Amazon Polly Developer Guide .\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\nVoiceId (string) --The name of the voice to use when delivering messages that are based on the message template. For a list of supported voices, see the Amazon Polly Developer Guide .\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CreateTemplateMessageBody': {
        'Arn': 'string',
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request succeeded and the specified resource was created.

CreateTemplateMessageBody (dict) --
Provides information about a request to create a message template.

Arn (string) --
The Amazon Resource Name (ARN) of the message template that was created.

Message (string) --
The message that\'s returned from the API for the request to create the message template.

RequestID (string) --
The unique identifier for the request to create the message template.









Exceptions

Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException
Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.ForbiddenException


    :return: {
        'CreateTemplateMessageBody': {
            'Arn': 'string',
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.ForbiddenException
    
    """
    pass

def delete_adm_channel(ApplicationId=None):
    """
    Disables the ADM channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_adm_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'ADMChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

ADMChannelResponse (dict) --Provides information about the status and settings of the ADM (Amazon Device Messaging) channel for an application.

ApplicationId (string) --The unique identifier for the application that the ADM channel applies to.

CreationDate (string) --The date and time when the ADM channel was enabled.

Enabled (boolean) --Specifies whether the ADM channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the ADM channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the ADM channel is archived.

LastModifiedBy (string) --The user who last modified the ADM channel.

LastModifiedDate (string) --The date and time when the ADM channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the ADM channel, this value is ADM.

Version (integer) --The current version of the ADM channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ADMChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_apns_channel(ApplicationId=None):
    """
    Disables the APNs channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_apns_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs channel applies to.

CreationDate (string) --The date and time when the APNs channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with APNs for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs channel is archived.

LastModifiedBy (string) --The user who last modified the APNs channel.

LastModifiedDate (string) --The date and time when the APNs channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs channel, this value is APNS.

Version (integer) --The current version of the APNs channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_apns_sandbox_channel(ApplicationId=None):
    """
    Disables the APNs sandbox channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_apns_sandbox_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSSandboxChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSSandboxChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) sandbox channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs sandbox channel applies to.

CreationDate (string) --The date and time when the APNs sandbox channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with the APNs sandbox environment for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs sandbox channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs sandbox channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs sandbox channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs sandbox channel is archived.

LastModifiedBy (string) --The user who last modified the APNs sandbox channel.

LastModifiedDate (string) --The date and time when the APNs sandbox channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs sandbox channel, this value is APNS_SANDBOX.

Version (integer) --The current version of the APNs sandbox channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSSandboxChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_apns_voip_channel(ApplicationId=None):
    """
    Disables the APNs VoIP channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_apns_voip_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSVoipChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSVoipChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) VoIP channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs VoIP channel applies to.

CreationDate (string) --The date and time when the APNs VoIP channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with APNs for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs VoIP channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs VoIP channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs VoIP channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs VoIP channel is archived.

LastModifiedBy (string) --The user who last modified the APNs VoIP channel.

LastModifiedDate (string) --The date and time when the APNs VoIP channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs VoIP channel, this value is APNS_VOIP.

Version (integer) --The current version of the APNs VoIP channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSVoipChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_apns_voip_sandbox_channel(ApplicationId=None):
    """
    Disables the APNs VoIP sandbox channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_apns_voip_sandbox_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSVoipSandboxChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSVoipSandboxChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) VoIP sandbox channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs VoIP sandbox channel applies to.

CreationDate (string) --The date and time when the APNs VoIP sandbox channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with the APNs sandbox environment for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs VoIP sandbox channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs VoIP sandbox channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs VoIP sandbox channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs VoIP sandbox channel is archived.

LastModifiedBy (string) --The user who last modified the APNs VoIP sandbox channel.

LastModifiedDate (string) --The date and time when the APNs VoIP sandbox channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs VoIP sandbox channel, this value is APNS_VOIP_SANDBOX.

Version (integer) --The current version of the APNs VoIP sandbox channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSVoipSandboxChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_app(ApplicationId=None):
    """
    Deletes an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_app(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'ApplicationResponse': {
        'Arn': 'string',
        'Id': 'string',
        'Name': 'string',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --The request succeeded.

ApplicationResponse (dict) --Provides information about an application.

Arn (string) --The Amazon Resource Name (ARN) of the application.

Id (string) --The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

Name (string) --The display name of the application. This name is displayed as the Project name on the Amazon Pinpoint console.

tags (dict) --A string-to-string map of key-value pairs that identifies the tags that are associated with the application. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --











Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationResponse': {
            'Arn': 'string',
            'Id': 'string',
            'Name': 'string',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def delete_baidu_channel(ApplicationId=None):
    """
    Disables the Baidu channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_baidu_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'BaiduChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Credential': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

BaiduChannelResponse (dict) --Provides information about the status and settings of the Baidu (Baidu Cloud Push) channel for an application.

ApplicationId (string) --The unique identifier for the application that the Baidu channel applies to.

CreationDate (string) --The date and time when the Baidu channel was enabled.

Credential (string) --The API key that you received from the Baidu Cloud Push service to communicate with the service.

Enabled (boolean) --Specifies whether the Baidu channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the Baidu channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the Baidu channel is archived.

LastModifiedBy (string) --The user who last modified the Baidu channel.

LastModifiedDate (string) --The date and time when the Baidu channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the Baidu channel, this value is BAIDU.

Version (integer) --The current version of the Baidu channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'BaiduChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Credential': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_campaign(ApplicationId=None, CampaignId=None):
    """
    Deletes a campaign from an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_campaign(
        ApplicationId='string',
        CampaignId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignResponse': {
        'AdditionalTreatments': [
            {
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'Id': 'string',
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SizePercent': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string'
            },
        ],
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'CustomDeliveryConfiguration': {
            'DeliveryUri': 'string',
            'EndpointTypes': [
                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            ]
        },
        'DefaultState': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'Description': 'string',
        'HoldoutPercent': 123,
        'Hook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'Id': 'string',
        'IsPaused': True|False,
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'MessageConfiguration': {
            'ADMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'APNSMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'BaiduMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'CustomMessage': {
                'Data': 'string'
            },
            'DefaultMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'EmailMessage': {
                'Body': 'string',
                'FromAddress': 'string',
                'HtmlBody': 'string',
                'Title': 'string'
            },
            'GCMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'SMSMessage': {
                'Body': 'string',
                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                'SenderId': 'string'
            }
        },
        'Name': 'string',
        'Schedule': {
            'EndTime': 'string',
            'EventFilter': {
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'EventType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    }
                },
                'FilterType': 'SYSTEM'|'ENDPOINT'
            },
            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
            'IsLocalTime': True|False,
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'StartTime': 'string',
            'Timezone': 'string'
        },
        'SegmentId': 'string',
        'SegmentVersion': 123,
        'State': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'tags': {
            'string': 'string'
        },
        'TemplateConfiguration': {
            'EmailTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'PushTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'SMSTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'VoiceTemplate': {
                'Name': 'string',
                'Version': 'string'
            }
        },
        'TreatmentDescription': 'string',
        'TreatmentName': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignResponse (dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignResponse': {
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'Id': 'string',
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'DefaultState': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'Id': 'string',
            'IsPaused': True|False,
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'State': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def delete_email_channel(ApplicationId=None):
    """
    Disables the email channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_email_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'EmailChannelResponse': {
        'ApplicationId': 'string',
        'ConfigurationSet': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'FromAddress': 'string',
        'HasCredential': True|False,
        'Id': 'string',
        'Identity': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'MessagesPerSecond': 123,
        'Platform': 'string',
        'RoleArn': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

EmailChannelResponse (dict) --Provides information about the status and settings of the email channel for an application.

ApplicationId (string) --The unique identifier for the application that the email channel applies to.

ConfigurationSet (string) --The Amazon SES configuration set that\'s applied to messages that are sent through the channel.

CreationDate (string) --The date and time, in ISO 8601 format, when the email channel was enabled.

Enabled (boolean) --Specifies whether the email channel is enabled for the application.

FromAddress (string) --The verified email address that email is sent from when you send email through the channel.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the email channel. This property is retained only for backward compatibility.

Identity (string) --The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that\'s used when you send email through the channel.

IsArchived (boolean) --Specifies whether the email channel is archived.

LastModifiedBy (string) --The user who last modified the email channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the email channel was last modified.

MessagesPerSecond (integer) --The maximum number of emails that can be sent through the channel each second.

Platform (string) --The type of messaging or notification platform for the channel. For the email channel, this value is EMAIL.

RoleArn (string) --The ARN of the AWS Identity and Access Management (IAM) role that Amazon Pinpoint uses to submit email-related event data for the channel.

Version (integer) --The current version of the email channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EmailChannelResponse': {
            'ApplicationId': 'string',
            'ConfigurationSet': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'FromAddress': 'string',
            'HasCredential': True|False,
            'Id': 'string',
            'Identity': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'MessagesPerSecond': 123,
            'Platform': 'string',
            'RoleArn': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_email_template(TemplateName=None, Version=None):
    """
    Deletes a message template for messages that were sent through the email channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_email_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def delete_endpoint(ApplicationId=None, EndpointId=None):
    """
    Deletes an endpoint from an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_endpoint(
        ApplicationId='string',
        EndpointId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EndpointId: string
    :param EndpointId: [REQUIRED]\nThe unique identifier for the endpoint.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EndpointResponse': {
        'Address': 'string',
        'ApplicationId': 'string',
        'Attributes': {
            'string': [
                'string',
            ]
        },
        'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
        'CohortId': 'string',
        'CreationDate': 'string',
        'Demographic': {
            'AppVersion': 'string',
            'Locale': 'string',
            'Make': 'string',
            'Model': 'string',
            'ModelVersion': 'string',
            'Platform': 'string',
            'PlatformVersion': 'string',
            'Timezone': 'string'
        },
        'EffectiveDate': 'string',
        'EndpointStatus': 'string',
        'Id': 'string',
        'Location': {
            'City': 'string',
            'Country': 'string',
            'Latitude': 123.0,
            'Longitude': 123.0,
            'PostalCode': 'string',
            'Region': 'string'
        },
        'Metrics': {
            'string': 123.0
        },
        'OptOut': 'string',
        'RequestId': 'string',
        'User': {
            'UserAttributes': {
                'string': [
                    'string',
                ]
            },
            'UserId': 'string'
        }
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

EndpointResponse (dict) --
Provides information about the channel type and other settings for an endpoint.

Address (string) --
The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For example, the address for a push-notification channel is typically the token provided by a push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. The address for the SMS channel is a phone number in E.164 format, such as +12065550100. The address for the email channel is an email address.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the endpoint.

Attributes (dict) --
One or more custom attributes that describe the endpoint by associating a name with an array of values. For example, the value of a custom attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments.

(string) --
(list) --
(string) --






ChannelType (string) --
The channel that\'s used when sending messages or push notifications to the endpoint.

CohortId (string) --
A number from 0-99 that represents the cohort that the endpoint is assigned to. Endpoints are grouped into cohorts randomly, and each cohort contains approximately 1 percent of the endpoints for an application. Amazon Pinpoint assigns cohorts to the holdout or treatment allocations for campaigns.

CreationDate (string) --
The date and time, in ISO 8601 format, when the endpoint was created.

Demographic (dict) --
The demographic information for the endpoint, such as the time zone and platform.

AppVersion (string) --
The version of the app that\'s associated with the endpoint.

Locale (string) --
The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

Make (string) --
The manufacturer of the endpoint device, such as apple or samsung.

Model (string) --
The model name or number of the endpoint device, such as iPhone or SM-G900F.

ModelVersion (string) --
The model version of the endpoint device.

Platform (string) --
The platform of the endpoint device, such as ios.

PlatformVersion (string) --
The platform version of the endpoint device.

Timezone (string) --
The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.



EffectiveDate (string) --
The date and time, in ISO 8601 format, when the endpoint was last updated.

EndpointStatus (string) --
Specifies whether messages or push notifications are sent to the endpoint. Possible values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.
Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.

Id (string) --
The unique identifier that you assigned to the endpoint. The identifier should be a globally unique identifier (GUID) to ensure that it doesn\'t conflict with other endpoint identifiers that are associated with the application.

Location (dict) --
The geographic information for the endpoint.

City (string) --
The name of the city where the endpoint is located.

Country (string) --
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.

Latitude (float) --
The latitude coordinate of the endpoint location, rounded to one decimal place.

Longitude (float) --
The longitude coordinate of the endpoint location, rounded to one decimal place.

PostalCode (string) --
The postal or ZIP code for the area where the endpoint is located.

Region (string) --
The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.



Metrics (dict) --
One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.

(string) --
(float) --




OptOut (string) --
Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.

RequestId (string) --
The unique identifier for the most recent request to update the endpoint.

User (dict) --
One or more custom user attributes that your app reports to Amazon Pinpoint for the user who\'s associated with the endpoint.

UserAttributes (dict) --
One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.
An attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.

(string) --
(list) --
(string) --






UserId (string) --
The unique identifier for the user.











Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EndpointResponse': {
            'Address': 'string',
            'ApplicationId': 'string',
            'Attributes': {
                'string': [
                    'string',
                ]
            },
            'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            'CohortId': 'string',
            'CreationDate': 'string',
            'Demographic': {
                'AppVersion': 'string',
                'Locale': 'string',
                'Make': 'string',
                'Model': 'string',
                'ModelVersion': 'string',
                'Platform': 'string',
                'PlatformVersion': 'string',
                'Timezone': 'string'
            },
            'EffectiveDate': 'string',
            'EndpointStatus': 'string',
            'Id': 'string',
            'Location': {
                'City': 'string',
                'Country': 'string',
                'Latitude': 123.0,
                'Longitude': 123.0,
                'PostalCode': 'string',
                'Region': 'string'
            },
            'Metrics': {
                'string': 123.0
            },
            'OptOut': 'string',
            'RequestId': 'string',
            'User': {
                'UserAttributes': {
                    'string': [
                        'string',
                    ]
                },
                'UserId': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    (list) --
    (string) --
    
    
    
    
    
    """
    pass

def delete_event_stream(ApplicationId=None):
    """
    Deletes the event stream for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_event_stream(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'EventStream': {
        'ApplicationId': 'string',
        'DestinationStreamArn': 'string',
        'ExternalId': 'string',
        'LastModifiedDate': 'string',
        'LastUpdatedBy': 'string',
        'RoleArn': 'string'
    }
}


Response Structure

(dict) --The request succeeded.

EventStream (dict) --Specifies settings for publishing event data to an Amazon Kinesis data stream or an Amazon Kinesis Data Firehose delivery stream.

ApplicationId (string) --The unique identifier for the application to publish event data for.

DestinationStreamArn (string) --The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data Firehose delivery stream to publish event data to.
For a Kinesis data stream, the ARN format is: arn:aws:kinesis:region:account-id:stream/stream_name
For a Kinesis Data Firehose delivery stream, the ARN format is: arn:aws:firehose:region:account-id:deliverystream/stream_name

ExternalId (string) --(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when publishing event data, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

LastModifiedDate (string) --The date, in ISO 8601 format, when the event stream was last modified.

LastUpdatedBy (string) --The IAM user who last modified the event stream.

RoleArn (string) --The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to publish event data to the stream in your AWS account.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EventStream': {
            'ApplicationId': 'string',
            'DestinationStreamArn': 'string',
            'ExternalId': 'string',
            'LastModifiedDate': 'string',
            'LastUpdatedBy': 'string',
            'RoleArn': 'string'
        }
    }
    
    
    """
    pass

def delete_gcm_channel(ApplicationId=None):
    """
    Disables the GCM channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_gcm_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'GCMChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Credential': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

GCMChannelResponse (dict) --Provides information about the status and settings of the GCM channel for an application. The GCM channel enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service.

ApplicationId (string) --The unique identifier for the application that the GCM channel applies to.

CreationDate (string) --The date and time when the GCM channel was enabled.

Credential (string) --The Web API Key, also referred to as an API_KEY or server key , that you received from Google to communicate with Google services.

Enabled (boolean) --Specifies whether the GCM channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the GCM channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the GCM channel is archived.

LastModifiedBy (string) --The user who last modified the GCM channel.

LastModifiedDate (string) --The date and time when the GCM channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the GCM channel, this value is GCM.

Version (integer) --The current version of the GCM channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'GCMChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Credential': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_journey(ApplicationId=None, JourneyId=None):
    """
    Deletes a journey from an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_journey(
        ApplicationId='string',
        JourneyId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyResponse': {
        'Activities': {
            'string': {
                'ConditionalSplit': {
                    'Condition': {
                        'Conditions': [
                            {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                        ],
                        'Operator': 'ALL'|'ANY'
                    },
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    },
                    'FalseActivity': 'string',
                    'TrueActivity': 'string'
                },
                'Description': 'string',
                'EMAIL': {
                    'MessageConfig': {
                        'FromAddress': 'string'
                    },
                    'NextActivity': 'string',
                    'TemplateName': 'string',
                    'TemplateVersion': 'string'
                },
                'Holdout': {
                    'NextActivity': 'string',
                    'Percentage': 123
                },
                'MultiCondition': {
                    'Branches': [
                        {
                            'Condition': {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                            'NextActivity': 'string'
                        },
                    ],
                    'DefaultActivity': 'string',
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                },
                'RandomSplit': {
                    'Branches': [
                        {
                            'NextActivity': 'string',
                            'Percentage': 123
                        },
                    ]
                },
                'Wait': {
                    'NextActivity': 'string',
                    'WaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                }
            }
        },
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Limits': {
            'DailyCap': 123,
            'EndpointReentryCap': 123,
            'MessagesPerSecond': 123
        },
        'LocalTime': True|False,
        'Name': 'string',
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        },
        'RefreshFrequency': 'string',
        'Schedule': {
            'EndTime': datetime(2015, 1, 1),
            'StartTime': datetime(2015, 1, 1),
            'Timezone': 'string'
        },
        'StartActivity': 'string',
        'StartCondition': {
            'Description': 'string',
            'SegmentStartCondition': {
                'SegmentId': 'string'
            }
        },
        'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyResponse (dict) --
Provides information about the status, configuration, and other settings for a journey.

Activities (dict) --
A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity.

(string) --

(dict) --
Specifies the configuration and other settings for an activity in a journey.

ConditionalSplit (dict) --
The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.

Condition (dict) --
The conditions that define the paths for the activity, and the relationship between the conditions.

Conditions (list) --
The conditions to evaluate for the activity.

(dict) --
Specifies a condition to evaluate for an activity in a journey.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --














Operator (string) --
Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.



EvaluationWaitTime (dict) --
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.



FalseActivity (string) --
The unique identifier for the activity to perform if the conditions aren\'t met.

TrueActivity (string) --
The unique identifier for the activity to perform if the conditions are met.



Description (string) --
The custom description of the activity.

EMAIL (dict) --
The settings for an email activity. This type of activity sends an email message to participants.

MessageConfig (dict) --
The "From" address to use for the message.

FromAddress (string) --
The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.



NextActivity (string) --
The unique identifier for the next activity to perform, after the message is sent.

TemplateName (string) --
The name of the email template to use for the message.

TemplateVersion (string) --
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



Holdout (dict) --
The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the holdout activity.

Percentage (integer) --
The percentage of participants who shouldn\'t continue the journey.
To determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.



MultiCondition (dict) --
The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.

(dict) --
Specifies a condition to evaluate for an activity path in a journey.

Condition (dict) --
The condition to evaluate for the activity path.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.





DefaultActivity (string) --
The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.

EvaluationWaitTime (dict) --
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.





RandomSplit (dict) --
The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.

(dict) --
Specifies the settings for a path in a random split activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.

Percentage (integer) --
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.







Wait (dict) --
The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the wait activity.

WaitTime (dict) --
The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.











ApplicationId (string) --
The unique identifier for the application that the journey applies to.

CreationDate (string) --
The date, in ISO 8601 format, when the journey was created.

Id (string) --
The unique identifier for the journey.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the journey was last modified.

Limits (dict) --
The messaging and entry limits for the journey.

DailyCap (integer) --
The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.

EndpointReentryCap (integer) --
The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.

MessagesPerSecond (integer) --
The maximum number of messages that the journey can send each second.



LocalTime (boolean) --
Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. If this value is true, the schedule uses each participant\'s local time.

Name (string) --
The name of the journey.

QuietTime (dict) --
The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.
The current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.
The current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.

If any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



RefreshFrequency (string) --
The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.

Schedule (dict) --
The schedule settings for the journey.

EndTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey ended or will end.

StartTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey began or will begin.

Timezone (string) --
The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.



StartActivity (string) --
The unique identifier for the first activity in the journey.

StartCondition (dict) --
The segment that defines which users are participants in the journey.

Description (string) --
The custom description of the condition.

SegmentStartCondition (dict) --
The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.





State (string) --
The current status of the journey. Possible values are:

DRAFT - The journey is being developed and hasn\'t been published yet.
ACTIVE - The journey has been developed and published. Depending on the journey\'s schedule, the journey may currently be running or scheduled to start running at a later time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.
COMPLETED - The journey has been published and has finished running. All participants have entered the journey and no participants are waiting to complete the journey or any activities in the journey.
CANCELLED - The journey has been stopped. If a journey\'s status is CANCELLED, you can\'t add, change, or remove activities or segment settings from the journey.
CLOSED - The journey has been published and has started running. It may have also passed its scheduled end time, or passed its scheduled start time and a refresh frequency hasn\'t been specified for it. If a journey\'s status is CLOSED, you can\'t add participants to it, and no existing participants can enter the journey for the first time. However, any existing participants who are currently waiting to start an activity may continue the journey.


tags (dict) --
This object is not used or supported.

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyResponse': {
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def delete_push_template(TemplateName=None, Version=None):
    """
    Deletes a message template for messages that were sent through a push notification channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_push_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def delete_recommender_configuration(RecommenderId=None):
    """
    Deletes an Amazon Pinpoint configuration for a recommender model.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_recommender_configuration(
        RecommenderId='string'
    )
    
    
    :type RecommenderId: string
    :param RecommenderId: [REQUIRED]\nThe unique identifier for the recommender model configuration. This identifier is displayed as the Recommender ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'RecommenderConfigurationResponse': {
        'Attributes': {
            'string': 'string'
        },
        'CreationDate': 'string',
        'Description': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Name': 'string',
        'RecommendationProviderIdType': 'string',
        'RecommendationProviderRoleArn': 'string',
        'RecommendationProviderUri': 'string',
        'RecommendationTransformerUri': 'string',
        'RecommendationsDisplayName': 'string',
        'RecommendationsPerMessage': 123
    }
}


Response Structure

(dict) --The request succeeded.

RecommenderConfigurationResponse (dict) --Provides information about Amazon Pinpoint configuration settings for retrieving and processing data from a recommender model.

Attributes (dict) --A map that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

(string) --
(string) --




CreationDate (string) --The date, in extended ISO 8601 format, when the configuration was created for the recommender model.

Description (string) --The custom description of the configuration for the recommender model.

Id (string) --The unique identifier for the recommender model configuration.

LastModifiedDate (string) --The date, in extended ISO 8601 format, when the configuration for the recommender model was last modified.

Name (string) --The custom name of the configuration for the recommender model.

RecommendationProviderIdType (string) --The type of Amazon Pinpoint ID that\'s associated with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Possible values are:

PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.


RecommendationProviderRoleArn (string) --The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.

RecommendationProviderUri (string) --The Amazon Resource Name (ARN) of the recommender model that Amazon Pinpoint retrieves the recommendation data from. This value is the ARN of an Amazon Personalize campaign.

RecommendationTransformerUri (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to perform additional processing of recommendation data that it retrieves from the recommender model.

RecommendationsDisplayName (string) --The custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This name appears in the Attribute finder of the template editor on the Amazon Pinpoint console.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

RecommendationsPerMessage (integer) --The number of recommended items that are retrieved from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'RecommenderConfigurationResponse': {
            'Attributes': {
                'string': 'string'
            },
            'CreationDate': 'string',
            'Description': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Name': 'string',
            'RecommendationProviderIdType': 'string',
            'RecommendationProviderRoleArn': 'string',
            'RecommendationProviderUri': 'string',
            'RecommendationTransformerUri': 'string',
            'RecommendationsDisplayName': 'string',
            'RecommendationsPerMessage': 123
        }
    }
    
    
    :returns: 
    PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
    PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.
    
    """
    pass

def delete_segment(ApplicationId=None, SegmentId=None):
    """
    Deletes a segment from an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_segment(
        ApplicationId='string',
        SegmentId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentResponse': {
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'Dimensions': {
            'Attributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Behavior': {
                'Recency': {
                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                    'RecencyType': 'ACTIVE'|'INACTIVE'
                }
            },
            'Demographic': {
                'AppVersion': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Channel': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'DeviceType': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Make': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Model': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Platform': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Location': {
                'Country': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'GPSPoint': {
                    'Coordinates': {
                        'Latitude': 123.0,
                        'Longitude': 123.0
                    },
                    'RangeInKilometers': 123.0
                }
            },
            'Metrics': {
                'string': {
                    'ComparisonOperator': 'string',
                    'Value': 123.0
                }
            },
            'UserAttributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            }
        },
        'Id': 'string',
        'ImportDefinition': {
            'ChannelCounts': {
                'string': 123
            },
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RoleArn': 'string',
            'S3Url': 'string',
            'Size': 123
        },
        'LastModifiedDate': 'string',
        'Name': 'string',
        'SegmentGroups': {
            'Groups': [
                {
                    'Dimensions': [
                        {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Behavior': {
                                'Recency': {
                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                }
                            },
                            'Demographic': {
                                'AppVersion': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Channel': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'DeviceType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Make': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Model': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Platform': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Location': {
                                'Country': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'GPSPoint': {
                                    'Coordinates': {
                                        'Latitude': 123.0,
                                        'Longitude': 123.0
                                    },
                                    'RangeInKilometers': 123.0
                                }
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            },
                            'UserAttributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            }
                        },
                    ],
                    'SourceSegments': [
                        {
                            'Id': 'string',
                            'Version': 123
                        },
                    ],
                    'SourceType': 'ALL'|'ANY'|'NONE',
                    'Type': 'ALL'|'ANY'|'NONE'
                },
            ],
            'Include': 'ALL'|'ANY'|'NONE'
        },
        'SegmentType': 'DIMENSIONAL'|'IMPORT',
        'tags': {
            'string': 'string'
        },
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

SegmentResponse (dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentResponse': {
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Id': 'string',
            'ImportDefinition': {
                'ChannelCounts': {
                    'string': 123
                },
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RoleArn': 'string',
                'S3Url': 'string',
                'Size': 123
            },
            'LastModifiedDate': 'string',
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'SegmentType': 'DIMENSIONAL'|'IMPORT',
            'tags': {
                'string': 'string'
            },
            'Version': 123
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def delete_sms_channel(ApplicationId=None):
    """
    Disables the SMS channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_sms_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'SMSChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'PromotionalMessagesPerSecond': 123,
        'SenderId': 'string',
        'ShortCode': 'string',
        'TransactionalMessagesPerSecond': 123,
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

SMSChannelResponse (dict) --Provides information about the status and settings of the SMS channel for an application.

ApplicationId (string) --The unique identifier for the application that the SMS channel applies to.

CreationDate (string) --The date and time, in ISO 8601 format, when the SMS channel was enabled.

Enabled (boolean) --Specifies whether the SMS channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the SMS channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the SMS channel is archived.

LastModifiedBy (string) --The user who last modified the SMS channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the SMS channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the SMS channel, this value is SMS.

PromotionalMessagesPerSecond (integer) --The maximum number of promotional messages that you can send through the SMS channel each second.

SenderId (string) --The identity that displays on recipients\' devices when they receive messages from the SMS channel.

ShortCode (string) --The registered short code to use when you send messages through the SMS channel.

TransactionalMessagesPerSecond (integer) --The maximum number of transactional messages that you can send through the SMS channel each second.

Version (integer) --The current version of the SMS channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SMSChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'PromotionalMessagesPerSecond': 123,
            'SenderId': 'string',
            'ShortCode': 'string',
            'TransactionalMessagesPerSecond': 123,
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_sms_template(TemplateName=None, Version=None):
    """
    Deletes a message template for messages that were sent through the SMS channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_sms_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def delete_user_endpoints(ApplicationId=None, UserId=None):
    """
    Deletes all the endpoints that are associated with a specific user ID.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_user_endpoints(
        ApplicationId='string',
        UserId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type UserId: string
    :param UserId: [REQUIRED]\nThe unique identifier for the user.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EndpointsResponse': {
        'Item': [
            {
                'Address': 'string',
                'ApplicationId': 'string',
                'Attributes': {
                    'string': [
                        'string',
                    ]
                },
                'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                'CohortId': 'string',
                'CreationDate': 'string',
                'Demographic': {
                    'AppVersion': 'string',
                    'Locale': 'string',
                    'Make': 'string',
                    'Model': 'string',
                    'ModelVersion': 'string',
                    'Platform': 'string',
                    'PlatformVersion': 'string',
                    'Timezone': 'string'
                },
                'EffectiveDate': 'string',
                'EndpointStatus': 'string',
                'Id': 'string',
                'Location': {
                    'City': 'string',
                    'Country': 'string',
                    'Latitude': 123.0,
                    'Longitude': 123.0,
                    'PostalCode': 'string',
                    'Region': 'string'
                },
                'Metrics': {
                    'string': 123.0
                },
                'OptOut': 'string',
                'RequestId': 'string',
                'User': {
                    'UserAttributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'UserId': 'string'
                }
            },
        ]
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

EndpointsResponse (dict) --
Provides information about all the endpoints that are associated with a user ID.

Item (list) --
An array of responses, one for each endpoint that\'s associated with the user ID.

(dict) --
Provides information about the channel type and other settings for an endpoint.

Address (string) --
The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For example, the address for a push-notification channel is typically the token provided by a push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. The address for the SMS channel is a phone number in E.164 format, such as +12065550100. The address for the email channel is an email address.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the endpoint.

Attributes (dict) --
One or more custom attributes that describe the endpoint by associating a name with an array of values. For example, the value of a custom attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments.

(string) --
(list) --
(string) --






ChannelType (string) --
The channel that\'s used when sending messages or push notifications to the endpoint.

CohortId (string) --
A number from 0-99 that represents the cohort that the endpoint is assigned to. Endpoints are grouped into cohorts randomly, and each cohort contains approximately 1 percent of the endpoints for an application. Amazon Pinpoint assigns cohorts to the holdout or treatment allocations for campaigns.

CreationDate (string) --
The date and time, in ISO 8601 format, when the endpoint was created.

Demographic (dict) --
The demographic information for the endpoint, such as the time zone and platform.

AppVersion (string) --
The version of the app that\'s associated with the endpoint.

Locale (string) --
The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

Make (string) --
The manufacturer of the endpoint device, such as apple or samsung.

Model (string) --
The model name or number of the endpoint device, such as iPhone or SM-G900F.

ModelVersion (string) --
The model version of the endpoint device.

Platform (string) --
The platform of the endpoint device, such as ios.

PlatformVersion (string) --
The platform version of the endpoint device.

Timezone (string) --
The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.



EffectiveDate (string) --
The date and time, in ISO 8601 format, when the endpoint was last updated.

EndpointStatus (string) --
Specifies whether messages or push notifications are sent to the endpoint. Possible values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.
Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.

Id (string) --
The unique identifier that you assigned to the endpoint. The identifier should be a globally unique identifier (GUID) to ensure that it doesn\'t conflict with other endpoint identifiers that are associated with the application.

Location (dict) --
The geographic information for the endpoint.

City (string) --
The name of the city where the endpoint is located.

Country (string) --
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.

Latitude (float) --
The latitude coordinate of the endpoint location, rounded to one decimal place.

Longitude (float) --
The longitude coordinate of the endpoint location, rounded to one decimal place.

PostalCode (string) --
The postal or ZIP code for the area where the endpoint is located.

Region (string) --
The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.



Metrics (dict) --
One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.

(string) --
(float) --




OptOut (string) --
Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.

RequestId (string) --
The unique identifier for the most recent request to update the endpoint.

User (dict) --
One or more custom user attributes that your app reports to Amazon Pinpoint for the user who\'s associated with the endpoint.

UserAttributes (dict) --
One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.
An attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.

(string) --
(list) --
(string) --






UserId (string) --
The unique identifier for the user.















Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EndpointsResponse': {
            'Item': [
                {
                    'Address': 'string',
                    'ApplicationId': 'string',
                    'Attributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    'CohortId': 'string',
                    'CreationDate': 'string',
                    'Demographic': {
                        'AppVersion': 'string',
                        'Locale': 'string',
                        'Make': 'string',
                        'Model': 'string',
                        'ModelVersion': 'string',
                        'Platform': 'string',
                        'PlatformVersion': 'string',
                        'Timezone': 'string'
                    },
                    'EffectiveDate': 'string',
                    'EndpointStatus': 'string',
                    'Id': 'string',
                    'Location': {
                        'City': 'string',
                        'Country': 'string',
                        'Latitude': 123.0,
                        'Longitude': 123.0,
                        'PostalCode': 'string',
                        'Region': 'string'
                    },
                    'Metrics': {
                        'string': 123.0
                    },
                    'OptOut': 'string',
                    'RequestId': 'string',
                    'User': {
                        'UserAttributes': {
                            'string': [
                                'string',
                            ]
                        },
                        'UserId': 'string'
                    }
                },
            ]
        }
    }
    
    
    :returns: 
    (string) --
    (list) --
    (string) --
    
    
    
    
    
    """
    pass

def delete_voice_channel(ApplicationId=None):
    """
    Disables the voice channel for an application and deletes any existing settings for the channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_voice_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'VoiceChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

VoiceChannelResponse (dict) --Provides information about the status and settings of the voice channel for an application.

ApplicationId (string) --The unique identifier for the application that the voice channel applies to.

CreationDate (string) --The date and time, in ISO 8601 format, when the voice channel was enabled.

Enabled (boolean) --Specifies whether the voice channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the voice channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the voice channel is archived.

LastModifiedBy (string) --The user who last modified the voice channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the voice channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the voice channel, this value is VOICE.

Version (integer) --The current version of the voice channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'VoiceChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def delete_voice_template(TemplateName=None, Version=None):
    """
    Deletes a message template for messages that were sent through the voice channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_voice_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_adm_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the ADM channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_adm_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'ADMChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

ADMChannelResponse (dict) --Provides information about the status and settings of the ADM (Amazon Device Messaging) channel for an application.

ApplicationId (string) --The unique identifier for the application that the ADM channel applies to.

CreationDate (string) --The date and time when the ADM channel was enabled.

Enabled (boolean) --Specifies whether the ADM channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the ADM channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the ADM channel is archived.

LastModifiedBy (string) --The user who last modified the ADM channel.

LastModifiedDate (string) --The date and time when the ADM channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the ADM channel, this value is ADM.

Version (integer) --The current version of the ADM channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ADMChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_apns_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the APNs channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_apns_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs channel applies to.

CreationDate (string) --The date and time when the APNs channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with APNs for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs channel is archived.

LastModifiedBy (string) --The user who last modified the APNs channel.

LastModifiedDate (string) --The date and time when the APNs channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs channel, this value is APNS.

Version (integer) --The current version of the APNs channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_apns_sandbox_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the APNs sandbox channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_apns_sandbox_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSSandboxChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSSandboxChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) sandbox channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs sandbox channel applies to.

CreationDate (string) --The date and time when the APNs sandbox channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with the APNs sandbox environment for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs sandbox channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs sandbox channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs sandbox channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs sandbox channel is archived.

LastModifiedBy (string) --The user who last modified the APNs sandbox channel.

LastModifiedDate (string) --The date and time when the APNs sandbox channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs sandbox channel, this value is APNS_SANDBOX.

Version (integer) --The current version of the APNs sandbox channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSSandboxChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_apns_voip_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the APNs VoIP channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_apns_voip_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSVoipChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSVoipChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) VoIP channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs VoIP channel applies to.

CreationDate (string) --The date and time when the APNs VoIP channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with APNs for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs VoIP channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs VoIP channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs VoIP channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs VoIP channel is archived.

LastModifiedBy (string) --The user who last modified the APNs VoIP channel.

LastModifiedDate (string) --The date and time when the APNs VoIP channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs VoIP channel, this value is APNS_VOIP.

Version (integer) --The current version of the APNs VoIP channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSVoipChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_apns_voip_sandbox_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the APNs VoIP sandbox channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_apns_voip_sandbox_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'APNSVoipSandboxChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

APNSVoipSandboxChannelResponse (dict) --Provides information about the status and settings of the APNs (Apple Push Notification service) VoIP sandbox channel for an application.

ApplicationId (string) --The unique identifier for the application that the APNs VoIP sandbox channel applies to.

CreationDate (string) --The date and time when the APNs VoIP sandbox channel was enabled.

DefaultAuthenticationMethod (string) --The default authentication method that Amazon Pinpoint uses to authenticate with the APNs sandbox environment for this channel, key or certificate.

Enabled (boolean) --Specifies whether the APNs VoIP sandbox channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --Specifies whether the APNs VoIP sandbox channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --(Deprecated) An identifier for the APNs VoIP sandbox channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the APNs VoIP sandbox channel is archived.

LastModifiedBy (string) --The user who last modified the APNs VoIP sandbox channel.

LastModifiedDate (string) --The date and time when the APNs VoIP sandbox channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the APNs VoIP sandbox channel, this value is APNS_VOIP_SANDBOX.

Version (integer) --The current version of the APNs VoIP sandbox channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSVoipSandboxChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_app(ApplicationId=None):
    """
    Retrieves information about an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_app(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'ApplicationResponse': {
        'Arn': 'string',
        'Id': 'string',
        'Name': 'string',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --The request succeeded.

ApplicationResponse (dict) --Provides information about an application.

Arn (string) --The Amazon Resource Name (ARN) of the application.

Id (string) --The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

Name (string) --The display name of the application. This name is displayed as the Project name on the Amazon Pinpoint console.

tags (dict) --A string-to-string map of key-value pairs that identifies the tags that are associated with the application. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --











Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationResponse': {
            'Arn': 'string',
            'Id': 'string',
            'Name': 'string',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def get_application_date_range_kpi(ApplicationId=None, EndTime=None, KpiName=None, NextToken=None, PageSize=None, StartTime=None):
    """
    Retrieves (queries) pre-aggregated data for a standard metric that applies to an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_application_date_range_kpi(
        ApplicationId='string',
        EndTime=datetime(2015, 1, 1),
        KpiName='string',
        NextToken='string',
        PageSize='string',
        StartTime=datetime(2015, 1, 1)
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EndTime: datetime
    :param EndTime: The last date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-26T20:00:00Z for 8:00 PM UTC July 26, 2019.

    :type KpiName: string
    :param KpiName: [REQUIRED]\nThe name of the metric, also referred to as a key performance indicator (KPI) , to retrieve data for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see the Amazon Pinpoint Developer Guide .\n

    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type StartTime: datetime
    :param StartTime: The first date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-19T20:00:00Z for 8:00 PM UTC July 19, 2019. This value should also be fewer than 90 days from the current day.

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationDateRangeKpiResponse': {
        'ApplicationId': 'string',
        'EndTime': datetime(2015, 1, 1),
        'KpiName': 'string',
        'KpiResult': {
            'Rows': [
                {
                    'GroupedBys': [
                        {
                            'Key': 'string',
                            'Type': 'string',
                            'Value': 'string'
                        },
                    ],
                    'Values': [
                        {
                            'Key': 'string',
                            'Type': 'string',
                            'Value': 'string'
                        },
                    ]
                },
            ]
        },
        'NextToken': 'string',
        'StartTime': datetime(2015, 1, 1)
    }
}


Response Structure

(dict) --
The request succeeded.

ApplicationDateRangeKpiResponse (dict) --
Provides the results of a query that retrieved the data for a standard metric that applies to an application, and provides information about that query.

ApplicationId (string) --
The unique identifier for the application that the metric applies to.

EndTime (datetime) --
The last date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.

KpiName (string) --
The name of the metric, also referred to as a key performance indicator (KPI) , that the data was retrieved for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. For a list of possible values, see the Amazon Pinpoint Developer Guide .

KpiResult (dict) --
An array of objects that contains the results of the query. Each object contains the value for the metric and metadata about that value.

Rows (list) --
An array of objects that provides the results of a query that retrieved the data for a standard metric that applies to an application, campaign, or journey.

(dict) --
Provides the results of a query that retrieved the data for a standard metric that applies to an application, campaign, or journey.

GroupedBys (list) --
An array of objects that defines the field and field values that were used to group data in a result set that contains multiple results. This value is null if the data in a result set isn\xe2\x80\x99t grouped.

(dict) --
Provides a single value and metadata about that value as part of an array of query results for a standard metric that applies to an application, campaign, or journey.

Key (string) --
The friendly name of the metric whose value is specified by the Value property.

Type (string) --
The data type of the value specified by the Value property.

Value (string) --
In a Values object, the value for the metric that the query retrieved data for. In a GroupedBys object, the value for the field that was used to group data in a result set that contains multiple results (Values objects).





Values (list) --
An array of objects that provides pre-aggregated values for a standard metric that applies to an application, campaign, or journey.

(dict) --
Provides a single value and metadata about that value as part of an array of query results for a standard metric that applies to an application, campaign, or journey.

Key (string) --
The friendly name of the metric whose value is specified by the Value property.

Type (string) --
The data type of the value specified by the Value property.

Value (string) --
In a Values object, the value for the metric that the query retrieved data for. In a GroupedBys object, the value for the field that was used to group data in a result set that contains multiple results (Values objects).











NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null for the Application Metrics resource because the resource returns all results in a single page.

StartTime (datetime) --
The first date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationDateRangeKpiResponse': {
            'ApplicationId': 'string',
            'EndTime': datetime(2015, 1, 1),
            'KpiName': 'string',
            'KpiResult': {
                'Rows': [
                    {
                        'GroupedBys': [
                            {
                                'Key': 'string',
                                'Type': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Values': [
                            {
                                'Key': 'string',
                                'Type': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            },
            'NextToken': 'string',
            'StartTime': datetime(2015, 1, 1)
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def get_application_settings(ApplicationId=None):
    """
    Retrieves information about the settings for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_application_settings(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'ApplicationSettingsResource': {
        'ApplicationId': 'string',
        'CampaignHook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        }
    }
}


Response Structure

(dict) --The request succeeded.

ApplicationSettingsResource (dict) --Provides information about an application, including the default settings for an application.

ApplicationId (string) --The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

CampaignHook (dict) --The settings for the AWS Lambda function to invoke by default as a code hook for campaigns in the application. You can use this hook to customize segments that are used by campaigns in the application.

LambdaFunctionName (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



LastModifiedDate (string) --The date and time, in ISO 8601 format, when the application\'s settings were last modified.

Limits (dict) --The default sending limits for campaigns and journeys in the application.

Daily (integer) --The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



QuietTime (dict) --The default quiet time for campaigns and journeys in the application. Quiet time is a specific time range when messages aren\'t sent to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the application (or a campaign or journey that has custom quiet time settings).
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the application (or a campaign or journey that has custom quiet time settings).

If any of the preceding conditions isn\'t met, the endpoint will receive messages from a campaign or journey, even if quiet time is enabled.

End (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.










Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationSettingsResource': {
            'ApplicationId': 'string',
            'CampaignHook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            }
        }
    }
    
    
    :returns: 
    The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
    The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the application (or a campaign or journey that has custom quiet time settings).
    The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the application (or a campaign or journey that has custom quiet time settings).
    
    """
    pass

def get_apps(PageSize=None, Token=None):
    """
    Retrieves information about all the applications that are associated with your Amazon Pinpoint account.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_apps(
        PageSize='string',
        Token='string'
    )
    
    
    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationsResponse': {
        'Item': [
            {
                'Arn': 'string',
                'Id': 'string',
                'Name': 'string',
                'tags': {
                    'string': 'string'
                }
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ApplicationsResponse (dict) --
Provides information about all of your applications.

Item (list) --
An array of responses, one for each application that was returned.

(dict) --
Provides information about an application.

Arn (string) --
The Amazon Resource Name (ARN) of the application.

Id (string) --
The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

Name (string) --
The display name of the application. This name is displayed as the Project name on the Amazon Pinpoint console.

tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the application. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --








NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationsResponse': {
            'Item': [
                {
                    'Arn': 'string',
                    'Id': 'string',
                    'Name': 'string',
                    'tags': {
                        'string': 'string'
                    }
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_baidu_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the Baidu channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_baidu_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'BaiduChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Credential': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

BaiduChannelResponse (dict) --Provides information about the status and settings of the Baidu (Baidu Cloud Push) channel for an application.

ApplicationId (string) --The unique identifier for the application that the Baidu channel applies to.

CreationDate (string) --The date and time when the Baidu channel was enabled.

Credential (string) --The API key that you received from the Baidu Cloud Push service to communicate with the service.

Enabled (boolean) --Specifies whether the Baidu channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the Baidu channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the Baidu channel is archived.

LastModifiedBy (string) --The user who last modified the Baidu channel.

LastModifiedDate (string) --The date and time when the Baidu channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the Baidu channel, this value is BAIDU.

Version (integer) --The current version of the Baidu channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'BaiduChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Credential': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_campaign(ApplicationId=None, CampaignId=None):
    """
    Retrieves information about the status, configuration, and other settings for a campaign.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_campaign(
        ApplicationId='string',
        CampaignId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignResponse': {
        'AdditionalTreatments': [
            {
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'Id': 'string',
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SizePercent': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string'
            },
        ],
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'CustomDeliveryConfiguration': {
            'DeliveryUri': 'string',
            'EndpointTypes': [
                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            ]
        },
        'DefaultState': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'Description': 'string',
        'HoldoutPercent': 123,
        'Hook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'Id': 'string',
        'IsPaused': True|False,
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'MessageConfiguration': {
            'ADMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'APNSMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'BaiduMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'CustomMessage': {
                'Data': 'string'
            },
            'DefaultMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'EmailMessage': {
                'Body': 'string',
                'FromAddress': 'string',
                'HtmlBody': 'string',
                'Title': 'string'
            },
            'GCMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'SMSMessage': {
                'Body': 'string',
                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                'SenderId': 'string'
            }
        },
        'Name': 'string',
        'Schedule': {
            'EndTime': 'string',
            'EventFilter': {
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'EventType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    }
                },
                'FilterType': 'SYSTEM'|'ENDPOINT'
            },
            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
            'IsLocalTime': True|False,
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'StartTime': 'string',
            'Timezone': 'string'
        },
        'SegmentId': 'string',
        'SegmentVersion': 123,
        'State': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'tags': {
            'string': 'string'
        },
        'TemplateConfiguration': {
            'EmailTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'PushTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'SMSTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'VoiceTemplate': {
                'Name': 'string',
                'Version': 'string'
            }
        },
        'TreatmentDescription': 'string',
        'TreatmentName': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignResponse (dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignResponse': {
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'Id': 'string',
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'DefaultState': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'Id': 'string',
            'IsPaused': True|False,
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'State': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def get_campaign_activities(ApplicationId=None, CampaignId=None, PageSize=None, Token=None):
    """
    Retrieves information about all the activities for a campaign.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_campaign_activities(
        ApplicationId='string',
        CampaignId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ActivitiesResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'CampaignId': 'string',
                'End': 'string',
                'Id': 'string',
                'Result': 'string',
                'ScheduledStart': 'string',
                'Start': 'string',
                'State': 'string',
                'SuccessfulEndpointCount': 123,
                'TimezonesCompletedCount': 123,
                'TimezonesTotalCount': 123,
                'TotalEndpointCount': 123,
                'TreatmentId': 'string'
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ActivitiesResponse (dict) --
Provides information about the activities that were performed by a campaign.

Item (list) --
An array of responses, one for each activity that was performed by the campaign.

(dict) --
Provides information about an activity that was performed by a campaign.

ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

CampaignId (string) --
The unique identifier for the campaign that the activity applies to.

End (string) --
The actual time, in ISO 8601 format, when the activity was marked CANCELLED or COMPLETED.

Id (string) --
The unique identifier for the activity.

Result (string) --
Specifies whether the activity succeeded. Possible values are SUCCESS and FAIL.

ScheduledStart (string) --
The scheduled start time, in ISO 8601 format, for the activity.

Start (string) --
The actual start time, in ISO 8601 format, of the activity.

State (string) --
The current status of the activity. Possible values are: PENDING, INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.

SuccessfulEndpointCount (integer) --
The total number of endpoints that the campaign successfully delivered messages to.

TimezonesCompletedCount (integer) --
The total number of time zones that were completed.

TimezonesTotalCount (integer) --
The total number of unique time zones that are in the segment for the campaign.

TotalEndpointCount (integer) --
The total number of endpoints that the campaign attempted to deliver messages to.

TreatmentId (string) --
The unique identifier for the campaign treatment that the activity applies to. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ActivitiesResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'CampaignId': 'string',
                    'End': 'string',
                    'Id': 'string',
                    'Result': 'string',
                    'ScheduledStart': 'string',
                    'Start': 'string',
                    'State': 'string',
                    'SuccessfulEndpointCount': 123,
                    'TimezonesCompletedCount': 123,
                    'TimezonesTotalCount': 123,
                    'TotalEndpointCount': 123,
                    'TreatmentId': 'string'
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def get_campaign_date_range_kpi(ApplicationId=None, CampaignId=None, EndTime=None, KpiName=None, NextToken=None, PageSize=None, StartTime=None):
    """
    Retrieves (queries) pre-aggregated data for a standard metric that applies to a campaign.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_campaign_date_range_kpi(
        ApplicationId='string',
        CampaignId='string',
        EndTime=datetime(2015, 1, 1),
        KpiName='string',
        NextToken='string',
        PageSize='string',
        StartTime=datetime(2015, 1, 1)
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :type EndTime: datetime
    :param EndTime: The last date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-26T20:00:00Z for 8:00 PM UTC July 26, 2019.

    :type KpiName: string
    :param KpiName: [REQUIRED]\nThe name of the metric, also referred to as a key performance indicator (KPI) , to retrieve data for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see the Amazon Pinpoint Developer Guide .\n

    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type StartTime: datetime
    :param StartTime: The first date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-19T20:00:00Z for 8:00 PM UTC July 19, 2019. This value should also be fewer than 90 days from the current day.

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignDateRangeKpiResponse': {
        'ApplicationId': 'string',
        'CampaignId': 'string',
        'EndTime': datetime(2015, 1, 1),
        'KpiName': 'string',
        'KpiResult': {
            'Rows': [
                {
                    'GroupedBys': [
                        {
                            'Key': 'string',
                            'Type': 'string',
                            'Value': 'string'
                        },
                    ],
                    'Values': [
                        {
                            'Key': 'string',
                            'Type': 'string',
                            'Value': 'string'
                        },
                    ]
                },
            ]
        },
        'NextToken': 'string',
        'StartTime': datetime(2015, 1, 1)
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignDateRangeKpiResponse (dict) --
Provides the results of a query that retrieved the data for a standard metric that applies to a campaign, and provides information about that query.

ApplicationId (string) --
The unique identifier for the application that the metric applies to.

CampaignId (string) --
The unique identifier for the campaign that the metric applies to.

EndTime (datetime) --
The last date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.

KpiName (string) --
The name of the metric, also referred to as a key performance indicator (KPI) , that the data was retrieved for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. For a list of possible values, see the Amazon Pinpoint Developer Guide .

KpiResult (dict) --
An array of objects that contains the results of the query. Each object contains the value for the metric and metadata about that value.

Rows (list) --
An array of objects that provides the results of a query that retrieved the data for a standard metric that applies to an application, campaign, or journey.

(dict) --
Provides the results of a query that retrieved the data for a standard metric that applies to an application, campaign, or journey.

GroupedBys (list) --
An array of objects that defines the field and field values that were used to group data in a result set that contains multiple results. This value is null if the data in a result set isn\xe2\x80\x99t grouped.

(dict) --
Provides a single value and metadata about that value as part of an array of query results for a standard metric that applies to an application, campaign, or journey.

Key (string) --
The friendly name of the metric whose value is specified by the Value property.

Type (string) --
The data type of the value specified by the Value property.

Value (string) --
In a Values object, the value for the metric that the query retrieved data for. In a GroupedBys object, the value for the field that was used to group data in a result set that contains multiple results (Values objects).





Values (list) --
An array of objects that provides pre-aggregated values for a standard metric that applies to an application, campaign, or journey.

(dict) --
Provides a single value and metadata about that value as part of an array of query results for a standard metric that applies to an application, campaign, or journey.

Key (string) --
The friendly name of the metric whose value is specified by the Value property.

Type (string) --
The data type of the value specified by the Value property.

Value (string) --
In a Values object, the value for the metric that the query retrieved data for. In a GroupedBys object, the value for the field that was used to group data in a result set that contains multiple results (Values objects).











NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null for the Campaign Metrics resource because the resource returns all results in a single page.

StartTime (datetime) --
The first date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignDateRangeKpiResponse': {
            'ApplicationId': 'string',
            'CampaignId': 'string',
            'EndTime': datetime(2015, 1, 1),
            'KpiName': 'string',
            'KpiResult': {
                'Rows': [
                    {
                        'GroupedBys': [
                            {
                                'Key': 'string',
                                'Type': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Values': [
                            {
                                'Key': 'string',
                                'Type': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            },
            'NextToken': 'string',
            'StartTime': datetime(2015, 1, 1)
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def get_campaign_version(ApplicationId=None, CampaignId=None, Version=None):
    """
    Retrieves information about the status, configuration, and other settings for a specific version of a campaign.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_campaign_version(
        ApplicationId='string',
        CampaignId='string',
        Version='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :type Version: string
    :param Version: [REQUIRED]\nThe unique version number (Version property) for the campaign version.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignResponse': {
        'AdditionalTreatments': [
            {
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'Id': 'string',
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SizePercent': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string'
            },
        ],
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'CustomDeliveryConfiguration': {
            'DeliveryUri': 'string',
            'EndpointTypes': [
                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            ]
        },
        'DefaultState': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'Description': 'string',
        'HoldoutPercent': 123,
        'Hook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'Id': 'string',
        'IsPaused': True|False,
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'MessageConfiguration': {
            'ADMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'APNSMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'BaiduMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'CustomMessage': {
                'Data': 'string'
            },
            'DefaultMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'EmailMessage': {
                'Body': 'string',
                'FromAddress': 'string',
                'HtmlBody': 'string',
                'Title': 'string'
            },
            'GCMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'SMSMessage': {
                'Body': 'string',
                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                'SenderId': 'string'
            }
        },
        'Name': 'string',
        'Schedule': {
            'EndTime': 'string',
            'EventFilter': {
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'EventType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    }
                },
                'FilterType': 'SYSTEM'|'ENDPOINT'
            },
            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
            'IsLocalTime': True|False,
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'StartTime': 'string',
            'Timezone': 'string'
        },
        'SegmentId': 'string',
        'SegmentVersion': 123,
        'State': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'tags': {
            'string': 'string'
        },
        'TemplateConfiguration': {
            'EmailTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'PushTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'SMSTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'VoiceTemplate': {
                'Name': 'string',
                'Version': 'string'
            }
        },
        'TreatmentDescription': 'string',
        'TreatmentName': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignResponse (dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignResponse': {
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'Id': 'string',
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'DefaultState': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'Id': 'string',
            'IsPaused': True|False,
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'State': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def get_campaign_versions(ApplicationId=None, CampaignId=None, PageSize=None, Token=None):
    """
    Retrieves information about the status, configuration, and other settings for all versions of a campaign.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_campaign_versions(
        ApplicationId='string',
        CampaignId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignsResponse': {
        'Item': [
            {
                'AdditionalTreatments': [
                    {
                        'CustomDeliveryConfiguration': {
                            'DeliveryUri': 'string',
                            'EndpointTypes': [
                                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                            ]
                        },
                        'Id': 'string',
                        'MessageConfiguration': {
                            'ADMMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'APNSMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'BaiduMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'CustomMessage': {
                                'Data': 'string'
                            },
                            'DefaultMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'EmailMessage': {
                                'Body': 'string',
                                'FromAddress': 'string',
                                'HtmlBody': 'string',
                                'Title': 'string'
                            },
                            'GCMMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'SMSMessage': {
                                'Body': 'string',
                                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                'SenderId': 'string'
                            }
                        },
                        'Schedule': {
                            'EndTime': 'string',
                            'EventFilter': {
                                'Dimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'EventType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    }
                                },
                                'FilterType': 'SYSTEM'|'ENDPOINT'
                            },
                            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                            'IsLocalTime': True|False,
                            'QuietTime': {
                                'End': 'string',
                                'Start': 'string'
                            },
                            'StartTime': 'string',
                            'Timezone': 'string'
                        },
                        'SizePercent': 123,
                        'State': {
                            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                        },
                        'TemplateConfiguration': {
                            'EmailTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            },
                            'PushTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            },
                            'SMSTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            },
                            'VoiceTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            }
                        },
                        'TreatmentDescription': 'string',
                        'TreatmentName': 'string'
                    },
                ],
                'ApplicationId': 'string',
                'Arn': 'string',
                'CreationDate': 'string',
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'DefaultState': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'Description': 'string',
                'HoldoutPercent': 123,
                'Hook': {
                    'LambdaFunctionName': 'string',
                    'Mode': 'DELIVERY'|'FILTER',
                    'WebUrl': 'string'
                },
                'Id': 'string',
                'IsPaused': True|False,
                'LastModifiedDate': 'string',
                'Limits': {
                    'Daily': 123,
                    'MaximumDuration': 123,
                    'MessagesPerSecond': 123,
                    'Total': 123
                },
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Name': 'string',
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SegmentId': 'string',
                'SegmentVersion': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'tags': {
                    'string': 'string'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string',
                'Version': 123
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignsResponse (dict) --
Provides information about the configuration and other settings for all the campaigns that are associated with an application.

Item (list) --
An array of responses, one for each campaign that\'s associated with the application.

(dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignsResponse': {
            'Item': [
                {
                    'AdditionalTreatments': [
                        {
                            'CustomDeliveryConfiguration': {
                                'DeliveryUri': 'string',
                                'EndpointTypes': [
                                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                                ]
                            },
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'CustomMessage': {
                                    'Data': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'DefaultState': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def get_campaigns(ApplicationId=None, PageSize=None, Token=None):
    """
    Retrieves information about the status, configuration, and other settings for all the campaigns that are associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_campaigns(
        ApplicationId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignsResponse': {
        'Item': [
            {
                'AdditionalTreatments': [
                    {
                        'CustomDeliveryConfiguration': {
                            'DeliveryUri': 'string',
                            'EndpointTypes': [
                                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                            ]
                        },
                        'Id': 'string',
                        'MessageConfiguration': {
                            'ADMMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'APNSMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'BaiduMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'CustomMessage': {
                                'Data': 'string'
                            },
                            'DefaultMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'EmailMessage': {
                                'Body': 'string',
                                'FromAddress': 'string',
                                'HtmlBody': 'string',
                                'Title': 'string'
                            },
                            'GCMMessage': {
                                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                'Body': 'string',
                                'ImageIconUrl': 'string',
                                'ImageSmallIconUrl': 'string',
                                'ImageUrl': 'string',
                                'JsonBody': 'string',
                                'MediaUrl': 'string',
                                'RawContent': 'string',
                                'SilentPush': True|False,
                                'TimeToLive': 123,
                                'Title': 'string',
                                'Url': 'string'
                            },
                            'SMSMessage': {
                                'Body': 'string',
                                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                'SenderId': 'string'
                            }
                        },
                        'Schedule': {
                            'EndTime': 'string',
                            'EventFilter': {
                                'Dimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'EventType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    }
                                },
                                'FilterType': 'SYSTEM'|'ENDPOINT'
                            },
                            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                            'IsLocalTime': True|False,
                            'QuietTime': {
                                'End': 'string',
                                'Start': 'string'
                            },
                            'StartTime': 'string',
                            'Timezone': 'string'
                        },
                        'SizePercent': 123,
                        'State': {
                            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                        },
                        'TemplateConfiguration': {
                            'EmailTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            },
                            'PushTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            },
                            'SMSTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            },
                            'VoiceTemplate': {
                                'Name': 'string',
                                'Version': 'string'
                            }
                        },
                        'TreatmentDescription': 'string',
                        'TreatmentName': 'string'
                    },
                ],
                'ApplicationId': 'string',
                'Arn': 'string',
                'CreationDate': 'string',
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'DefaultState': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'Description': 'string',
                'HoldoutPercent': 123,
                'Hook': {
                    'LambdaFunctionName': 'string',
                    'Mode': 'DELIVERY'|'FILTER',
                    'WebUrl': 'string'
                },
                'Id': 'string',
                'IsPaused': True|False,
                'LastModifiedDate': 'string',
                'Limits': {
                    'Daily': 123,
                    'MaximumDuration': 123,
                    'MessagesPerSecond': 123,
                    'Total': 123
                },
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Name': 'string',
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SegmentId': 'string',
                'SegmentVersion': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'tags': {
                    'string': 'string'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string',
                'Version': 123
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignsResponse (dict) --
Provides information about the configuration and other settings for all the campaigns that are associated with an application.

Item (list) --
An array of responses, one for each campaign that\'s associated with the application.

(dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignsResponse': {
            'Item': [
                {
                    'AdditionalTreatments': [
                        {
                            'CustomDeliveryConfiguration': {
                                'DeliveryUri': 'string',
                                'EndpointTypes': [
                                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                                ]
                            },
                            'Id': 'string',
                            'MessageConfiguration': {
                                'ADMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'APNSMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'BaiduMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'CustomMessage': {
                                    'Data': 'string'
                                },
                                'DefaultMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'EmailMessage': {
                                    'Body': 'string',
                                    'FromAddress': 'string',
                                    'HtmlBody': 'string',
                                    'Title': 'string'
                                },
                                'GCMMessage': {
                                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                                    'Body': 'string',
                                    'ImageIconUrl': 'string',
                                    'ImageSmallIconUrl': 'string',
                                    'ImageUrl': 'string',
                                    'JsonBody': 'string',
                                    'MediaUrl': 'string',
                                    'RawContent': 'string',
                                    'SilentPush': True|False,
                                    'TimeToLive': 123,
                                    'Title': 'string',
                                    'Url': 'string'
                                },
                                'SMSMessage': {
                                    'Body': 'string',
                                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                                    'SenderId': 'string'
                                }
                            },
                            'Schedule': {
                                'EndTime': 'string',
                                'EventFilter': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'FilterType': 'SYSTEM'|'ENDPOINT'
                                },
                                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                                'IsLocalTime': True|False,
                                'QuietTime': {
                                    'End': 'string',
                                    'Start': 'string'
                                },
                                'StartTime': 'string',
                                'Timezone': 'string'
                            },
                            'SizePercent': 123,
                            'State': {
                                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                            },
                            'TemplateConfiguration': {
                                'EmailTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                },
                                'PushTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                },
                                'SMSTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                },
                                'VoiceTemplate': {
                                    'Name': 'string',
                                    'Version': 'string'
                                }
                            },
                            'TreatmentDescription': 'string',
                            'TreatmentName': 'string'
                        },
                    ],
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'DefaultState': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'Description': 'string',
                    'HoldoutPercent': 123,
                    'Hook': {
                        'LambdaFunctionName': 'string',
                        'Mode': 'DELIVERY'|'FILTER',
                        'WebUrl': 'string'
                    },
                    'Id': 'string',
                    'IsPaused': True|False,
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'Daily': 123,
                        'MaximumDuration': 123,
                        'MessagesPerSecond': 123,
                        'Total': 123
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Name': 'string',
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SegmentId': 'string',
                    'SegmentVersion': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string',
                    'Version': 123
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def get_channels(ApplicationId=None):
    """
    Retrieves information about the history and status of each channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_channels(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'ChannelsResponse': {
        'Channels': {
            'string': {
                'ApplicationId': 'string',
                'CreationDate': 'string',
                'Enabled': True|False,
                'HasCredential': True|False,
                'Id': 'string',
                'IsArchived': True|False,
                'LastModifiedBy': 'string',
                'LastModifiedDate': 'string',
                'Version': 123
            }
        }
    }
}


Response Structure

(dict) --The request succeeded.

ChannelsResponse (dict) --Provides information about the general settings and status of all channels for an application, including channels that aren\'t enabled for the application.

Channels (dict) --A map that contains a multipart response for each channel. For each item in this object, the ChannelType is the key and the Channel is the value.

(string) --
(dict) --Provides information about the general settings and status of a channel for an application.

ApplicationId (string) --The unique identifier for the application.

CreationDate (string) --The date and time, in ISO 8601 format, when the channel was enabled.

Enabled (boolean) --Specifies whether the channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the channel is archived.

LastModifiedBy (string) --The user who last modified the channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the channel was last modified.

Version (integer) --The current version of the channel.














Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ChannelsResponse': {
            'Channels': {
                'string': {
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Enabled': True|False,
                    'HasCredential': True|False,
                    'Id': 'string',
                    'IsArchived': True|False,
                    'LastModifiedBy': 'string',
                    'LastModifiedDate': 'string',
                    'Version': 123
                }
            }
        }
    }
    
    
    """
    pass

def get_email_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the email channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_email_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'EmailChannelResponse': {
        'ApplicationId': 'string',
        'ConfigurationSet': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'FromAddress': 'string',
        'HasCredential': True|False,
        'Id': 'string',
        'Identity': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'MessagesPerSecond': 123,
        'Platform': 'string',
        'RoleArn': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

EmailChannelResponse (dict) --Provides information about the status and settings of the email channel for an application.

ApplicationId (string) --The unique identifier for the application that the email channel applies to.

ConfigurationSet (string) --The Amazon SES configuration set that\'s applied to messages that are sent through the channel.

CreationDate (string) --The date and time, in ISO 8601 format, when the email channel was enabled.

Enabled (boolean) --Specifies whether the email channel is enabled for the application.

FromAddress (string) --The verified email address that email is sent from when you send email through the channel.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the email channel. This property is retained only for backward compatibility.

Identity (string) --The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that\'s used when you send email through the channel.

IsArchived (boolean) --Specifies whether the email channel is archived.

LastModifiedBy (string) --The user who last modified the email channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the email channel was last modified.

MessagesPerSecond (integer) --The maximum number of emails that can be sent through the channel each second.

Platform (string) --The type of messaging or notification platform for the channel. For the email channel, this value is EMAIL.

RoleArn (string) --The ARN of the AWS Identity and Access Management (IAM) role that Amazon Pinpoint uses to submit email-related event data for the channel.

Version (integer) --The current version of the email channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EmailChannelResponse': {
            'ApplicationId': 'string',
            'ConfigurationSet': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'FromAddress': 'string',
            'HasCredential': True|False,
            'Id': 'string',
            'Identity': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'MessagesPerSecond': 123,
            'Platform': 'string',
            'RoleArn': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_email_template(TemplateName=None, Version=None):
    """
    Retrieves the content and settings of a message template for messages that are sent through the email channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_email_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EmailTemplateResponse': {
        'Arn': 'string',
        'CreationDate': 'string',
        'DefaultSubstitutions': 'string',
        'HtmlPart': 'string',
        'LastModifiedDate': 'string',
        'RecommenderId': 'string',
        'Subject': 'string',
        'tags': {
            'string': 'string'
        },
        'TemplateDescription': 'string',
        'TemplateName': 'string',
        'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
        'TextPart': 'string',
        'Version': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

EmailTemplateResponse (dict) --
Provides information about the content and settings for a message template that can be used in messages that are sent through the email channel.

Arn (string) --
The Amazon Resource Name (ARN) of the message template.

CreationDate (string) --
The date, in ISO 8601 format, when the message template was created.

DefaultSubstitutions (string) --
The JSON object that specifies the default values that are used for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable.

HtmlPart (string) --
The message body, in HTML format, that\'s used in email messages that are based on the message template.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the message template was last modified.

RecommenderId (string) --
The unique identifier for the recommender model that\'s used by the message template.

Subject (string) --
The subject line, or title, that\'s used in email messages that are based on the message template.

tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the message template. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateDescription (string) --
The custom description of the message template.

TemplateName (string) --
The name of the message template.

TemplateType (string) --
The type of channel that the message template is designed for. For an email template, this value is EMAIL.

TextPart (string) --
The message body, in plain text format, that\'s used in email messages that are based on the message template.

Version (string) --
The unique identifier, as an integer, for the active version of the message template, or the version of the template that you specified by using the version parameter in your request.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EmailTemplateResponse': {
            'Arn': 'string',
            'CreationDate': 'string',
            'DefaultSubstitutions': 'string',
            'HtmlPart': 'string',
            'LastModifiedDate': 'string',
            'RecommenderId': 'string',
            'Subject': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'TemplateName': 'string',
            'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
            'TextPart': 'string',
            'Version': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_endpoint(ApplicationId=None, EndpointId=None):
    """
    Retrieves information about the settings and attributes of a specific endpoint for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_endpoint(
        ApplicationId='string',
        EndpointId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EndpointId: string
    :param EndpointId: [REQUIRED]\nThe unique identifier for the endpoint.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EndpointResponse': {
        'Address': 'string',
        'ApplicationId': 'string',
        'Attributes': {
            'string': [
                'string',
            ]
        },
        'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
        'CohortId': 'string',
        'CreationDate': 'string',
        'Demographic': {
            'AppVersion': 'string',
            'Locale': 'string',
            'Make': 'string',
            'Model': 'string',
            'ModelVersion': 'string',
            'Platform': 'string',
            'PlatformVersion': 'string',
            'Timezone': 'string'
        },
        'EffectiveDate': 'string',
        'EndpointStatus': 'string',
        'Id': 'string',
        'Location': {
            'City': 'string',
            'Country': 'string',
            'Latitude': 123.0,
            'Longitude': 123.0,
            'PostalCode': 'string',
            'Region': 'string'
        },
        'Metrics': {
            'string': 123.0
        },
        'OptOut': 'string',
        'RequestId': 'string',
        'User': {
            'UserAttributes': {
                'string': [
                    'string',
                ]
            },
            'UserId': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

EndpointResponse (dict) --
Provides information about the channel type and other settings for an endpoint.

Address (string) --
The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For example, the address for a push-notification channel is typically the token provided by a push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. The address for the SMS channel is a phone number in E.164 format, such as +12065550100. The address for the email channel is an email address.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the endpoint.

Attributes (dict) --
One or more custom attributes that describe the endpoint by associating a name with an array of values. For example, the value of a custom attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments.

(string) --
(list) --
(string) --






ChannelType (string) --
The channel that\'s used when sending messages or push notifications to the endpoint.

CohortId (string) --
A number from 0-99 that represents the cohort that the endpoint is assigned to. Endpoints are grouped into cohorts randomly, and each cohort contains approximately 1 percent of the endpoints for an application. Amazon Pinpoint assigns cohorts to the holdout or treatment allocations for campaigns.

CreationDate (string) --
The date and time, in ISO 8601 format, when the endpoint was created.

Demographic (dict) --
The demographic information for the endpoint, such as the time zone and platform.

AppVersion (string) --
The version of the app that\'s associated with the endpoint.

Locale (string) --
The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

Make (string) --
The manufacturer of the endpoint device, such as apple or samsung.

Model (string) --
The model name or number of the endpoint device, such as iPhone or SM-G900F.

ModelVersion (string) --
The model version of the endpoint device.

Platform (string) --
The platform of the endpoint device, such as ios.

PlatformVersion (string) --
The platform version of the endpoint device.

Timezone (string) --
The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.



EffectiveDate (string) --
The date and time, in ISO 8601 format, when the endpoint was last updated.

EndpointStatus (string) --
Specifies whether messages or push notifications are sent to the endpoint. Possible values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.
Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.

Id (string) --
The unique identifier that you assigned to the endpoint. The identifier should be a globally unique identifier (GUID) to ensure that it doesn\'t conflict with other endpoint identifiers that are associated with the application.

Location (dict) --
The geographic information for the endpoint.

City (string) --
The name of the city where the endpoint is located.

Country (string) --
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.

Latitude (float) --
The latitude coordinate of the endpoint location, rounded to one decimal place.

Longitude (float) --
The longitude coordinate of the endpoint location, rounded to one decimal place.

PostalCode (string) --
The postal or ZIP code for the area where the endpoint is located.

Region (string) --
The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.



Metrics (dict) --
One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.

(string) --
(float) --




OptOut (string) --
Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.

RequestId (string) --
The unique identifier for the most recent request to update the endpoint.

User (dict) --
One or more custom user attributes that your app reports to Amazon Pinpoint for the user who\'s associated with the endpoint.

UserAttributes (dict) --
One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.
An attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.

(string) --
(list) --
(string) --






UserId (string) --
The unique identifier for the user.











Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EndpointResponse': {
            'Address': 'string',
            'ApplicationId': 'string',
            'Attributes': {
                'string': [
                    'string',
                ]
            },
            'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            'CohortId': 'string',
            'CreationDate': 'string',
            'Demographic': {
                'AppVersion': 'string',
                'Locale': 'string',
                'Make': 'string',
                'Model': 'string',
                'ModelVersion': 'string',
                'Platform': 'string',
                'PlatformVersion': 'string',
                'Timezone': 'string'
            },
            'EffectiveDate': 'string',
            'EndpointStatus': 'string',
            'Id': 'string',
            'Location': {
                'City': 'string',
                'Country': 'string',
                'Latitude': 123.0,
                'Longitude': 123.0,
                'PostalCode': 'string',
                'Region': 'string'
            },
            'Metrics': {
                'string': 123.0
            },
            'OptOut': 'string',
            'RequestId': 'string',
            'User': {
                'UserAttributes': {
                    'string': [
                        'string',
                    ]
                },
                'UserId': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    (list) --
    (string) --
    
    
    
    
    
    """
    pass

def get_event_stream(ApplicationId=None):
    """
    Retrieves information about the event stream settings for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_event_stream(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'EventStream': {
        'ApplicationId': 'string',
        'DestinationStreamArn': 'string',
        'ExternalId': 'string',
        'LastModifiedDate': 'string',
        'LastUpdatedBy': 'string',
        'RoleArn': 'string'
    }
}


Response Structure

(dict) --The request succeeded.

EventStream (dict) --Specifies settings for publishing event data to an Amazon Kinesis data stream or an Amazon Kinesis Data Firehose delivery stream.

ApplicationId (string) --The unique identifier for the application to publish event data for.

DestinationStreamArn (string) --The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data Firehose delivery stream to publish event data to.
For a Kinesis data stream, the ARN format is: arn:aws:kinesis:region:account-id:stream/stream_name
For a Kinesis Data Firehose delivery stream, the ARN format is: arn:aws:firehose:region:account-id:deliverystream/stream_name

ExternalId (string) --(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when publishing event data, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

LastModifiedDate (string) --The date, in ISO 8601 format, when the event stream was last modified.

LastUpdatedBy (string) --The IAM user who last modified the event stream.

RoleArn (string) --The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to publish event data to the stream in your AWS account.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EventStream': {
            'ApplicationId': 'string',
            'DestinationStreamArn': 'string',
            'ExternalId': 'string',
            'LastModifiedDate': 'string',
            'LastUpdatedBy': 'string',
            'RoleArn': 'string'
        }
    }
    
    
    """
    pass

def get_export_job(ApplicationId=None, JobId=None):
    """
    Retrieves information about the status and settings of a specific export job for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_export_job(
        ApplicationId='string',
        JobId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JobId: string
    :param JobId: [REQUIRED]\nThe unique identifier for the job.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ExportJobResponse': {
        'ApplicationId': 'string',
        'CompletedPieces': 123,
        'CompletionDate': 'string',
        'CreationDate': 'string',
        'Definition': {
            'RoleArn': 'string',
            'S3UrlPrefix': 'string',
            'SegmentId': 'string',
            'SegmentVersion': 123
        },
        'FailedPieces': 123,
        'Failures': [
            'string',
        ],
        'Id': 'string',
        'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
        'TotalFailures': 123,
        'TotalPieces': 123,
        'TotalProcessed': 123,
        'Type': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ExportJobResponse (dict) --
Provides information about the status and settings of a job that exports endpoint definitions to a file. The file can be added directly to an Amazon Simple Storage Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly to a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the export job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the export job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the export job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the export job was created.

Definition (dict) --
The resource settings that apply to the export job.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location where the endpoint definitions were exported to.

S3UrlPrefix (string) --
The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket where the endpoint definitions were exported to. This location is typically a folder that contains multiple files. The URL should be in the following format: s3://bucket-name/folder-name/.

SegmentId (string) --
The identifier for the segment that the endpoint definitions were exported from. If this value isn\'t present, Amazon Pinpoint exported definitions for all the endpoints that are associated with the application.

SegmentVersion (integer) --
The version of the segment that the endpoint definitions were exported from.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the export job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the export job, if any.

(string) --


Id (string) --
The unique identifier for the export job.

JobStatus (string) --
The status of the export job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the export job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the export job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the export job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the export job.

Type (string) --
The job type. This value is EXPORT for export jobs.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ExportJobResponse': {
            'ApplicationId': 'string',
            'CompletedPieces': 123,
            'CompletionDate': 'string',
            'CreationDate': 'string',
            'Definition': {
                'RoleArn': 'string',
                'S3UrlPrefix': 'string',
                'SegmentId': 'string',
                'SegmentVersion': 123
            },
            'FailedPieces': 123,
            'Failures': [
                'string',
            ],
            'Id': 'string',
            'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
            'TotalFailures': 123,
            'TotalPieces': 123,
            'TotalProcessed': 123,
            'Type': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_export_jobs(ApplicationId=None, PageSize=None, Token=None):
    """
    Retrieves information about the status and settings of all the export jobs for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_export_jobs(
        ApplicationId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ExportJobsResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'CompletedPieces': 123,
                'CompletionDate': 'string',
                'CreationDate': 'string',
                'Definition': {
                    'RoleArn': 'string',
                    'S3UrlPrefix': 'string',
                    'SegmentId': 'string',
                    'SegmentVersion': 123
                },
                'FailedPieces': 123,
                'Failures': [
                    'string',
                ],
                'Id': 'string',
                'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                'TotalFailures': 123,
                'TotalPieces': 123,
                'TotalProcessed': 123,
                'Type': 'string'
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ExportJobsResponse (dict) --
Provides information about all the export jobs that are associated with an application or segment. An export job is a job that exports endpoint definitions to a file.

Item (list) --
An array of responses, one for each export job that\'s associated with the application (Export Jobs resource) or segment (Segment Export Jobs resource).

(dict) --
Provides information about the status and settings of a job that exports endpoint definitions to a file. The file can be added directly to an Amazon Simple Storage Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly to a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the export job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the export job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the export job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the export job was created.

Definition (dict) --
The resource settings that apply to the export job.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location where the endpoint definitions were exported to.

S3UrlPrefix (string) --
The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket where the endpoint definitions were exported to. This location is typically a folder that contains multiple files. The URL should be in the following format: s3://bucket-name/folder-name/.

SegmentId (string) --
The identifier for the segment that the endpoint definitions were exported from. If this value isn\'t present, Amazon Pinpoint exported definitions for all the endpoints that are associated with the application.

SegmentVersion (integer) --
The version of the segment that the endpoint definitions were exported from.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the export job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the export job, if any.

(string) --


Id (string) --
The unique identifier for the export job.

JobStatus (string) --
The status of the export job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the export job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the export job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the export job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the export job.

Type (string) --
The job type. This value is EXPORT for export jobs.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ExportJobsResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'RoleArn': 'string',
                        'S3UrlPrefix': 'string',
                        'SegmentId': 'string',
                        'SegmentVersion': 123
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_gcm_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the GCM channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_gcm_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'GCMChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Credential': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

GCMChannelResponse (dict) --Provides information about the status and settings of the GCM channel for an application. The GCM channel enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service.

ApplicationId (string) --The unique identifier for the application that the GCM channel applies to.

CreationDate (string) --The date and time when the GCM channel was enabled.

Credential (string) --The Web API Key, also referred to as an API_KEY or server key , that you received from Google to communicate with Google services.

Enabled (boolean) --Specifies whether the GCM channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the GCM channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the GCM channel is archived.

LastModifiedBy (string) --The user who last modified the GCM channel.

LastModifiedDate (string) --The date and time when the GCM channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the GCM channel, this value is GCM.

Version (integer) --The current version of the GCM channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'GCMChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Credential': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_import_job(ApplicationId=None, JobId=None):
    """
    Retrieves information about the status and settings of a specific import job for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_import_job(
        ApplicationId='string',
        JobId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JobId: string
    :param JobId: [REQUIRED]\nThe unique identifier for the job.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ImportJobResponse': {
        'ApplicationId': 'string',
        'CompletedPieces': 123,
        'CompletionDate': 'string',
        'CreationDate': 'string',
        'Definition': {
            'DefineSegment': True|False,
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RegisterEndpoints': True|False,
            'RoleArn': 'string',
            'S3Url': 'string',
            'SegmentId': 'string',
            'SegmentName': 'string'
        },
        'FailedPieces': 123,
        'Failures': [
            'string',
        ],
        'Id': 'string',
        'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
        'TotalFailures': 123,
        'TotalPieces': 123,
        'TotalProcessed': 123,
        'Type': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ImportJobResponse (dict) --
Provides information about the status and settings of a job that imports endpoint definitions from one or more files. The files can be stored in an Amazon Simple Storage Service (Amazon S3) bucket or uploaded directly from a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the import job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the import job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the import job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the import job was created.

Definition (dict) --
The resource settings that apply to the import job.

DefineSegment (boolean) --
Specifies whether the import job creates a segment that contains the endpoints, when the endpoint definitions are imported.

ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.
If the files are stored in an Amazon S3 location and that location contains multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.

RegisterEndpoints (boolean) --
Specifies whether the import job registers the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.
The URL should be in the following format: s3://bucket-name/folder-name/file-name. The location can end with the key for an individual object or a prefix that qualifies multiple objects.

SegmentId (string) --
The identifier for the segment that the import job updates or adds endpoint definitions to, if the import job updates an existing segment.

SegmentName (string) --
The custom name for the segment that\'s created by the import job, if the value of the DefineSegment property is true.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the import job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the import job, if any.

(string) --


Id (string) --
The unique identifier for the import job.

JobStatus (string) --
The status of the import job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the import job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the import job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the import job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the import job.

Type (string) --
The job type. This value is IMPORT for import jobs.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ImportJobResponse': {
            'ApplicationId': 'string',
            'CompletedPieces': 123,
            'CompletionDate': 'string',
            'CreationDate': 'string',
            'Definition': {
                'DefineSegment': True|False,
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RegisterEndpoints': True|False,
                'RoleArn': 'string',
                'S3Url': 'string',
                'SegmentId': 'string',
                'SegmentName': 'string'
            },
            'FailedPieces': 123,
            'Failures': [
                'string',
            ],
            'Id': 'string',
            'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
            'TotalFailures': 123,
            'TotalPieces': 123,
            'TotalProcessed': 123,
            'Type': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_import_jobs(ApplicationId=None, PageSize=None, Token=None):
    """
    Retrieves information about the status and settings of all the import jobs for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_import_jobs(
        ApplicationId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ImportJobsResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'CompletedPieces': 123,
                'CompletionDate': 'string',
                'CreationDate': 'string',
                'Definition': {
                    'DefineSegment': True|False,
                    'ExternalId': 'string',
                    'Format': 'CSV'|'JSON',
                    'RegisterEndpoints': True|False,
                    'RoleArn': 'string',
                    'S3Url': 'string',
                    'SegmentId': 'string',
                    'SegmentName': 'string'
                },
                'FailedPieces': 123,
                'Failures': [
                    'string',
                ],
                'Id': 'string',
                'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                'TotalFailures': 123,
                'TotalPieces': 123,
                'TotalProcessed': 123,
                'Type': 'string'
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ImportJobsResponse (dict) --
Provides information about the status and settings of all the import jobs that are associated with an application or segment. An import job is a job that imports endpoint definitions from one or more files.

Item (list) --
An array of responses, one for each import job that\'s associated with the application (Import Jobs resource) or segment (Segment Import Jobs resource).

(dict) --
Provides information about the status and settings of a job that imports endpoint definitions from one or more files. The files can be stored in an Amazon Simple Storage Service (Amazon S3) bucket or uploaded directly from a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the import job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the import job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the import job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the import job was created.

Definition (dict) --
The resource settings that apply to the import job.

DefineSegment (boolean) --
Specifies whether the import job creates a segment that contains the endpoints, when the endpoint definitions are imported.

ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.
If the files are stored in an Amazon S3 location and that location contains multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.

RegisterEndpoints (boolean) --
Specifies whether the import job registers the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.
The URL should be in the following format: s3://bucket-name/folder-name/file-name. The location can end with the key for an individual object or a prefix that qualifies multiple objects.

SegmentId (string) --
The identifier for the segment that the import job updates or adds endpoint definitions to, if the import job updates an existing segment.

SegmentName (string) --
The custom name for the segment that\'s created by the import job, if the value of the DefineSegment property is true.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the import job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the import job, if any.

(string) --


Id (string) --
The unique identifier for the import job.

JobStatus (string) --
The status of the import job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the import job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the import job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the import job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the import job.

Type (string) --
The job type. This value is IMPORT for import jobs.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ImportJobsResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'DefineSegment': True|False,
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RegisterEndpoints': True|False,
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'SegmentId': 'string',
                        'SegmentName': 'string'
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_journey(ApplicationId=None, JourneyId=None):
    """
    Retrieves information about the status, configuration, and other settings for a journey.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_journey(
        ApplicationId='string',
        JourneyId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyResponse': {
        'Activities': {
            'string': {
                'ConditionalSplit': {
                    'Condition': {
                        'Conditions': [
                            {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                        ],
                        'Operator': 'ALL'|'ANY'
                    },
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    },
                    'FalseActivity': 'string',
                    'TrueActivity': 'string'
                },
                'Description': 'string',
                'EMAIL': {
                    'MessageConfig': {
                        'FromAddress': 'string'
                    },
                    'NextActivity': 'string',
                    'TemplateName': 'string',
                    'TemplateVersion': 'string'
                },
                'Holdout': {
                    'NextActivity': 'string',
                    'Percentage': 123
                },
                'MultiCondition': {
                    'Branches': [
                        {
                            'Condition': {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                            'NextActivity': 'string'
                        },
                    ],
                    'DefaultActivity': 'string',
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                },
                'RandomSplit': {
                    'Branches': [
                        {
                            'NextActivity': 'string',
                            'Percentage': 123
                        },
                    ]
                },
                'Wait': {
                    'NextActivity': 'string',
                    'WaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                }
            }
        },
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Limits': {
            'DailyCap': 123,
            'EndpointReentryCap': 123,
            'MessagesPerSecond': 123
        },
        'LocalTime': True|False,
        'Name': 'string',
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        },
        'RefreshFrequency': 'string',
        'Schedule': {
            'EndTime': datetime(2015, 1, 1),
            'StartTime': datetime(2015, 1, 1),
            'Timezone': 'string'
        },
        'StartActivity': 'string',
        'StartCondition': {
            'Description': 'string',
            'SegmentStartCondition': {
                'SegmentId': 'string'
            }
        },
        'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyResponse (dict) --
Provides information about the status, configuration, and other settings for a journey.

Activities (dict) --
A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity.

(string) --

(dict) --
Specifies the configuration and other settings for an activity in a journey.

ConditionalSplit (dict) --
The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.

Condition (dict) --
The conditions that define the paths for the activity, and the relationship between the conditions.

Conditions (list) --
The conditions to evaluate for the activity.

(dict) --
Specifies a condition to evaluate for an activity in a journey.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --














Operator (string) --
Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.



EvaluationWaitTime (dict) --
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.



FalseActivity (string) --
The unique identifier for the activity to perform if the conditions aren\'t met.

TrueActivity (string) --
The unique identifier for the activity to perform if the conditions are met.



Description (string) --
The custom description of the activity.

EMAIL (dict) --
The settings for an email activity. This type of activity sends an email message to participants.

MessageConfig (dict) --
The "From" address to use for the message.

FromAddress (string) --
The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.



NextActivity (string) --
The unique identifier for the next activity to perform, after the message is sent.

TemplateName (string) --
The name of the email template to use for the message.

TemplateVersion (string) --
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



Holdout (dict) --
The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the holdout activity.

Percentage (integer) --
The percentage of participants who shouldn\'t continue the journey.
To determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.



MultiCondition (dict) --
The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.

(dict) --
Specifies a condition to evaluate for an activity path in a journey.

Condition (dict) --
The condition to evaluate for the activity path.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.





DefaultActivity (string) --
The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.

EvaluationWaitTime (dict) --
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.





RandomSplit (dict) --
The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.

(dict) --
Specifies the settings for a path in a random split activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.

Percentage (integer) --
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.







Wait (dict) --
The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the wait activity.

WaitTime (dict) --
The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.











ApplicationId (string) --
The unique identifier for the application that the journey applies to.

CreationDate (string) --
The date, in ISO 8601 format, when the journey was created.

Id (string) --
The unique identifier for the journey.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the journey was last modified.

Limits (dict) --
The messaging and entry limits for the journey.

DailyCap (integer) --
The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.

EndpointReentryCap (integer) --
The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.

MessagesPerSecond (integer) --
The maximum number of messages that the journey can send each second.



LocalTime (boolean) --
Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. If this value is true, the schedule uses each participant\'s local time.

Name (string) --
The name of the journey.

QuietTime (dict) --
The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.
The current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.
The current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.

If any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



RefreshFrequency (string) --
The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.

Schedule (dict) --
The schedule settings for the journey.

EndTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey ended or will end.

StartTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey began or will begin.

Timezone (string) --
The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.



StartActivity (string) --
The unique identifier for the first activity in the journey.

StartCondition (dict) --
The segment that defines which users are participants in the journey.

Description (string) --
The custom description of the condition.

SegmentStartCondition (dict) --
The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.





State (string) --
The current status of the journey. Possible values are:

DRAFT - The journey is being developed and hasn\'t been published yet.
ACTIVE - The journey has been developed and published. Depending on the journey\'s schedule, the journey may currently be running or scheduled to start running at a later time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.
COMPLETED - The journey has been published and has finished running. All participants have entered the journey and no participants are waiting to complete the journey or any activities in the journey.
CANCELLED - The journey has been stopped. If a journey\'s status is CANCELLED, you can\'t add, change, or remove activities or segment settings from the journey.
CLOSED - The journey has been published and has started running. It may have also passed its scheduled end time, or passed its scheduled start time and a refresh frequency hasn\'t been specified for it. If a journey\'s status is CLOSED, you can\'t add participants to it, and no existing participants can enter the journey for the first time. However, any existing participants who are currently waiting to start an activity may continue the journey.


tags (dict) --
This object is not used or supported.

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyResponse': {
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_journey_date_range_kpi(ApplicationId=None, EndTime=None, JourneyId=None, KpiName=None, NextToken=None, PageSize=None, StartTime=None):
    """
    Retrieves (queries) pre-aggregated data for a standard engagement metric that applies to a journey.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_journey_date_range_kpi(
        ApplicationId='string',
        EndTime=datetime(2015, 1, 1),
        JourneyId='string',
        KpiName='string',
        NextToken='string',
        PageSize='string',
        StartTime=datetime(2015, 1, 1)
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EndTime: datetime
    :param EndTime: The last date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-26T20:00:00Z for 8:00 PM UTC July 26, 2019.

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :type KpiName: string
    :param KpiName: [REQUIRED]\nThe name of the metric, also referred to as a key performance indicator (KPI) , to retrieve data for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see the Amazon Pinpoint Developer Guide .\n

    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type StartTime: datetime
    :param StartTime: The first date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-19T20:00:00Z for 8:00 PM UTC July 19, 2019. This value should also be fewer than 90 days from the current day.

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyDateRangeKpiResponse': {
        'ApplicationId': 'string',
        'EndTime': datetime(2015, 1, 1),
        'JourneyId': 'string',
        'KpiName': 'string',
        'KpiResult': {
            'Rows': [
                {
                    'GroupedBys': [
                        {
                            'Key': 'string',
                            'Type': 'string',
                            'Value': 'string'
                        },
                    ],
                    'Values': [
                        {
                            'Key': 'string',
                            'Type': 'string',
                            'Value': 'string'
                        },
                    ]
                },
            ]
        },
        'NextToken': 'string',
        'StartTime': datetime(2015, 1, 1)
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyDateRangeKpiResponse (dict) --
Provides the results of a query that retrieved the data for a standard engagement metric that applies to a journey, and provides information about that query.

ApplicationId (string) --
The unique identifier for the application that the metric applies to.

EndTime (datetime) --
The last date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.

JourneyId (string) --
The unique identifier for the journey that the metric applies to.

KpiName (string) --
The name of the metric, also referred to as a key performance indicator (KPI) , that the data was retrieved for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. For a list of possible values, see the Amazon Pinpoint Developer Guide .

KpiResult (dict) --
An array of objects that contains the results of the query. Each object contains the value for the metric and metadata about that value.

Rows (list) --
An array of objects that provides the results of a query that retrieved the data for a standard metric that applies to an application, campaign, or journey.

(dict) --
Provides the results of a query that retrieved the data for a standard metric that applies to an application, campaign, or journey.

GroupedBys (list) --
An array of objects that defines the field and field values that were used to group data in a result set that contains multiple results. This value is null if the data in a result set isn\xe2\x80\x99t grouped.

(dict) --
Provides a single value and metadata about that value as part of an array of query results for a standard metric that applies to an application, campaign, or journey.

Key (string) --
The friendly name of the metric whose value is specified by the Value property.

Type (string) --
The data type of the value specified by the Value property.

Value (string) --
In a Values object, the value for the metric that the query retrieved data for. In a GroupedBys object, the value for the field that was used to group data in a result set that contains multiple results (Values objects).





Values (list) --
An array of objects that provides pre-aggregated values for a standard metric that applies to an application, campaign, or journey.

(dict) --
Provides a single value and metadata about that value as part of an array of query results for a standard metric that applies to an application, campaign, or journey.

Key (string) --
The friendly name of the metric whose value is specified by the Value property.

Type (string) --
The data type of the value specified by the Value property.

Value (string) --
In a Values object, the value for the metric that the query retrieved data for. In a GroupedBys object, the value for the field that was used to group data in a result set that contains multiple results (Values objects).











NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null for the Journey Engagement Metrics resource because the resource returns all results in a single page.

StartTime (datetime) --
The first date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyDateRangeKpiResponse': {
            'ApplicationId': 'string',
            'EndTime': datetime(2015, 1, 1),
            'JourneyId': 'string',
            'KpiName': 'string',
            'KpiResult': {
                'Rows': [
                    {
                        'GroupedBys': [
                            {
                                'Key': 'string',
                                'Type': 'string',
                                'Value': 'string'
                            },
                        ],
                        'Values': [
                            {
                                'Key': 'string',
                                'Type': 'string',
                                'Value': 'string'
                            },
                        ]
                    },
                ]
            },
            'NextToken': 'string',
            'StartTime': datetime(2015, 1, 1)
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def get_journey_execution_activity_metrics(ApplicationId=None, JourneyActivityId=None, JourneyId=None, NextToken=None, PageSize=None):
    """
    Retrieves (queries) pre-aggregated data for a standard execution metric that applies to a journey activity.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_journey_execution_activity_metrics(
        ApplicationId='string',
        JourneyActivityId='string',
        JourneyId='string',
        NextToken='string',
        PageSize='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JourneyActivityId: string
    :param JourneyActivityId: [REQUIRED]\nThe unique identifier for the journey activity.\n

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyExecutionActivityMetricsResponse': {
        'ActivityType': 'string',
        'ApplicationId': 'string',
        'JourneyActivityId': 'string',
        'JourneyId': 'string',
        'LastEvaluatedTime': 'string',
        'Metrics': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyExecutionActivityMetricsResponse (dict) --
Provides the results of a query that retrieved the data for a standard execution metric that applies to a journey activity, and provides information about that query.

ActivityType (string) --
The type of activity that the metric applies to. Possible values are:

CONDITIONAL_SPLIT - For a yes/no split activity, which is an activity that sends participants down one of two paths in a journey.
HOLDOUT - For a holdout activity, which is an activity that stops a journey for a specified percentage of participants.
MESSAGE - For an email activity, which is an activity that sends an email message to participants.
MULTI_CONDITIONAL_SPLIT - For a multivariate split activity, which is an activity that sends participants down one of as many as five paths in a journey.
RANDOM_SPLIT - For a random split activity, which is an activity that sends specified percentages of participants down one of as many as five paths in a journey.
WAIT - For a wait activity, which is an activity that waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.


ApplicationId (string) --
The unique identifier for the application that the metric applies to.

JourneyActivityId (string) --
The unique identifier for the activity that the metric applies to.

JourneyId (string) --
The unique identifier for the journey that the metric applies to.

LastEvaluatedTime (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint last evaluated the execution status of the activity and updated the data for the metric.

Metrics (dict) --
A JSON object that contains the results of the query. The results vary depending on the type of activity (ActivityType). For information about the structure and contents of the results, see the Amazon Pinpoint Developer Guide .

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyExecutionActivityMetricsResponse': {
            'ActivityType': 'string',
            'ApplicationId': 'string',
            'JourneyActivityId': 'string',
            'JourneyId': 'string',
            'LastEvaluatedTime': 'string',
            'Metrics': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    CONDITIONAL_SPLIT - For a yes/no split activity, which is an activity that sends participants down one of two paths in a journey.
    HOLDOUT - For a holdout activity, which is an activity that stops a journey for a specified percentage of participants.
    MESSAGE - For an email activity, which is an activity that sends an email message to participants.
    MULTI_CONDITIONAL_SPLIT - For a multivariate split activity, which is an activity that sends participants down one of as many as five paths in a journey.
    RANDOM_SPLIT - For a random split activity, which is an activity that sends specified percentages of participants down one of as many as five paths in a journey.
    WAIT - For a wait activity, which is an activity that waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.
    
    """
    pass

def get_journey_execution_metrics(ApplicationId=None, JourneyId=None, NextToken=None, PageSize=None):
    """
    Retrieves (queries) pre-aggregated data for a standard execution metric that applies to a journey.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_journey_execution_metrics(
        ApplicationId='string',
        JourneyId='string',
        NextToken='string',
        PageSize='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyExecutionMetricsResponse': {
        'ApplicationId': 'string',
        'JourneyId': 'string',
        'LastEvaluatedTime': 'string',
        'Metrics': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyExecutionMetricsResponse (dict) --
Provides the results of a query that retrieved the data for a standard execution metric that applies to a journey, and provides information about that query.

ApplicationId (string) --
The unique identifier for the application that the metric applies to.

JourneyId (string) --
The unique identifier for the journey that the metric applies to.

LastEvaluatedTime (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint last evaluated the journey and updated the data for the metric.

Metrics (dict) --
A JSON object that contains the results of the query. For information about the structure and contents of the results, see the Amazon Pinpoint Developer Guide .

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyExecutionMetricsResponse': {
            'ApplicationId': 'string',
            'JourneyId': 'string',
            'LastEvaluatedTime': 'string',
            'Metrics': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_push_template(TemplateName=None, Version=None):
    """
    Retrieves the content and settings of a message template for messages that are sent through a push notification channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_push_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'PushNotificationTemplateResponse': {
        'ADM': {
            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
            'Body': 'string',
            'ImageIconUrl': 'string',
            'ImageUrl': 'string',
            'RawContent': 'string',
            'SmallImageIconUrl': 'string',
            'Sound': 'string',
            'Title': 'string',
            'Url': 'string'
        },
        'APNS': {
            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
            'Body': 'string',
            'MediaUrl': 'string',
            'RawContent': 'string',
            'Sound': 'string',
            'Title': 'string',
            'Url': 'string'
        },
        'Arn': 'string',
        'Baidu': {
            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
            'Body': 'string',
            'ImageIconUrl': 'string',
            'ImageUrl': 'string',
            'RawContent': 'string',
            'SmallImageIconUrl': 'string',
            'Sound': 'string',
            'Title': 'string',
            'Url': 'string'
        },
        'CreationDate': 'string',
        'Default': {
            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
            'Body': 'string',
            'Sound': 'string',
            'Title': 'string',
            'Url': 'string'
        },
        'DefaultSubstitutions': 'string',
        'GCM': {
            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
            'Body': 'string',
            'ImageIconUrl': 'string',
            'ImageUrl': 'string',
            'RawContent': 'string',
            'SmallImageIconUrl': 'string',
            'Sound': 'string',
            'Title': 'string',
            'Url': 'string'
        },
        'LastModifiedDate': 'string',
        'RecommenderId': 'string',
        'tags': {
            'string': 'string'
        },
        'TemplateDescription': 'string',
        'TemplateName': 'string',
        'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
        'Version': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

PushNotificationTemplateResponse (dict) --
Provides information about the content and settings for a message template that can be used in messages that are sent through a push notification channel.

ADM (dict) --
The message template that\'s used for the ADM (Amazon Device Messaging) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).

Action (string) --
The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The message body to use in a push notification that\'s based on the message template.

ImageIconUrl (string) --
The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.

ImageUrl (string) --
The URL of an image to display in a push notification that\'s based on the message template.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.

SmallImageIconUrl (string) --
The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.

Sound (string) --
The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.

Title (string) --
The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.



APNS (dict) --
The message template that\'s used for the APNs (Apple Push Notification service) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).

Action (string) --
The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The message body to use in push notifications that are based on the message template.

MediaUrl (string) --
The URL of an image or video to display in push notifications that are based on the message template.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for push notifications that are based on the message template. If specified, this value overrides all other content for the message template.

Sound (string) --
The key for the sound to play when the recipient receives a push notification that\'s based on the message template. The value for this key is the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.

Title (string) --
The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient\'s device.

Url (string) --
The URL to open in the recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.



Arn (string) --
The Amazon Resource Name (ARN) of the message template.

Baidu (dict) --
The message template that\'s used for the Baidu (Baidu Cloud Push) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).

Action (string) --
The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The message body to use in a push notification that\'s based on the message template.

ImageIconUrl (string) --
The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.

ImageUrl (string) --
The URL of an image to display in a push notification that\'s based on the message template.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.

SmallImageIconUrl (string) --
The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.

Sound (string) --
The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.

Title (string) --
The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.



CreationDate (string) --
The date, in ISO 8601 format, when the message template was created.

Default (dict) --
The default message template that\'s used for push notification channels.

Action (string) --
The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The message body to use in push notifications that are based on the message template.

Sound (string) --
The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.
For an iOS platform, this value is the key for the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.

Title (string) --
The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.



DefaultSubstitutions (string) --
The JSON object that specifies the default values that are used for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable.

GCM (dict) --
The message template that\'s used for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).

Action (string) --
The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The message body to use in a push notification that\'s based on the message template.

ImageIconUrl (string) --
The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.

ImageUrl (string) --
The URL of an image to display in a push notification that\'s based on the message template.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.

SmallImageIconUrl (string) --
The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.

Sound (string) --
The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.

Title (string) --
The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.



LastModifiedDate (string) --
The date, in ISO 8601 format, when the message template was last modified.

RecommenderId (string) --
The unique identifier for the recommender model that\'s used by the message template.

tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the message template. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateDescription (string) --
The custom description of the message template.

TemplateName (string) --
The name of the message template.

TemplateType (string) --
The type of channel that the message template is designed for. For a push notification template, this value is PUSH.

Version (string) --
The unique identifier, as an integer, for the active version of the message template, or the version of the template that you specified by using the version parameter in your request.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'PushNotificationTemplateResponse': {
            'ADM': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'APNS': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'Arn': 'string',
            'Baidu': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'CreationDate': 'string',
            'Default': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'DefaultSubstitutions': 'string',
            'GCM': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'LastModifiedDate': 'string',
            'RecommenderId': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'TemplateName': 'string',
            'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
            'Version': 'string'
        }
    }
    
    
    :returns: 
    OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
    DEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.
    URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.
    
    """
    pass

def get_recommender_configuration(RecommenderId=None):
    """
    Retrieves information about an Amazon Pinpoint configuration for a recommender model.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_recommender_configuration(
        RecommenderId='string'
    )
    
    
    :type RecommenderId: string
    :param RecommenderId: [REQUIRED]\nThe unique identifier for the recommender model configuration. This identifier is displayed as the Recommender ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'RecommenderConfigurationResponse': {
        'Attributes': {
            'string': 'string'
        },
        'CreationDate': 'string',
        'Description': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Name': 'string',
        'RecommendationProviderIdType': 'string',
        'RecommendationProviderRoleArn': 'string',
        'RecommendationProviderUri': 'string',
        'RecommendationTransformerUri': 'string',
        'RecommendationsDisplayName': 'string',
        'RecommendationsPerMessage': 123
    }
}


Response Structure

(dict) --The request succeeded.

RecommenderConfigurationResponse (dict) --Provides information about Amazon Pinpoint configuration settings for retrieving and processing data from a recommender model.

Attributes (dict) --A map that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

(string) --
(string) --




CreationDate (string) --The date, in extended ISO 8601 format, when the configuration was created for the recommender model.

Description (string) --The custom description of the configuration for the recommender model.

Id (string) --The unique identifier for the recommender model configuration.

LastModifiedDate (string) --The date, in extended ISO 8601 format, when the configuration for the recommender model was last modified.

Name (string) --The custom name of the configuration for the recommender model.

RecommendationProviderIdType (string) --The type of Amazon Pinpoint ID that\'s associated with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Possible values are:

PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.


RecommendationProviderRoleArn (string) --The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.

RecommendationProviderUri (string) --The Amazon Resource Name (ARN) of the recommender model that Amazon Pinpoint retrieves the recommendation data from. This value is the ARN of an Amazon Personalize campaign.

RecommendationTransformerUri (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to perform additional processing of recommendation data that it retrieves from the recommender model.

RecommendationsDisplayName (string) --The custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This name appears in the Attribute finder of the template editor on the Amazon Pinpoint console.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

RecommendationsPerMessage (integer) --The number of recommended items that are retrieved from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'RecommenderConfigurationResponse': {
            'Attributes': {
                'string': 'string'
            },
            'CreationDate': 'string',
            'Description': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Name': 'string',
            'RecommendationProviderIdType': 'string',
            'RecommendationProviderRoleArn': 'string',
            'RecommendationProviderUri': 'string',
            'RecommendationTransformerUri': 'string',
            'RecommendationsDisplayName': 'string',
            'RecommendationsPerMessage': 123
        }
    }
    
    
    :returns: 
    PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
    PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.
    
    """
    pass

def get_recommender_configurations(PageSize=None, Token=None):
    """
    Retrieves information about all the recommender model configurations that are associated with your Amazon Pinpoint account.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_recommender_configurations(
        PageSize='string',
        Token='string'
    )
    
    
    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ListRecommenderConfigurationsResponse': {
        'Item': [
            {
                'Attributes': {
                    'string': 'string'
                },
                'CreationDate': 'string',
                'Description': 'string',
                'Id': 'string',
                'LastModifiedDate': 'string',
                'Name': 'string',
                'RecommendationProviderIdType': 'string',
                'RecommendationProviderRoleArn': 'string',
                'RecommendationProviderUri': 'string',
                'RecommendationTransformerUri': 'string',
                'RecommendationsDisplayName': 'string',
                'RecommendationsPerMessage': 123
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ListRecommenderConfigurationsResponse (dict) --
Provides information about all the recommender model configurations that are associated with your Amazon Pinpoint account.

Item (list) --
An array of responses, one for each recommender model configuration that\'s associated with your Amazon Pinpoint account.

(dict) --
Provides information about Amazon Pinpoint configuration settings for retrieving and processing data from a recommender model.

Attributes (dict) --
A map that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

(string) --
(string) --




CreationDate (string) --
The date, in extended ISO 8601 format, when the configuration was created for the recommender model.

Description (string) --
The custom description of the configuration for the recommender model.

Id (string) --
The unique identifier for the recommender model configuration.

LastModifiedDate (string) --
The date, in extended ISO 8601 format, when the configuration for the recommender model was last modified.

Name (string) --
The custom name of the configuration for the recommender model.

RecommendationProviderIdType (string) --
The type of Amazon Pinpoint ID that\'s associated with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Possible values are:

PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.


RecommendationProviderRoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.

RecommendationProviderUri (string) --
The Amazon Resource Name (ARN) of the recommender model that Amazon Pinpoint retrieves the recommendation data from. This value is the ARN of an Amazon Personalize campaign.

RecommendationTransformerUri (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to perform additional processing of recommendation data that it retrieves from the recommender model.

RecommendationsDisplayName (string) --
The custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This name appears in the Attribute finder of the template editor on the Amazon Pinpoint console.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

RecommendationsPerMessage (integer) --
The number of recommended items that are retrieved from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ListRecommenderConfigurationsResponse': {
            'Item': [
                {
                    'Attributes': {
                        'string': 'string'
                    },
                    'CreationDate': 'string',
                    'Description': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'RecommendationProviderIdType': 'string',
                    'RecommendationProviderRoleArn': 'string',
                    'RecommendationProviderUri': 'string',
                    'RecommendationTransformerUri': 'string',
                    'RecommendationsDisplayName': 'string',
                    'RecommendationsPerMessage': 123
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_segment(ApplicationId=None, SegmentId=None):
    """
    Retrieves information about the configuration, dimension, and other settings for a specific segment that\'s associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_segment(
        ApplicationId='string',
        SegmentId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentResponse': {
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'Dimensions': {
            'Attributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Behavior': {
                'Recency': {
                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                    'RecencyType': 'ACTIVE'|'INACTIVE'
                }
            },
            'Demographic': {
                'AppVersion': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Channel': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'DeviceType': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Make': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Model': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Platform': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Location': {
                'Country': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'GPSPoint': {
                    'Coordinates': {
                        'Latitude': 123.0,
                        'Longitude': 123.0
                    },
                    'RangeInKilometers': 123.0
                }
            },
            'Metrics': {
                'string': {
                    'ComparisonOperator': 'string',
                    'Value': 123.0
                }
            },
            'UserAttributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            }
        },
        'Id': 'string',
        'ImportDefinition': {
            'ChannelCounts': {
                'string': 123
            },
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RoleArn': 'string',
            'S3Url': 'string',
            'Size': 123
        },
        'LastModifiedDate': 'string',
        'Name': 'string',
        'SegmentGroups': {
            'Groups': [
                {
                    'Dimensions': [
                        {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Behavior': {
                                'Recency': {
                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                }
                            },
                            'Demographic': {
                                'AppVersion': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Channel': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'DeviceType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Make': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Model': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Platform': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Location': {
                                'Country': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'GPSPoint': {
                                    'Coordinates': {
                                        'Latitude': 123.0,
                                        'Longitude': 123.0
                                    },
                                    'RangeInKilometers': 123.0
                                }
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            },
                            'UserAttributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            }
                        },
                    ],
                    'SourceSegments': [
                        {
                            'Id': 'string',
                            'Version': 123
                        },
                    ],
                    'SourceType': 'ALL'|'ANY'|'NONE',
                    'Type': 'ALL'|'ANY'|'NONE'
                },
            ],
            'Include': 'ALL'|'ANY'|'NONE'
        },
        'SegmentType': 'DIMENSIONAL'|'IMPORT',
        'tags': {
            'string': 'string'
        },
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

SegmentResponse (dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentResponse': {
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Id': 'string',
            'ImportDefinition': {
                'ChannelCounts': {
                    'string': 123
                },
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RoleArn': 'string',
                'S3Url': 'string',
                'Size': 123
            },
            'LastModifiedDate': 'string',
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'SegmentType': 'DIMENSIONAL'|'IMPORT',
            'tags': {
                'string': 'string'
            },
            'Version': 123
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_segment_export_jobs(ApplicationId=None, PageSize=None, SegmentId=None, Token=None):
    """
    Retrieves information about the status and settings of the export jobs for a segment.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_segment_export_jobs(
        ApplicationId='string',
        PageSize='string',
        SegmentId='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ExportJobsResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'CompletedPieces': 123,
                'CompletionDate': 'string',
                'CreationDate': 'string',
                'Definition': {
                    'RoleArn': 'string',
                    'S3UrlPrefix': 'string',
                    'SegmentId': 'string',
                    'SegmentVersion': 123
                },
                'FailedPieces': 123,
                'Failures': [
                    'string',
                ],
                'Id': 'string',
                'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                'TotalFailures': 123,
                'TotalPieces': 123,
                'TotalProcessed': 123,
                'Type': 'string'
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ExportJobsResponse (dict) --
Provides information about all the export jobs that are associated with an application or segment. An export job is a job that exports endpoint definitions to a file.

Item (list) --
An array of responses, one for each export job that\'s associated with the application (Export Jobs resource) or segment (Segment Export Jobs resource).

(dict) --
Provides information about the status and settings of a job that exports endpoint definitions to a file. The file can be added directly to an Amazon Simple Storage Service (Amazon S3) bucket by using the Amazon Pinpoint API or downloaded directly to a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the export job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the export job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the export job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the export job was created.

Definition (dict) --
The resource settings that apply to the export job.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location where the endpoint definitions were exported to.

S3UrlPrefix (string) --
The URL of the location in an Amazon Simple Storage Service (Amazon S3) bucket where the endpoint definitions were exported to. This location is typically a folder that contains multiple files. The URL should be in the following format: s3://bucket-name/folder-name/.

SegmentId (string) --
The identifier for the segment that the endpoint definitions were exported from. If this value isn\'t present, Amazon Pinpoint exported definitions for all the endpoints that are associated with the application.

SegmentVersion (integer) --
The version of the segment that the endpoint definitions were exported from.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the export job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the export job, if any.

(string) --


Id (string) --
The unique identifier for the export job.

JobStatus (string) --
The status of the export job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the export job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the export job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the export job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the export job.

Type (string) --
The job type. This value is EXPORT for export jobs.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ExportJobsResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'RoleArn': 'string',
                        'S3UrlPrefix': 'string',
                        'SegmentId': 'string',
                        'SegmentVersion': 123
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_segment_import_jobs(ApplicationId=None, PageSize=None, SegmentId=None, Token=None):
    """
    Retrieves information about the status and settings of the import jobs for a segment.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_segment_import_jobs(
        ApplicationId='string',
        PageSize='string',
        SegmentId='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'ImportJobsResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'CompletedPieces': 123,
                'CompletionDate': 'string',
                'CreationDate': 'string',
                'Definition': {
                    'DefineSegment': True|False,
                    'ExternalId': 'string',
                    'Format': 'CSV'|'JSON',
                    'RegisterEndpoints': True|False,
                    'RoleArn': 'string',
                    'S3Url': 'string',
                    'SegmentId': 'string',
                    'SegmentName': 'string'
                },
                'FailedPieces': 123,
                'Failures': [
                    'string',
                ],
                'Id': 'string',
                'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                'TotalFailures': 123,
                'TotalPieces': 123,
                'TotalProcessed': 123,
                'Type': 'string'
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

ImportJobsResponse (dict) --
Provides information about the status and settings of all the import jobs that are associated with an application or segment. An import job is a job that imports endpoint definitions from one or more files.

Item (list) --
An array of responses, one for each import job that\'s associated with the application (Import Jobs resource) or segment (Segment Import Jobs resource).

(dict) --
Provides information about the status and settings of a job that imports endpoint definitions from one or more files. The files can be stored in an Amazon Simple Storage Service (Amazon S3) bucket or uploaded directly from a computer by using the Amazon Pinpoint console.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the import job.

CompletedPieces (integer) --
The number of pieces that were processed successfully (completed) by the import job, as of the time of the request.

CompletionDate (string) --
The date, in ISO 8601 format, when the import job was completed.

CreationDate (string) --
The date, in ISO 8601 format, when the import job was created.

Definition (dict) --
The resource settings that apply to the import job.

DefineSegment (boolean) --
Specifies whether the import job creates a segment that contains the endpoints, when the endpoint definitions are imported.

ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.
If the files are stored in an Amazon S3 location and that location contains multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.

RegisterEndpoints (boolean) --
Specifies whether the import job registers the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.
The URL should be in the following format: s3://bucket-name/folder-name/file-name. The location can end with the key for an individual object or a prefix that qualifies multiple objects.

SegmentId (string) --
The identifier for the segment that the import job updates or adds endpoint definitions to, if the import job updates an existing segment.

SegmentName (string) --
The custom name for the segment that\'s created by the import job, if the value of the DefineSegment property is true.



FailedPieces (integer) --
The number of pieces that weren\'t processed successfully (failed) by the import job, as of the time of the request.

Failures (list) --
An array of entries, one for each of the first 100 entries that weren\'t processed successfully (failed) by the import job, if any.

(string) --


Id (string) --
The unique identifier for the import job.

JobStatus (string) --
The status of the import job. The job status is FAILED if Amazon Pinpoint wasn\'t able to process one or more pieces in the job.

TotalFailures (integer) --
The total number of endpoint definitions that weren\'t processed successfully (failed) by the import job, typically because an error, such as a syntax error, occurred.

TotalPieces (integer) --
The total number of pieces that must be processed to complete the import job. Each piece consists of an approximately equal portion of the endpoint definitions that are part of the import job.

TotalProcessed (integer) --
The total number of endpoint definitions that were processed by the import job.

Type (string) --
The job type. This value is IMPORT for import jobs.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ImportJobsResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'CompletedPieces': 123,
                    'CompletionDate': 'string',
                    'CreationDate': 'string',
                    'Definition': {
                        'DefineSegment': True|False,
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RegisterEndpoints': True|False,
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'SegmentId': 'string',
                        'SegmentName': 'string'
                    },
                    'FailedPieces': 123,
                    'Failures': [
                        'string',
                    ],
                    'Id': 'string',
                    'JobStatus': 'CREATED'|'PREPARING_FOR_INITIALIZATION'|'INITIALIZING'|'PROCESSING'|'PENDING_JOB'|'COMPLETING'|'COMPLETED'|'FAILING'|'FAILED',
                    'TotalFailures': 123,
                    'TotalPieces': 123,
                    'TotalProcessed': 123,
                    'Type': 'string'
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_segment_version(ApplicationId=None, SegmentId=None, Version=None):
    """
    Retrieves information about the configuration, dimension, and other settings for a specific version of a segment that\'s associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_segment_version(
        ApplicationId='string',
        SegmentId='string',
        Version='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :type Version: string
    :param Version: [REQUIRED]\nThe unique version number (Version property) for the campaign version.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentResponse': {
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'Dimensions': {
            'Attributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Behavior': {
                'Recency': {
                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                    'RecencyType': 'ACTIVE'|'INACTIVE'
                }
            },
            'Demographic': {
                'AppVersion': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Channel': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'DeviceType': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Make': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Model': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Platform': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Location': {
                'Country': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'GPSPoint': {
                    'Coordinates': {
                        'Latitude': 123.0,
                        'Longitude': 123.0
                    },
                    'RangeInKilometers': 123.0
                }
            },
            'Metrics': {
                'string': {
                    'ComparisonOperator': 'string',
                    'Value': 123.0
                }
            },
            'UserAttributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            }
        },
        'Id': 'string',
        'ImportDefinition': {
            'ChannelCounts': {
                'string': 123
            },
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RoleArn': 'string',
            'S3Url': 'string',
            'Size': 123
        },
        'LastModifiedDate': 'string',
        'Name': 'string',
        'SegmentGroups': {
            'Groups': [
                {
                    'Dimensions': [
                        {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Behavior': {
                                'Recency': {
                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                }
                            },
                            'Demographic': {
                                'AppVersion': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Channel': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'DeviceType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Make': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Model': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Platform': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Location': {
                                'Country': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'GPSPoint': {
                                    'Coordinates': {
                                        'Latitude': 123.0,
                                        'Longitude': 123.0
                                    },
                                    'RangeInKilometers': 123.0
                                }
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            },
                            'UserAttributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            }
                        },
                    ],
                    'SourceSegments': [
                        {
                            'Id': 'string',
                            'Version': 123
                        },
                    ],
                    'SourceType': 'ALL'|'ANY'|'NONE',
                    'Type': 'ALL'|'ANY'|'NONE'
                },
            ],
            'Include': 'ALL'|'ANY'|'NONE'
        },
        'SegmentType': 'DIMENSIONAL'|'IMPORT',
        'tags': {
            'string': 'string'
        },
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

SegmentResponse (dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentResponse': {
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Id': 'string',
            'ImportDefinition': {
                'ChannelCounts': {
                    'string': 123
                },
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RoleArn': 'string',
                'S3Url': 'string',
                'Size': 123
            },
            'LastModifiedDate': 'string',
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'SegmentType': 'DIMENSIONAL'|'IMPORT',
            'tags': {
                'string': 'string'
            },
            'Version': 123
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_segment_versions(ApplicationId=None, PageSize=None, SegmentId=None, Token=None):
    """
    Retrieves information about the configuration, dimension, and other settings for all the versions of a specific segment that\'s associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_segment_versions(
        ApplicationId='string',
        PageSize='string',
        SegmentId='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentsResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'Arn': 'string',
                'CreationDate': 'string',
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'Behavior': {
                        'Recency': {
                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                            'RecencyType': 'ACTIVE'|'INACTIVE'
                        }
                    },
                    'Demographic': {
                        'AppVersion': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Channel': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'DeviceType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Make': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Model': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Platform': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'Location': {
                        'Country': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'GPSPoint': {
                            'Coordinates': {
                                'Latitude': 123.0,
                                'Longitude': 123.0
                            },
                            'RangeInKilometers': 123.0
                        }
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    },
                    'UserAttributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    }
                },
                'Id': 'string',
                'ImportDefinition': {
                    'ChannelCounts': {
                        'string': 123
                    },
                    'ExternalId': 'string',
                    'Format': 'CSV'|'JSON',
                    'RoleArn': 'string',
                    'S3Url': 'string',
                    'Size': 123
                },
                'LastModifiedDate': 'string',
                'Name': 'string',
                'SegmentGroups': {
                    'Groups': [
                        {
                            'Dimensions': [
                                {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                },
                            ],
                            'SourceSegments': [
                                {
                                    'Id': 'string',
                                    'Version': 123
                                },
                            ],
                            'SourceType': 'ALL'|'ANY'|'NONE',
                            'Type': 'ALL'|'ANY'|'NONE'
                        },
                    ],
                    'Include': 'ALL'|'ANY'|'NONE'
                },
                'SegmentType': 'DIMENSIONAL'|'IMPORT',
                'tags': {
                    'string': 'string'
                },
                'Version': 123
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

SegmentsResponse (dict) --
Provides information about all the segments that are associated with an application.

Item (list) --
An array of responses, one for each segment that\'s associated with the application (Segments resource) or each version of a segment that\'s associated with the application (Segment Versions resource).

(dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentsResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_segments(ApplicationId=None, PageSize=None, Token=None):
    """
    Retrieves information about the configuration, dimension, and other settings for all the segments that are associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_segments(
        ApplicationId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentsResponse': {
        'Item': [
            {
                'ApplicationId': 'string',
                'Arn': 'string',
                'CreationDate': 'string',
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'Behavior': {
                        'Recency': {
                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                            'RecencyType': 'ACTIVE'|'INACTIVE'
                        }
                    },
                    'Demographic': {
                        'AppVersion': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Channel': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'DeviceType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Make': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Model': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Platform': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'Location': {
                        'Country': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'GPSPoint': {
                            'Coordinates': {
                                'Latitude': 123.0,
                                'Longitude': 123.0
                            },
                            'RangeInKilometers': 123.0
                        }
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    },
                    'UserAttributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    }
                },
                'Id': 'string',
                'ImportDefinition': {
                    'ChannelCounts': {
                        'string': 123
                    },
                    'ExternalId': 'string',
                    'Format': 'CSV'|'JSON',
                    'RoleArn': 'string',
                    'S3Url': 'string',
                    'Size': 123
                },
                'LastModifiedDate': 'string',
                'Name': 'string',
                'SegmentGroups': {
                    'Groups': [
                        {
                            'Dimensions': [
                                {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                },
                            ],
                            'SourceSegments': [
                                {
                                    'Id': 'string',
                                    'Version': 123
                                },
                            ],
                            'SourceType': 'ALL'|'ANY'|'NONE',
                            'Type': 'ALL'|'ANY'|'NONE'
                        },
                    ],
                    'Include': 'ALL'|'ANY'|'NONE'
                },
                'SegmentType': 'DIMENSIONAL'|'IMPORT',
                'tags': {
                    'string': 'string'
                },
                'Version': 123
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

SegmentsResponse (dict) --
Provides information about all the segments that are associated with an application.

Item (list) --
An array of responses, one for each segment that\'s associated with the application (Segments resource) or each version of a segment that\'s associated with the application (Segment Versions resource).

(dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentsResponse': {
            'Item': [
                {
                    'ApplicationId': 'string',
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Behavior': {
                            'Recency': {
                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                'RecencyType': 'ACTIVE'|'INACTIVE'
                            }
                        },
                        'Demographic': {
                            'AppVersion': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Channel': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'DeviceType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Make': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Model': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Platform': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'Location': {
                            'Country': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'GPSPoint': {
                                'Coordinates': {
                                    'Latitude': 123.0,
                                    'Longitude': 123.0
                                },
                                'RangeInKilometers': 123.0
                            }
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        },
                        'UserAttributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        }
                    },
                    'Id': 'string',
                    'ImportDefinition': {
                        'ChannelCounts': {
                            'string': 123
                        },
                        'ExternalId': 'string',
                        'Format': 'CSV'|'JSON',
                        'RoleArn': 'string',
                        'S3Url': 'string',
                        'Size': 123
                    },
                    'LastModifiedDate': 'string',
                    'Name': 'string',
                    'SegmentGroups': {
                        'Groups': [
                            {
                                'Dimensions': [
                                    {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    },
                                ],
                                'SourceSegments': [
                                    {
                                        'Id': 'string',
                                        'Version': 123
                                    },
                                ],
                                'SourceType': 'ALL'|'ANY'|'NONE',
                                'Type': 'ALL'|'ANY'|'NONE'
                            },
                        ],
                        'Include': 'ALL'|'ANY'|'NONE'
                    },
                    'SegmentType': 'DIMENSIONAL'|'IMPORT',
                    'tags': {
                        'string': 'string'
                    },
                    'Version': 123
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def get_sms_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the SMS channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_sms_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'SMSChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'PromotionalMessagesPerSecond': 123,
        'SenderId': 'string',
        'ShortCode': 'string',
        'TransactionalMessagesPerSecond': 123,
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

SMSChannelResponse (dict) --Provides information about the status and settings of the SMS channel for an application.

ApplicationId (string) --The unique identifier for the application that the SMS channel applies to.

CreationDate (string) --The date and time, in ISO 8601 format, when the SMS channel was enabled.

Enabled (boolean) --Specifies whether the SMS channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the SMS channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the SMS channel is archived.

LastModifiedBy (string) --The user who last modified the SMS channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the SMS channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the SMS channel, this value is SMS.

PromotionalMessagesPerSecond (integer) --The maximum number of promotional messages that you can send through the SMS channel each second.

SenderId (string) --The identity that displays on recipients\' devices when they receive messages from the SMS channel.

ShortCode (string) --The registered short code to use when you send messages through the SMS channel.

TransactionalMessagesPerSecond (integer) --The maximum number of transactional messages that you can send through the SMS channel each second.

Version (integer) --The current version of the SMS channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SMSChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'PromotionalMessagesPerSecond': 123,
            'SenderId': 'string',
            'ShortCode': 'string',
            'TransactionalMessagesPerSecond': 123,
            'Version': 123
        }
    }
    
    
    """
    pass

def get_sms_template(TemplateName=None, Version=None):
    """
    Retrieves the content and settings of a message template for messages that are sent through the SMS channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_sms_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SMSTemplateResponse': {
        'Arn': 'string',
        'Body': 'string',
        'CreationDate': 'string',
        'DefaultSubstitutions': 'string',
        'LastModifiedDate': 'string',
        'RecommenderId': 'string',
        'tags': {
            'string': 'string'
        },
        'TemplateDescription': 'string',
        'TemplateName': 'string',
        'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
        'Version': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

SMSTemplateResponse (dict) --
Provides information about the content and settings for a message template that can be used in text messages that are sent through the SMS channel.

Arn (string) --
The Amazon Resource Name (ARN) of the message template.

Body (string) --
The message body that\'s used in text messages that are based on the message template.

CreationDate (string) --
The date, in ISO 8601 format, when the message template was created.

DefaultSubstitutions (string) --
The JSON object that specifies the default values that are used for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the message template was last modified.

RecommenderId (string) --
The unique identifier for the recommender model that\'s used by the message template.

tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the message template. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateDescription (string) --
The custom description of the message template.

TemplateName (string) --
The name of the message template.

TemplateType (string) --
The type of channel that the message template is designed for. For an SMS template, this value is SMS.

Version (string) --
The unique identifier, as an integer, for the active version of the message template, or the version of the template that you specified by using the version parameter in your request.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SMSTemplateResponse': {
            'Arn': 'string',
            'Body': 'string',
            'CreationDate': 'string',
            'DefaultSubstitutions': 'string',
            'LastModifiedDate': 'string',
            'RecommenderId': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'TemplateName': 'string',
            'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
            'Version': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_user_endpoints(ApplicationId=None, UserId=None):
    """
    Retrieves information about all the endpoints that are associated with a specific user ID.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_user_endpoints(
        ApplicationId='string',
        UserId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type UserId: string
    :param UserId: [REQUIRED]\nThe unique identifier for the user.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EndpointsResponse': {
        'Item': [
            {
                'Address': 'string',
                'ApplicationId': 'string',
                'Attributes': {
                    'string': [
                        'string',
                    ]
                },
                'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                'CohortId': 'string',
                'CreationDate': 'string',
                'Demographic': {
                    'AppVersion': 'string',
                    'Locale': 'string',
                    'Make': 'string',
                    'Model': 'string',
                    'ModelVersion': 'string',
                    'Platform': 'string',
                    'PlatformVersion': 'string',
                    'Timezone': 'string'
                },
                'EffectiveDate': 'string',
                'EndpointStatus': 'string',
                'Id': 'string',
                'Location': {
                    'City': 'string',
                    'Country': 'string',
                    'Latitude': 123.0,
                    'Longitude': 123.0,
                    'PostalCode': 'string',
                    'Region': 'string'
                },
                'Metrics': {
                    'string': 123.0
                },
                'OptOut': 'string',
                'RequestId': 'string',
                'User': {
                    'UserAttributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'UserId': 'string'
                }
            },
        ]
    }
}


Response Structure

(dict) --
The request succeeded.

EndpointsResponse (dict) --
Provides information about all the endpoints that are associated with a user ID.

Item (list) --
An array of responses, one for each endpoint that\'s associated with the user ID.

(dict) --
Provides information about the channel type and other settings for an endpoint.

Address (string) --
The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For example, the address for a push-notification channel is typically the token provided by a push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. The address for the SMS channel is a phone number in E.164 format, such as +12065550100. The address for the email channel is an email address.

ApplicationId (string) --
The unique identifier for the application that\'s associated with the endpoint.

Attributes (dict) --
One or more custom attributes that describe the endpoint by associating a name with an array of values. For example, the value of a custom attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments.

(string) --
(list) --
(string) --






ChannelType (string) --
The channel that\'s used when sending messages or push notifications to the endpoint.

CohortId (string) --
A number from 0-99 that represents the cohort that the endpoint is assigned to. Endpoints are grouped into cohorts randomly, and each cohort contains approximately 1 percent of the endpoints for an application. Amazon Pinpoint assigns cohorts to the holdout or treatment allocations for campaigns.

CreationDate (string) --
The date and time, in ISO 8601 format, when the endpoint was created.

Demographic (dict) --
The demographic information for the endpoint, such as the time zone and platform.

AppVersion (string) --
The version of the app that\'s associated with the endpoint.

Locale (string) --
The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.

Make (string) --
The manufacturer of the endpoint device, such as apple or samsung.

Model (string) --
The model name or number of the endpoint device, such as iPhone or SM-G900F.

ModelVersion (string) --
The model version of the endpoint device.

Platform (string) --
The platform of the endpoint device, such as ios.

PlatformVersion (string) --
The platform version of the endpoint device.

Timezone (string) --
The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.



EffectiveDate (string) --
The date and time, in ISO 8601 format, when the endpoint was last updated.

EndpointStatus (string) --
Specifies whether messages or push notifications are sent to the endpoint. Possible values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.
Amazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.

Id (string) --
The unique identifier that you assigned to the endpoint. The identifier should be a globally unique identifier (GUID) to ensure that it doesn\'t conflict with other endpoint identifiers that are associated with the application.

Location (dict) --
The geographic information for the endpoint.

City (string) --
The name of the city where the endpoint is located.

Country (string) --
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.

Latitude (float) --
The latitude coordinate of the endpoint location, rounded to one decimal place.

Longitude (float) --
The longitude coordinate of the endpoint location, rounded to one decimal place.

PostalCode (string) --
The postal or ZIP code for the area where the endpoint is located.

Region (string) --
The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.



Metrics (dict) --
One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.

(string) --
(float) --




OptOut (string) --
Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.

RequestId (string) --
The unique identifier for the most recent request to update the endpoint.

User (dict) --
One or more custom user attributes that your app reports to Amazon Pinpoint for the user who\'s associated with the endpoint.

UserAttributes (dict) --
One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ["Science", "Music", "Travel"]. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.
An attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.

(string) --
(list) --
(string) --






UserId (string) --
The unique identifier for the user.















Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EndpointsResponse': {
            'Item': [
                {
                    'Address': 'string',
                    'ApplicationId': 'string',
                    'Attributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    'CohortId': 'string',
                    'CreationDate': 'string',
                    'Demographic': {
                        'AppVersion': 'string',
                        'Locale': 'string',
                        'Make': 'string',
                        'Model': 'string',
                        'ModelVersion': 'string',
                        'Platform': 'string',
                        'PlatformVersion': 'string',
                        'Timezone': 'string'
                    },
                    'EffectiveDate': 'string',
                    'EndpointStatus': 'string',
                    'Id': 'string',
                    'Location': {
                        'City': 'string',
                        'Country': 'string',
                        'Latitude': 123.0,
                        'Longitude': 123.0,
                        'PostalCode': 'string',
                        'Region': 'string'
                    },
                    'Metrics': {
                        'string': 123.0
                    },
                    'OptOut': 'string',
                    'RequestId': 'string',
                    'User': {
                        'UserAttributes': {
                            'string': [
                                'string',
                            ]
                        },
                        'UserId': 'string'
                    }
                },
            ]
        }
    }
    
    
    :returns: 
    (string) --
    (list) --
    (string) --
    
    
    
    
    
    """
    pass

def get_voice_channel(ApplicationId=None):
    """
    Retrieves information about the status and settings of the voice channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_voice_channel(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict
ReturnsResponse Syntax{
    'VoiceChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --The request succeeded.

VoiceChannelResponse (dict) --Provides information about the status and settings of the voice channel for an application.

ApplicationId (string) --The unique identifier for the application that the voice channel applies to.

CreationDate (string) --The date and time, in ISO 8601 format, when the voice channel was enabled.

Enabled (boolean) --Specifies whether the voice channel is enabled for the application.

HasCredential (boolean) --(Not used) This property is retained only for backward compatibility.

Id (string) --(Deprecated) An identifier for the voice channel. This property is retained only for backward compatibility.

IsArchived (boolean) --Specifies whether the voice channel is archived.

LastModifiedBy (string) --The user who last modified the voice channel.

LastModifiedDate (string) --The date and time, in ISO 8601 format, when the voice channel was last modified.

Platform (string) --The type of messaging or notification platform for the channel. For the voice channel, this value is VOICE.

Version (integer) --The current version of the voice channel.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'VoiceChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    """
    pass

def get_voice_template(TemplateName=None, Version=None):
    """
    Retrieves the content and settings of a message template for messages that are sent through the voice channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_voice_template(
        TemplateName='string',
        Version='string'
    )
    
    
    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'VoiceTemplateResponse': {
        'Arn': 'string',
        'Body': 'string',
        'CreationDate': 'string',
        'DefaultSubstitutions': 'string',
        'LanguageCode': 'string',
        'LastModifiedDate': 'string',
        'tags': {
            'string': 'string'
        },
        'TemplateDescription': 'string',
        'TemplateName': 'string',
        'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
        'Version': 'string',
        'VoiceId': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

VoiceTemplateResponse (dict) --
Provides information about the content and settings for a message template that can be used in messages that are sent through the voice channel.

Arn (string) --
The Amazon Resource Name (ARN) of the message template.

Body (string) --
The text of the script that\'s used in messages that are based on the message template, in plain text format.

CreationDate (string) --
The date, in ISO 8601 format, when the message template was created.

DefaultSubstitutions (string) --
The JSON object that specifies the default values that are used for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable.

LanguageCode (string) --
The code for the language that\'s used when synthesizing the text of the script in messages that are based on the message template. For a list of supported languages and the code for each one, see the Amazon Polly Developer Guide .

LastModifiedDate (string) --
The date, in ISO 8601 format, when the message template was last modified.

tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the message template. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateDescription (string) --
The custom description of the message template.

TemplateName (string) --
The name of the message template.

TemplateType (string) --
The type of channel that the message template is designed for. For a voice template, this value is VOICE.

Version (string) --
The unique identifier, as an integer, for the active version of the message template, or the version of the template that you specified by using the version parameter in your request.

VoiceId (string) --
The name of the voice that\'s used when delivering messages that are based on the message template. For a list of supported voices, see the Amazon Polly Developer Guide .









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'VoiceTemplateResponse': {
            'Arn': 'string',
            'Body': 'string',
            'CreationDate': 'string',
            'DefaultSubstitutions': 'string',
            'LanguageCode': 'string',
            'LastModifiedDate': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'TemplateName': 'string',
            'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
            'Version': 'string',
            'VoiceId': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_journeys(ApplicationId=None, PageSize=None, Token=None):
    """
    Retrieves information about the status, configuration, and other settings for all the journeys that are associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_journeys(
        ApplicationId='string',
        PageSize='string',
        Token='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Token: string
    :param Token: The NextToken string that specifies which page of results to return in a paginated response.

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneysResponse': {
        'Item': [
            {
                'Activities': {
                    'string': {
                        'ConditionalSplit': {
                            'Condition': {
                                'Conditions': [
                                    {
                                        'EventCondition': {
                                            'Dimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'EventType': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                }
                                            },
                                            'MessageActivity': 'string'
                                        },
                                        'SegmentCondition': {
                                            'SegmentId': 'string'
                                        },
                                        'SegmentDimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'Behavior': {
                                                'Recency': {
                                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                                }
                                            },
                                            'Demographic': {
                                                'AppVersion': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Channel': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'DeviceType': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Make': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Model': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Platform': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'Location': {
                                                'Country': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'GPSPoint': {
                                                    'Coordinates': {
                                                        'Latitude': 123.0,
                                                        'Longitude': 123.0
                                                    },
                                                    'RangeInKilometers': 123.0
                                                }
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            },
                                            'UserAttributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            }
                                        }
                                    },
                                ],
                                'Operator': 'ALL'|'ANY'
                            },
                            'EvaluationWaitTime': {
                                'WaitFor': 'string',
                                'WaitUntil': 'string'
                            },
                            'FalseActivity': 'string',
                            'TrueActivity': 'string'
                        },
                        'Description': 'string',
                        'EMAIL': {
                            'MessageConfig': {
                                'FromAddress': 'string'
                            },
                            'NextActivity': 'string',
                            'TemplateName': 'string',
                            'TemplateVersion': 'string'
                        },
                        'Holdout': {
                            'NextActivity': 'string',
                            'Percentage': 123
                        },
                        'MultiCondition': {
                            'Branches': [
                                {
                                    'Condition': {
                                        'EventCondition': {
                                            'Dimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'EventType': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                }
                                            },
                                            'MessageActivity': 'string'
                                        },
                                        'SegmentCondition': {
                                            'SegmentId': 'string'
                                        },
                                        'SegmentDimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'Behavior': {
                                                'Recency': {
                                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                                }
                                            },
                                            'Demographic': {
                                                'AppVersion': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Channel': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'DeviceType': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Make': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Model': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'Platform': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'Location': {
                                                'Country': {
                                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                },
                                                'GPSPoint': {
                                                    'Coordinates': {
                                                        'Latitude': 123.0,
                                                        'Longitude': 123.0
                                                    },
                                                    'RangeInKilometers': 123.0
                                                }
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            },
                                            'UserAttributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            }
                                        }
                                    },
                                    'NextActivity': 'string'
                                },
                            ],
                            'DefaultActivity': 'string',
                            'EvaluationWaitTime': {
                                'WaitFor': 'string',
                                'WaitUntil': 'string'
                            }
                        },
                        'RandomSplit': {
                            'Branches': [
                                {
                                    'NextActivity': 'string',
                                    'Percentage': 123
                                },
                            ]
                        },
                        'Wait': {
                            'NextActivity': 'string',
                            'WaitTime': {
                                'WaitFor': 'string',
                                'WaitUntil': 'string'
                            }
                        }
                    }
                },
                'ApplicationId': 'string',
                'CreationDate': 'string',
                'Id': 'string',
                'LastModifiedDate': 'string',
                'Limits': {
                    'DailyCap': 123,
                    'EndpointReentryCap': 123,
                    'MessagesPerSecond': 123
                },
                'LocalTime': True|False,
                'Name': 'string',
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'RefreshFrequency': 'string',
                'Schedule': {
                    'EndTime': datetime(2015, 1, 1),
                    'StartTime': datetime(2015, 1, 1),
                    'Timezone': 'string'
                },
                'StartActivity': 'string',
                'StartCondition': {
                    'Description': 'string',
                    'SegmentStartCondition': {
                        'SegmentId': 'string'
                    }
                },
                'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                'tags': {
                    'string': 'string'
                }
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

JourneysResponse (dict) --
Provides information about the status, configuration, and other settings for all the journeys that are associated with an application.

Item (list) --
An array of responses, one for each journey that\'s associated with the application.

(dict) --
Provides information about the status, configuration, and other settings for a journey.

Activities (dict) --
A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity.

(string) --

(dict) --
Specifies the configuration and other settings for an activity in a journey.

ConditionalSplit (dict) --
The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.

Condition (dict) --
The conditions that define the paths for the activity, and the relationship between the conditions.

Conditions (list) --
The conditions to evaluate for the activity.

(dict) --
Specifies a condition to evaluate for an activity in a journey.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --














Operator (string) --
Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.



EvaluationWaitTime (dict) --
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.



FalseActivity (string) --
The unique identifier for the activity to perform if the conditions aren\'t met.

TrueActivity (string) --
The unique identifier for the activity to perform if the conditions are met.



Description (string) --
The custom description of the activity.

EMAIL (dict) --
The settings for an email activity. This type of activity sends an email message to participants.

MessageConfig (dict) --
The "From" address to use for the message.

FromAddress (string) --
The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.



NextActivity (string) --
The unique identifier for the next activity to perform, after the message is sent.

TemplateName (string) --
The name of the email template to use for the message.

TemplateVersion (string) --
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



Holdout (dict) --
The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the holdout activity.

Percentage (integer) --
The percentage of participants who shouldn\'t continue the journey.
To determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.



MultiCondition (dict) --
The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.

(dict) --
Specifies a condition to evaluate for an activity path in a journey.

Condition (dict) --
The condition to evaluate for the activity path.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.





DefaultActivity (string) --
The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.

EvaluationWaitTime (dict) --
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.





RandomSplit (dict) --
The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.

(dict) --
Specifies the settings for a path in a random split activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.

Percentage (integer) --
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.







Wait (dict) --
The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the wait activity.

WaitTime (dict) --
The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.











ApplicationId (string) --
The unique identifier for the application that the journey applies to.

CreationDate (string) --
The date, in ISO 8601 format, when the journey was created.

Id (string) --
The unique identifier for the journey.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the journey was last modified.

Limits (dict) --
The messaging and entry limits for the journey.

DailyCap (integer) --
The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.

EndpointReentryCap (integer) --
The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.

MessagesPerSecond (integer) --
The maximum number of messages that the journey can send each second.



LocalTime (boolean) --
Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. If this value is true, the schedule uses each participant\'s local time.

Name (string) --
The name of the journey.

QuietTime (dict) --
The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.
The current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.
The current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.

If any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



RefreshFrequency (string) --
The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.

Schedule (dict) --
The schedule settings for the journey.

EndTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey ended or will end.

StartTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey began or will begin.

Timezone (string) --
The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.



StartActivity (string) --
The unique identifier for the first activity in the journey.

StartCondition (dict) --
The segment that defines which users are participants in the journey.

Description (string) --
The custom description of the condition.

SegmentStartCondition (dict) --
The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.





State (string) --
The current status of the journey. Possible values are:

DRAFT - The journey is being developed and hasn\'t been published yet.
ACTIVE - The journey has been developed and published. Depending on the journey\'s schedule, the journey may currently be running or scheduled to start running at a later time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.
COMPLETED - The journey has been published and has finished running. All participants have entered the journey and no participants are waiting to complete the journey or any activities in the journey.
CANCELLED - The journey has been stopped. If a journey\'s status is CANCELLED, you can\'t add, change, or remove activities or segment settings from the journey.
CLOSED - The journey has been published and has started running. It may have also passed its scheduled end time, or passed its scheduled start time and a refresh frequency hasn\'t been specified for it. If a journey\'s status is CLOSED, you can\'t add participants to it, and no existing participants can enter the journey for the first time. However, any existing participants who are currently waiting to start an activity may continue the journey.


tags (dict) --
This object is not used or supported.

(string) --
(string) --








NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneysResponse': {
            'Item': [
                {
                    'Activities': {
                        'string': {
                            'ConditionalSplit': {
                                'Condition': {
                                    'Conditions': [
                                        {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                    'Operator': 'ALL'|'ANY'
                                },
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                },
                                'FalseActivity': 'string',
                                'TrueActivity': 'string'
                            },
                            'Description': 'string',
                            'EMAIL': {
                                'MessageConfig': {
                                    'FromAddress': 'string'
                                },
                                'NextActivity': 'string',
                                'TemplateName': 'string',
                                'TemplateVersion': 'string'
                            },
                            'Holdout': {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                            'MultiCondition': {
                                'Branches': [
                                    {
                                        'Condition': {
                                            'EventCondition': {
                                                'Dimensions': {
                                                    'Attributes': {
                                                        'string': {
                                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                            'Values': [
                                                                'string',
                                                            ]
                                                        }
                                                    },
                                                    'EventType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Metrics': {
                                                        'string': {
                                                            'ComparisonOperator': 'string',
                                                            'Value': 123.0
                                                        }
                                                    }
                                                },
                                                'MessageActivity': 'string'
                                            },
                                            'SegmentCondition': {
                                                'SegmentId': 'string'
                                            },
                                            'SegmentDimensions': {
                                                'Attributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Behavior': {
                                                    'Recency': {
                                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                                    }
                                                },
                                                'Demographic': {
                                                    'AppVersion': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Channel': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'DeviceType': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Make': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Model': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'Platform': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                },
                                                'Location': {
                                                    'Country': {
                                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    },
                                                    'GPSPoint': {
                                                        'Coordinates': {
                                                            'Latitude': 123.0,
                                                            'Longitude': 123.0
                                                        },
                                                        'RangeInKilometers': 123.0
                                                    }
                                                },
                                                'Metrics': {
                                                    'string': {
                                                        'ComparisonOperator': 'string',
                                                        'Value': 123.0
                                                    }
                                                },
                                                'UserAttributes': {
                                                    'string': {
                                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                        'Values': [
                                                            'string',
                                                        ]
                                                    }
                                                }
                                            }
                                        },
                                        'NextActivity': 'string'
                                    },
                                ],
                                'DefaultActivity': 'string',
                                'EvaluationWaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            },
                            'RandomSplit': {
                                'Branches': [
                                    {
                                        'NextActivity': 'string',
                                        'Percentage': 123
                                    },
                                ]
                            },
                            'Wait': {
                                'NextActivity': 'string',
                                'WaitTime': {
                                    'WaitFor': 'string',
                                    'WaitUntil': 'string'
                                }
                            }
                        }
                    },
                    'ApplicationId': 'string',
                    'CreationDate': 'string',
                    'Id': 'string',
                    'LastModifiedDate': 'string',
                    'Limits': {
                        'DailyCap': 123,
                        'EndpointReentryCap': 123,
                        'MessagesPerSecond': 123
                    },
                    'LocalTime': True|False,
                    'Name': 'string',
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'RefreshFrequency': 'string',
                    'Schedule': {
                        'EndTime': datetime(2015, 1, 1),
                        'StartTime': datetime(2015, 1, 1),
                        'Timezone': 'string'
                    },
                    'StartActivity': 'string',
                    'StartCondition': {
                        'Description': 'string',
                        'SegmentStartCondition': {
                            'SegmentId': 'string'
                        }
                    },
                    'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
                    'tags': {
                        'string': 'string'
                    }
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_tags_for_resource(ResourceArn=None):
    """
    Retrieves all the tags (keys and values) that are associated with an application, campaign, message template, or segment.
    See also: AWS API Documentation
    
    
    :example: response = client.list_tags_for_resource(
        ResourceArn='string'
    )
    
    
    :type ResourceArn: string
    :param ResourceArn: [REQUIRED]\nThe Amazon Resource Name (ARN) of the resource.\n

    :rtype: dict
ReturnsResponse Syntax{
    'TagsModel': {
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --The request succeeded.

TagsModel (dict) --Specifies the tags (keys and values) for an application, campaign, message template, or segment.

tags (dict) --A string-to-string map of key-value pairs that defines the tags for an application, campaign, message template, or segment. Each of these resources can have a maximum of 50 tags.
Each tag consists of a required tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.

(string) --
(string) --












    :return: {
        'TagsModel': {
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    """
    pass

def list_template_versions(NextToken=None, PageSize=None, TemplateName=None, TemplateType=None):
    """
    Retrieves information about all the versions of a specific message template.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_template_versions(
        NextToken='string',
        PageSize='string',
        TemplateName='string',
        TemplateType='string'
    )
    
    
    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type TemplateType: string
    :param TemplateType: [REQUIRED]\nThe type of channel that the message template is designed for. Valid values are: EMAIL, PUSH, SMS, and VOICE.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'TemplateVersionsResponse': {
        'Item': [
            {
                'CreationDate': 'string',
                'DefaultSubstitutions': 'string',
                'LastModifiedDate': 'string',
                'TemplateDescription': 'string',
                'TemplateName': 'string',
                'TemplateType': 'string',
                'Version': 'string'
            },
        ],
        'Message': 'string',
        'NextToken': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

TemplateVersionsResponse (dict) --
Provides information about all the versions of a specific message template.

Item (list) --
An array of responses, one for each version of the message template.

(dict) --
Provides information about a specific version of a message template.

CreationDate (string) --
The date, in ISO 8601 format, when the version of the message template was created.

DefaultSubstitutions (string) --
A JSON object that specifies the default values that are used for message variables in the version of the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the version of the message template was last modified.

TemplateDescription (string) --
The custom description of the version of the message template.

TemplateName (string) --
The name of the message template.

TemplateType (string) --
The type of channel that the message template is designed for. Possible values are: EMAIL, PUSH, SMS, and VOICE.

Version (string) --
The unique identifier for the version of the message template. This value is an integer that Amazon Pinpoint automatically increments and assigns to each new version of a template.





Message (string) --
The message that\'s returned from the API for the request to retrieve information about all the versions of the message template.

NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.

RequestID (string) --
The unique identifier for the request to retrieve information about all the versions of the message template.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'TemplateVersionsResponse': {
            'Item': [
                {
                    'CreationDate': 'string',
                    'DefaultSubstitutions': 'string',
                    'LastModifiedDate': 'string',
                    'TemplateDescription': 'string',
                    'TemplateName': 'string',
                    'TemplateType': 'string',
                    'Version': 'string'
                },
            ],
            'Message': 'string',
            'NextToken': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def list_templates(NextToken=None, PageSize=None, Prefix=None, TemplateType=None):
    """
    Retrieves information about all the message templates that are associated with your Amazon Pinpoint account.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_templates(
        NextToken='string',
        PageSize='string',
        Prefix='string',
        TemplateType='string'
    )
    
    
    :type NextToken: string
    :param NextToken: The string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type PageSize: string
    :param PageSize: The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.

    :type Prefix: string
    :param Prefix: The substring to match in the names of the message templates to include in the results. If you specify this value, Amazon Pinpoint returns only those templates whose names begin with the value that you specify.

    :type TemplateType: string
    :param TemplateType: The type of message template to include in the results. Valid values are: EMAIL, PUSH, SMS, and VOICE. To include all types of templates in the results, don\'t include this parameter in your request.

    :rtype: dict

ReturnsResponse Syntax
{
    'TemplatesResponse': {
        'Item': [
            {
                'Arn': 'string',
                'CreationDate': 'string',
                'DefaultSubstitutions': 'string',
                'LastModifiedDate': 'string',
                'tags': {
                    'string': 'string'
                },
                'TemplateDescription': 'string',
                'TemplateName': 'string',
                'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
                'Version': 'string'
            },
        ],
        'NextToken': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

TemplatesResponse (dict) --
Provides information about all the message templates that are associated with your Amazon Pinpoint account.

Item (list) --
An array of responses, one for each message template that\'s associated with your Amazon Pinpoint account and meets any filter criteria that you specified in the request.

(dict) --
Provides information about a message template that\'s associated with your Amazon Pinpoint account.

Arn (string) --
The Amazon Resource Name (ARN) of the message template. This value isn\'t included in a TemplateResponse object. To retrieve the ARN of a template, use the GetEmailTemplate, GetPushTemplate, GetSmsTemplate, or GetVoiceTemplate operation, depending on the type of template that you want to retrieve the ARN for.

CreationDate (string) --
The date, in ISO 8601 format, when the message template was created.

DefaultSubstitutions (string) --
The JSON object that specifies the default values that are used for message variables in the message template. This object isn\'t included in a TemplateResponse object. To retrieve this object for a template, use the GetEmailTemplate, GetPushTemplate, GetSmsTemplate, or GetVoiceTemplate operation, depending on the type of template that you want to retrieve the object for.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the message template was last modified.

tags (dict) --
A map of key-value pairs that identifies the tags that are associated with the message template. This object isn\'t included in a TemplateResponse object. To retrieve this object for a template, use the GetEmailTemplate, GetPushTemplate, GetSmsTemplate, or GetVoiceTemplate operation, depending on the type of template that you want to retrieve the object for.

(string) --
(string) --




TemplateDescription (string) --
The custom description of the message template. This value isn\'t included in a TemplateResponse object. To retrieve the description of a template, use the GetEmailTemplate, GetPushTemplate, GetSmsTemplate, or GetVoiceTemplate operation, depending on the type of template that you want to retrieve the description for.

TemplateName (string) --
The name of the message template.

TemplateType (string) --
The type of channel that the message template is designed for. Possible values are: EMAIL, PUSH, SMS, and VOICE.

Version (string) --
The unique identifier, as an integer, for the active version of the message template.





NextToken (string) --
The string to use in a subsequent request to get the next page of results in a paginated response. This value is null if there are no additional pages.









Exceptions

Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException
Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.ForbiddenException


    :return: {
        'TemplatesResponse': {
            'Item': [
                {
                    'Arn': 'string',
                    'CreationDate': 'string',
                    'DefaultSubstitutions': 'string',
                    'LastModifiedDate': 'string',
                    'tags': {
                        'string': 'string'
                    },
                    'TemplateDescription': 'string',
                    'TemplateName': 'string',
                    'TemplateType': 'EMAIL'|'SMS'|'VOICE'|'PUSH',
                    'Version': 'string'
                },
            ],
            'NextToken': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def phone_number_validate(NumberValidateRequest=None):
    """
    Retrieves information about a phone number.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.phone_number_validate(
        NumberValidateRequest={
            'IsoCountryCode': 'string',
            'PhoneNumber': 'string'
        }
    )
    
    
    :type NumberValidateRequest: dict
    :param NumberValidateRequest: [REQUIRED]\nSpecifies a phone number to validate and retrieve information about.\n\nIsoCountryCode (string) --The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the phone number was originally registered.\n\nPhoneNumber (string) --The phone number to retrieve information about. The phone number that you provide should include a valid numeric country code. Otherwise, the operation might result in an error.\n\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'NumberValidateResponse': {
        'Carrier': 'string',
        'City': 'string',
        'CleansedPhoneNumberE164': 'string',
        'CleansedPhoneNumberNational': 'string',
        'Country': 'string',
        'CountryCodeIso2': 'string',
        'CountryCodeNumeric': 'string',
        'County': 'string',
        'OriginalCountryCodeIso2': 'string',
        'OriginalPhoneNumber': 'string',
        'PhoneType': 'string',
        'PhoneTypeCode': 123,
        'Timezone': 'string',
        'ZipCode': 'string'
    }
}


Response Structure

(dict) --The request succeeded.

NumberValidateResponse (dict) --Provides information about a phone number.

Carrier (string) --The carrier or service provider that the phone number is currently registered with. In some countries and regions, this value may be the carrier or service provider that the phone number was originally registered with.

City (string) --The name of the city where the phone number was originally registered.

CleansedPhoneNumberE164 (string) --The cleansed phone number, in E.164 format, for the location where the phone number was originally registered.

CleansedPhoneNumberNational (string) --The cleansed phone number, in the format for the location where the phone number was originally registered.

Country (string) --The name of the country or region where the phone number was originally registered.

CountryCodeIso2 (string) --The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the phone number was originally registered.

CountryCodeNumeric (string) --The numeric code for the country or region where the phone number was originally registered.

County (string) --The name of the county where the phone number was originally registered.

OriginalCountryCodeIso2 (string) --The two-character code, in ISO 3166-1 alpha-2 format, that was sent in the request body.

OriginalPhoneNumber (string) --The phone number that was sent in the request body.

PhoneType (string) --The description of the phone type. Valid values are: MOBILE, LANDLINE, VOIP, INVALID, PREPAID, and OTHER.

PhoneTypeCode (integer) --The phone type, represented by an integer. Valid values are: 0 (mobile), 1 (landline), 2 (VoIP), 3 (invalid), 4 (other), and 5 (prepaid).

Timezone (string) --The time zone for the location where the phone number was originally registered.

ZipCode (string) --The postal or ZIP code for the location where the phone number was originally registered.








Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'NumberValidateResponse': {
            'Carrier': 'string',
            'City': 'string',
            'CleansedPhoneNumberE164': 'string',
            'CleansedPhoneNumberNational': 'string',
            'Country': 'string',
            'CountryCodeIso2': 'string',
            'CountryCodeNumeric': 'string',
            'County': 'string',
            'OriginalCountryCodeIso2': 'string',
            'OriginalPhoneNumber': 'string',
            'PhoneType': 'string',
            'PhoneTypeCode': 123,
            'Timezone': 'string',
            'ZipCode': 'string'
        }
    }
    
    
    """
    pass

def put_event_stream(ApplicationId=None, WriteEventStream=None):
    """
    Creates a new event stream for an application or updates the settings of an existing event stream for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.put_event_stream(
        ApplicationId='string',
        WriteEventStream={
            'DestinationStreamArn': 'string',
            'RoleArn': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type WriteEventStream: dict
    :param WriteEventStream: [REQUIRED]\nSpecifies the Amazon Resource Name (ARN) of an event stream to publish events to and the AWS Identity and Access Management (IAM) role to use when publishing those events.\n\nDestinationStreamArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data Firehose delivery stream that you want to publish event data to.\nFor a Kinesis data stream, the ARN format is: arn:aws:kinesis:region:account-id:stream/stream_name\nFor a Kinesis Data Firehose delivery stream, the ARN format is: arn:aws:firehose:region:account-id:deliverystream/stream_name\n\nRoleArn (string) -- [REQUIRED]The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to publish event data to the stream in your AWS account.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EventStream': {
        'ApplicationId': 'string',
        'DestinationStreamArn': 'string',
        'ExternalId': 'string',
        'LastModifiedDate': 'string',
        'LastUpdatedBy': 'string',
        'RoleArn': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

EventStream (dict) --
Specifies settings for publishing event data to an Amazon Kinesis data stream or an Amazon Kinesis Data Firehose delivery stream.

ApplicationId (string) --
The unique identifier for the application to publish event data for.

DestinationStreamArn (string) --
The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data Firehose delivery stream to publish event data to.
For a Kinesis data stream, the ARN format is: arn:aws:kinesis:region:account-id:stream/stream_name
For a Kinesis Data Firehose delivery stream, the ARN format is: arn:aws:firehose:region:account-id:deliverystream/stream_name

ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when publishing event data, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the event stream was last modified.

LastUpdatedBy (string) --
The IAM user who last modified the event stream.

RoleArn (string) --
The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to publish event data to the stream in your AWS account.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EventStream': {
            'ApplicationId': 'string',
            'DestinationStreamArn': 'string',
            'ExternalId': 'string',
            'LastModifiedDate': 'string',
            'LastUpdatedBy': 'string',
            'RoleArn': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def put_events(ApplicationId=None, EventsRequest=None):
    """
    Creates a new event to record for endpoints, or creates or updates endpoint data that existing events are associated with.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.put_events(
        ApplicationId='string',
        EventsRequest={
            'BatchItem': {
                'string': {
                    'Endpoint': {
                        'Address': 'string',
                        'Attributes': {
                            'string': [
                                'string',
                            ]
                        },
                        'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        'Demographic': {
                            'AppVersion': 'string',
                            'Locale': 'string',
                            'Make': 'string',
                            'Model': 'string',
                            'ModelVersion': 'string',
                            'Platform': 'string',
                            'PlatformVersion': 'string',
                            'Timezone': 'string'
                        },
                        'EffectiveDate': 'string',
                        'EndpointStatus': 'string',
                        'Location': {
                            'City': 'string',
                            'Country': 'string',
                            'Latitude': 123.0,
                            'Longitude': 123.0,
                            'PostalCode': 'string',
                            'Region': 'string'
                        },
                        'Metrics': {
                            'string': 123.0
                        },
                        'OptOut': 'string',
                        'RequestId': 'string',
                        'User': {
                            'UserAttributes': {
                                'string': [
                                    'string',
                                ]
                            },
                            'UserId': 'string'
                        }
                    },
                    'Events': {
                        'string': {
                            'AppPackageName': 'string',
                            'AppTitle': 'string',
                            'AppVersionCode': 'string',
                            'Attributes': {
                                'string': 'string'
                            },
                            'ClientSdkVersion': 'string',
                            'EventType': 'string',
                            'Metrics': {
                                'string': 123.0
                            },
                            'SdkName': 'string',
                            'Session': {
                                'Duration': 123,
                                'Id': 'string',
                                'StartTimestamp': 'string',
                                'StopTimestamp': 'string'
                            },
                            'Timestamp': 'string'
                        }
                    }
                }
            }
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EventsRequest: dict
    :param EventsRequest: [REQUIRED]\nSpecifies a batch of events to process.\n\nBatchItem (dict) -- [REQUIRED]The batch of events to process. For each item in a batch, the endpoint ID acts as a key that has an EventsBatch object as its value.\n\n(string) --\n(dict) --Specifies a batch of endpoints and events to process.\n\nEndpoint (dict) -- [REQUIRED]A set of properties and attributes that are associated with the endpoint.\n\nAddress (string) --The unique identifier for the recipient, such as a device token, email address, or mobile phone number.\n\nAttributes (dict) --One or more custom attributes that describe the endpoint by associating a name with an array of values. You can use these attributes as filter criteria when you create segments.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nChannelType (string) --The channel that\'s used when sending messages or push notifications to the endpoint.\n\nDemographic (dict) --The demographic information for the endpoint, such as the time zone and platform.\n\nAppVersion (string) --The version of the app that\'s associated with the endpoint.\n\nLocale (string) --The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.\n\nMake (string) --The manufacturer of the endpoint device, such as apple or samsung.\n\nModel (string) --The model name or number of the endpoint device, such as iPhone or SM-G900F.\n\nModelVersion (string) --The model version of the endpoint device.\n\nPlatform (string) --The platform of the endpoint device, such as ios.\n\nPlatformVersion (string) --The platform version of the endpoint device.\n\nTimezone (string) --The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.\n\n\n\nEffectiveDate (string) --The date and time, in ISO 8601 format, when the endpoint was last updated.\n\nEndpointStatus (string) --Specifies whether to send messages or push notifications to the endpoint. Valid values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.\nAmazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.\n\nLocation (dict) --The geographic information for the endpoint.\n\nCity (string) --The name of the city where the endpoint is located.\n\nCountry (string) --The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.\n\nLatitude (float) --The latitude coordinate of the endpoint location, rounded to one decimal place.\n\nLongitude (float) --The longitude coordinate of the endpoint location, rounded to one decimal place.\n\nPostalCode (string) --The postal or ZIP code for the area where the endpoint is located.\n\nRegion (string) --The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.\n\n\n\nMetrics (dict) --One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.\n\n(string) --\n(float) --\n\n\n\n\nOptOut (string) --Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.\n\nRequestId (string) --A unique identifier that\'s generated each time the endpoint is updated.\n\nUser (dict) --One or more custom user attributes that your app reports to Amazon Pinpoint for the user who\'s associated with the endpoint.\n\nUserAttributes (dict) --One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ['Science', 'Music', 'Travel']. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.\nAn attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nUserId (string) --The unique identifier for the user.\n\n\n\n\n\nEvents (dict) -- [REQUIRED]A set of properties that are associated with the event.\n\n(string) --\n(dict) --Specifies information about an event that reports data to Amazon Pinpoint.\n\nAppPackageName (string) --The package name of the app that\'s recording the event.\n\nAppTitle (string) --The title of the app that\'s recording the event.\n\nAppVersionCode (string) --The version number of the app that\'s recording the event.\n\nAttributes (dict) --One or more custom attributes that are associated with the event.\n\n(string) --\n(string) --\n\n\n\n\nClientSdkVersion (string) --The version of the SDK that\'s running on the client device.\n\nEventType (string) -- [REQUIRED]The name of the event.\n\nMetrics (dict) --One or more custom metrics that are associated with the event.\n\n(string) --\n(float) --\n\n\n\n\nSdkName (string) --The name of the SDK that\'s being used to record the event.\n\nSession (dict) --Information about the session in which the event occurred.\n\nDuration (integer) --The duration of the session, in milliseconds.\n\nId (string) -- [REQUIRED]The unique identifier for the session.\n\nStartTimestamp (string) -- [REQUIRED]The date and time when the session began.\n\nStopTimestamp (string) --The date and time when the session ended.\n\n\n\nTimestamp (string) -- [REQUIRED]The date and time, in ISO 8601 format, when the event occurred.\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EventsResponse': {
        'Results': {
            'string': {
                'EndpointItemResponse': {
                    'Message': 'string',
                    'StatusCode': 123
                },
                'EventsItemResponse': {
                    'string': {
                        'Message': 'string',
                        'StatusCode': 123
                    }
                }
            }
        }
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

EventsResponse (dict) --
Provides information about endpoints and the events that they\'re associated with.

Results (dict) --
A map that contains a multipart response for each endpoint. For each item in this object, the endpoint ID is the key and the item response is the value. If no item response exists, the value can also be one of the following: 202, the request was processed successfully; or 400, the payload wasn\'t valid or required fields were missing.

(string) --

(dict) --
Provides information about the results of a request to create or update an endpoint that\'s associated with an event.

EndpointItemResponse (dict) --
The response that was received after the endpoint data was accepted.

Message (string) --
The custom message that\'s returned in the response as a result of processing the endpoint data.

StatusCode (integer) --
The status code that\'s returned in the response as a result of processing the endpoint data.



EventsItemResponse (dict) --
A multipart response object that contains a key and a value for each event in the request. In each object, the event ID is the key and an EventItemResponse object is the value.

(string) --

(dict) --
Provides the status code and message that result from processing an event.

Message (string) --
A custom message that\'s returned in the response as a result of processing the event.

StatusCode (integer) --
The status code that\'s returned in the response as a result of processing the event. Possible values are: 202, for events that were accepted; and, 400, for events that weren\'t valid.





















Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EventsResponse': {
            'Results': {
                'string': {
                    'EndpointItemResponse': {
                        'Message': 'string',
                        'StatusCode': 123
                    },
                    'EventsItemResponse': {
                        'string': {
                            'Message': 'string',
                            'StatusCode': 123
                        }
                    }
                }
            }
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def remove_attributes(ApplicationId=None, AttributeType=None, UpdateAttributesRequest=None):
    """
    Removes one or more attributes, of the same attribute type, from all the endpoints that are associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.remove_attributes(
        ApplicationId='string',
        AttributeType='string',
        UpdateAttributesRequest={
            'Blacklist': [
                'string',
            ]
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type AttributeType: string
    :param AttributeType: [REQUIRED]\nThe type of attribute or attributes to remove. Valid values are:\n\nendpoint-custom-attributes - Custom attributes that describe endpoints, such as the date when an associated user opted in or out of receiving communications from you through a specific type of channel.\nendpoint-metric-attributes - Custom metrics that your app reports to Amazon Pinpoint for endpoints, such as the number of app sessions or the number of items left in a cart.\nendpoint-user-attributes - Custom attributes that describe users, such as first name, last name, and age.\n\n

    :type UpdateAttributesRequest: dict
    :param UpdateAttributesRequest: [REQUIRED]\nSpecifies one or more attributes to remove from all the endpoints that are associated with an application.\n\nBlacklist (list) --An array of the attributes to remove from all the endpoints that are associated with the application. The array can specify the complete, exact name of each attribute to remove or it can specify a glob pattern that an attribute name must match in order for the attribute to be removed.\n\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'AttributesResource': {
        'ApplicationId': 'string',
        'AttributeType': 'string',
        'Attributes': [
            'string',
        ]
    }
}


Response Structure

(dict) --
The request succeeded.

AttributesResource (dict) --
Provides information about the type and the names of attributes that were removed from all the endpoints that are associated with an application.

ApplicationId (string) --
The unique identifier for the application.

AttributeType (string) --
The type of attribute or attributes that were removed from the endpoints. Valid values are:

endpoint-custom-attributes - Custom attributes that describe endpoints.
endpoint-metric-attributes - Custom metrics that your app reports to Amazon Pinpoint for endpoints.
endpoint-user-attributes - Custom attributes that describe users.


Attributes (list) --
An array that specifies the names of the attributes that were removed from the endpoints.

(string) --










Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'AttributesResource': {
            'ApplicationId': 'string',
            'AttributeType': 'string',
            'Attributes': [
                'string',
            ]
        }
    }
    
    
    :returns: 
    endpoint-custom-attributes - Custom attributes that describe endpoints.
    endpoint-metric-attributes - Custom metrics that your app reports to Amazon Pinpoint for endpoints.
    endpoint-user-attributes - Custom attributes that describe users.
    
    """
    pass

def send_messages(ApplicationId=None, MessageRequest=None):
    """
    Creates and sends a direct message.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.send_messages(
        ApplicationId='string',
        MessageRequest={
            'Addresses': {
                'string': {
                    'BodyOverride': 'string',
                    'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    'Context': {
                        'string': 'string'
                    },
                    'RawContent': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TitleOverride': 'string'
                }
            },
            'Context': {
                'string': 'string'
            },
            'Endpoints': {
                'string': {
                    'BodyOverride': 'string',
                    'Context': {
                        'string': 'string'
                    },
                    'RawContent': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TitleOverride': 'string'
                }
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ConsolidationKey': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'ExpiresAfter': 'string',
                    'IconReference': 'string',
                    'ImageIconUrl': 'string',
                    'ImageUrl': 'string',
                    'MD5': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'SmallImageIconUrl': 'string',
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'APNSPushType': 'string',
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Badge': 123,
                    'Body': 'string',
                    'Category': 'string',
                    'CollapseId': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'MediaUrl': 'string',
                    'PreferredAuthenticationMethod': 'string',
                    'Priority': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'ThreadId': 'string',
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'IconReference': 'string',
                    'ImageIconUrl': 'string',
                    'ImageUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'SmallImageIconUrl': 'string',
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'DefaultMessage': {
                    'Body': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    }
                },
                'DefaultPushNotificationMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'SilentPush': True|False,
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FeedbackForwardingAddress': 'string',
                    'FromAddress': 'string',
                    'RawEmail': {
                        'Data': b'bytes'
                    },
                    'ReplyToAddresses': [
                        'string',
                    ],
                    'SimpleEmail': {
                        'HtmlPart': {
                            'Charset': 'string',
                            'Data': 'string'
                        },
                        'Subject': {
                            'Charset': 'string',
                            'Data': 'string'
                        },
                        'TextPart': {
                            'Charset': 'string',
                            'Data': 'string'
                        }
                    },
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    }
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'CollapseKey': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'IconReference': 'string',
                    'ImageIconUrl': 'string',
                    'ImageUrl': 'string',
                    'Priority': 'string',
                    'RawContent': 'string',
                    'RestrictedPackageName': 'string',
                    'SilentPush': True|False,
                    'SmallImageIconUrl': 'string',
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'Keyword': 'string',
                    'MediaUrl': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'OriginationNumber': 'string',
                    'SenderId': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    }
                },
                'VoiceMessage': {
                    'Body': 'string',
                    'LanguageCode': 'string',
                    'OriginationNumber': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'VoiceId': 'string'
                }
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TraceId': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type MessageRequest: dict
    :param MessageRequest: [REQUIRED]\nSpecifies the configuration and other settings for a message.\n\nAddresses (dict) --A map of key-value pairs, where each key is an address and each value is an AddressConfiguration object. An address can be a push notification token, a phone number, or an email address. You can use an AddressConfiguration object to tailor the message for an address by specifying settings such as content overrides and message variables.\n\n(string) --\n(dict) --Specifies address-based configuration settings for a message that\'s sent directly to an endpoint.\n\nBodyOverride (string) --The message body to use instead of the default message body. This value overrides the default message body.\n\nChannelType (string) --The channel to use when sending the message.\n\nContext (dict) --An object that maps custom attributes to attributes for the address and is attached to the message. Attribute names are case sensitive.\nFor a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.\n\n(string) --\n(string) --\n\n\n\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.\n\nSubstitutions (dict) --A map of the message variables to merge with the variables specified by properties of the DefaultMessage object. The variables specified in this map take precedence over all other variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitleOverride (string) --The message title to use instead of the default message title. This value overrides the default message title.\n\n\n\n\n\n\n\nContext (dict) --A map of custom attributes to attach to the message. For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.\n\n(string) --\n(string) --\n\n\n\n\nEndpoints (dict) --A map of key-value pairs, where each key is an endpoint ID and each value is an EndpointSendConfiguration object. You can use an EndpointSendConfiguration object to tailor the message for an endpoint by specifying settings such as content overrides and message variables.\n\n(string) --\n(dict) --Specifies the content, including message variables and attributes, to use in a message that\'s sent directly to an endpoint.\n\nBodyOverride (string) --The body of the message. If specified, this value overrides the default message body.\n\nContext (dict) --A map of custom attributes to attach to the message for the address. Attribute names are case sensitive.\nFor a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.\n\n(string) --\n(string) --\n\n\n\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.\n\nSubstitutions (dict) --A map of the message variables to merge with the variables specified for the default message (DefaultMessage.Substitutions). The variables specified in this map take precedence over all other variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitleOverride (string) --The title or subject line of the message. If specified, this value overrides the default message title or subject line.\n\n\n\n\n\n\n\nMessageConfiguration (dict) -- [REQUIRED]The settings and content for the default message and any default messages that you defined for specific channels.\n\nADMMessage (dict) --The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message.\n\nConsolidationKey (string) --An arbitrary string that indicates that multiple messages are logically the same and that Amazon Device Messaging (ADM) can drop previously enqueued messages in favor of this message.\n\nData (dict) --The JSON data payload to use for the push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nExpiresAfter (string) --The amount of time, in seconds, that ADM should store the message if the recipient\'s device is offline. Amazon Pinpoint specifies this value in the expiresAfter parameter when it sends the notification message to ADM.\n\nIconReference (string) --The icon image name of the asset saved in your app.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of the push notification.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nMD5 (string) --The base64-encoded, MD5 checksum of the value specified by the Data property. ADM uses the MD5 value to verify the integrity of the data.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or supporting phone home functionality.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of the push notification.\n\nSound (string) --The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nAPNSMessage (dict) --The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAPNSPushType (string) --The type of push notification to send. Valid values are:\n\nalert - For a standard notification that\'s displayed on recipients\' devices and prompts a recipient to interact with the notification.\nbackground - For a silent notification that delivers content in the background and isn\'t displayed on recipients\' devices.\ncomplication - For a notification that contains update information for an app\xe2\x80\x99s complication timeline.\nfileprovider - For a notification that signals changes to a File Provider extension.\nmdm - For a notification that tells managed devices to contact the MDM server.\nvoip - For a notification that provides information about an incoming VoIP call.\n\nAmazon Pinpoint specifies this value in the apns-push-type request header when it sends the notification message to APNs. If you don\'t specify a value for this property, Amazon Pinpoint sets the value to alert or background automatically, based on the value that you specify for the SilentPush or RawContent property of the message.\nFor more information about the apns-push-type request header, see Sending Notification Requests to APNs on the Apple Developer website.\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBadge (integer) --The key that indicates whether and how to modify the badge of your app\'s icon when the recipient receives the push notification. If this key isn\'t included in the dictionary, the badge doesn\'t change. To remove the badge, set this value to 0.\n\nBody (string) --The body of the notification message.\n\nCategory (string) --The key that indicates the notification type for the push notification. This key is a value that\'s defined by the identifier property of one of your app\'s registered categories.\n\nCollapseId (string) --An arbitrary identifier that, if assigned to multiple messages, APNs uses to coalesce the messages into a single push notification instead of delivering each message individually. This value can\'t exceed 64 bytes.\nAmazon Pinpoint specifies this value in the apns-collapse-id request header when it sends the notification message to APNs.\n\nData (dict) --The JSON payload to use for a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nMediaUrl (string) --The URL of an image or video to display in the push notification.\n\nPreferredAuthenticationMethod (string) --The authentication method that you want Amazon Pinpoint to use when authenticating with APNs, CERTIFICATE or TOKEN.\n\nPriority (string) --para>5 - Low priority, the notification might be delayed, delivered as part of a group, or throttled.\n/listitem>\n* 10 - High priority, the notification is sent immediately. This is the default value. A high priority notification should trigger an alert, play a sound, or badge your app\'s icon on the recipient\'s device.\n/para>\nAmazon Pinpoint specifies this value in the apns-priority request header when it sends the notification message to APNs.\nThe equivalent values for Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), are normal, for 5, and high, for 10. If you specify an FCM value for this property, Amazon Pinpoint accepts and converts the value to the corresponding APNs value.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nNote\nIf you specify the raw content of an APNs push notification, the message payload has to include the content-available key. The value of the content-available key has to be an integer, and can only be 0 or 1. If you\'re sending a standard notification, set the value of content-available to 0. If you\'re sending a silent (background) notification, set the value of content-available to 1. Additionally, silent notification payloads can\'t include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.\n\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification. A silent (or background) push notification isn\'t displayed on recipients\' devices. You can use silent push notifications to make small updates to your app, or to display messages in an in-app message center.\nAmazon Pinpoint uses this property to determine the correct value for the apns-push-type request header when it sends the notification message to APNs. If you specify a value of true for this property, Amazon Pinpoint sets the value for the apns-push-type header field to background.\n\nNote\nIf you specify the raw content of an APNs push notification, the message payload has to include the content-available key. For silent (background) notifications, set the value of content-available to 1. Additionally, the message payload for a silent notification can\'t include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.\nApple has indicated that they will throttle 'excessive' background notifications based on current traffic volumes. To prevent your notifications being throttled, Apple recommends that you send no more than 3 silent push notifications to each recipient per hour.\n\n\nSound (string) --The key for the sound to play when the recipient receives the push notification. The value for this key is the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override these default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nThreadId (string) --The key that represents your app-specific identifier for grouping notifications. If you provide a Notification Content app extension, you can use this value to group your notifications together.\n\nTimeToLive (integer) --The amount of time, in seconds, that APNs should store and attempt to deliver the push notification, if the service is unable to deliver the notification the first time. If this value is 0, APNs treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nAmazon Pinpoint specifies this value in the apns-expiration request header when it sends the notification message to APNs.\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nBaiduMessage (dict) --The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message.\n\nData (dict) --The JSON data payload to use for the push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nIconReference (string) --The icon image name of the asset saved in your app.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of the push notification.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or supporting phone home functionality.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of the push notification.\n\nSound (string) --The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTimeToLive (integer) --The amount of time, in seconds, that the Baidu Cloud Push service should store the message if the recipient\'s device is offline. The default value and maximum supported time is 604,800 seconds (7 days).\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nDefaultMessage (dict) --The default message for all channels.\n\nBody (string) --The default body of the message.\n\nSubstitutions (dict) --The default message variables to use in the message. You can override these default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\n\n\nDefaultPushNotificationMessage (dict) --The default push notification message for all push notification channels.\n\nAction (string) --The default action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The default body of the notification message.\n\nData (dict) --The JSON data payload to use for the default push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nSilentPush (boolean) --Specifies whether the default notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or delivering messages to an in-app notification center.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitle (string) --The default title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The default URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nEmailMessage (dict) --The default message for the email channel. This message overrides the default message (DefaultMessage).\n\nBody (string) --The body of the email message.\n\nFeedbackForwardingAddress (string) --The email address to forward bounces and complaints to, if feedback forwarding is enabled.\n\nFromAddress (string) --The verified email address to send the email message from. The default value is the FromAddress specified for the email channel.\n\nRawEmail (dict) --The email message, represented as a raw MIME message.\n\nData (bytes) --The email message, represented as a raw MIME message. The entire message must be base64 encoded.\n\n\n\nReplyToAddresses (list) --The reply-to email address(es) for the email message. If a recipient replies to the email, each reply-to address receives the reply.\n\n(string) --\n\n\nSimpleEmail (dict) --The email message, composed of a subject, a text part, and an HTML part.\n\nHtmlPart (dict) --The body of the email message, in HTML format. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.\n\nCharset (string) --The applicable character set for the message content.\n\nData (string) --The textual data of the message content.\n\n\n\nSubject (dict) --The subject line, or title, of the email.\n\nCharset (string) --The applicable character set for the message content.\n\nData (string) --The textual data of the message content.\n\n\n\nTextPart (dict) --The body of the email message, in plain text format. We recommend using plain text format for email clients that don\'t render HTML content and clients that are connected to high-latency networks, such as mobile devices.\n\nCharset (string) --The applicable character set for the message content.\n\nData (string) --The textual data of the message content.\n\n\n\n\n\nSubstitutions (dict) --The default message variables to use in the email message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\n\n\nGCMMessage (dict) --The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message.\n\nCollapseKey (string) --An arbitrary string that identifies a group of messages that can be collapsed to ensure that only the last message is sent when delivery can resume. This helps avoid sending too many instances of the same messages when the recipient\'s device comes online again or becomes active.\nAmazon Pinpoint specifies this value in the Firebase Cloud Messaging (FCM) collapse_key parameter when it sends the notification message to FCM.\n\nData (dict) --The JSON data payload to use for the push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nIconReference (string) --The icon image name of the asset saved in your app.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of the push notification.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nPriority (string) --para>normal - The notification might be delayed. Delivery is optimized for battery usage on the recipient\'s device. Use this value unless immediate delivery is required.\n/listitem>\n* high - The notification is sent immediately and might wake a sleeping device.\n/para>\nAmazon Pinpoint specifies this value in the FCM priority parameter when it sends the notification message to FCM.\nThe equivalent values for Apple Push Notification service (APNs) are 5, for normal, and 10, for high. If you specify an APNs value for this property, Amazon Pinpoint accepts and converts the value to the corresponding FCM value.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nRestrictedPackageName (string) --The package name of the application where registration tokens must match in order for the recipient to receive the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or supporting phone home functionality.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of the push notification.\n\nSound (string) --The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTimeToLive (integer) --The amount of time, in seconds, that FCM should store and attempt to deliver the push notification, if the service is unable to deliver the notification the first time. If you don\'t specify this value, FCM defaults to the maximum value, which is 2,419,200 seconds (28 days).\nAmazon Pinpoint specifies this value in the FCM time_to_live parameter when it sends the notification message to FCM.\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nSMSMessage (dict) --The default message for the SMS channel. This message overrides the default message (DefaultMessage).\n\nBody (string) --The body of the SMS message.\n\nKeyword (string) --The SMS program name that you provided to AWS Support when you requested your dedicated number.\n\nMediaUrl (string) --The URL of an image or video to display in the SMS message.\n\nMessageType (string) --The SMS message type. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message is not critical or time-sensitive, such as a marketing message.\n\nOriginationNumber (string) --The number to send the SMS message from. This value should be one of the dedicated long or short codes that\'s assigned to your AWS account. If you don\'t specify a long or short code, Amazon Pinpoint assigns a random long code to the SMS message and sends the message from that code.\n\nSenderId (string) --The sender ID to display as the sender of the message on a recipient\'s device. Support for sender IDs varies by country or region.\n\nSubstitutions (dict) --The message variables to use in the SMS message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\n\n\nVoiceMessage (dict) --The default message for the voice channel. This message overrides the default message (DefaultMessage).\n\nBody (string) --The text of the script to use for the voice message.\n\nLanguageCode (string) --The code for the language to use when synthesizing the text of the message script. For a list of supported languages and the code for each one, see the Amazon Polly Developer Guide .\n\nOriginationNumber (string) --The long code to send the voice message from. This value should be one of the dedicated long codes that\'s assigned to your AWS account. Although it isn\'t required, we recommend that you specify the long code in E.164 format, for example +12065550100, to ensure prompt and accurate delivery of the message.\n\nSubstitutions (dict) --The default message variables to use in the voice message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nVoiceId (string) --The name of the voice to use when delivering the message. For a list of supported voices, see the Amazon Polly Developer Guide .\n\n\n\n\n\nTemplateConfiguration (dict) --The message template to use for the message.\n\nEmailTemplate (dict) --The email template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nPushTemplate (dict) --The push notification template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nSMSTemplate (dict) --The SMS template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nVoiceTemplate (dict) --The voice template to use for the message. This object isn\'t supported for campaigns.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\n\n\nTraceId (string) --The unique identifier for tracing the message. This identifier is visible to message recipients.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageResponse': {
        'ApplicationId': 'string',
        'EndpointResult': {
            'string': {
                'Address': 'string',
                'DeliveryStatus': 'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'|'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'|'DUPLICATE',
                'MessageId': 'string',
                'StatusCode': 123,
                'StatusMessage': 'string',
                'UpdatedToken': 'string'
            }
        },
        'RequestId': 'string',
        'Result': {
            'string': {
                'DeliveryStatus': 'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'|'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'|'DUPLICATE',
                'MessageId': 'string',
                'StatusCode': 123,
                'StatusMessage': 'string',
                'UpdatedToken': 'string'
            }
        }
    }
}


Response Structure

(dict) --
The request succeeded.

MessageResponse (dict) --
Provides information about the results of a request to send a message to an endpoint address.

ApplicationId (string) --
The unique identifier for the application that was used to send the message.

EndpointResult (dict) --
A map that contains a multipart response for each address that the message was sent to. In the map, the endpoint ID is the key and the result is the value.

(string) --

(dict) --
Provides information about the delivery status and results of sending a message directly to an endpoint.

Address (string) --
The endpoint address that the message was delivered to.

DeliveryStatus (string) --
The delivery status of the message. Possible values are:

DUPLICATE - The endpoint address is a duplicate of another endpoint address. Amazon Pinpoint won\'t attempt to send the message again.
OPT_OUT - The user who\'s associated with the endpoint has opted out of receiving messages from you. Amazon Pinpoint won\'t attempt to send the message again.
PERMANENT_FAILURE - An error occurred when delivering the message to the endpoint. Amazon Pinpoint won\'t attempt to send the message again.
SUCCESSFUL - The message was successfully delivered to the endpoint.
TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint won\'t attempt to send the message again.
THROTTLED - Amazon Pinpoint throttled the operation to send the message to the endpoint.
TIMEOUT - The message couldn\'t be sent within the timeout period.
UNKNOWN_FAILURE - An unknown error occurred.


MessageId (string) --
The unique identifier for the message that was sent.

StatusCode (integer) --
The downstream service status code for delivering the message.

StatusMessage (string) --
The status message for delivering the message.

UpdatedToken (string) --
For push notifications that are sent through the GCM channel, specifies whether the endpoint\'s device registration token was updated as part of delivering the message.







RequestId (string) --
The identifier for the original request that the message was delivered for.

Result (dict) --
A map that contains a multipart response for each address (email address, phone number, or push notification token) that the message was sent to. In the map, the address is the key and the result is the value.

(string) --

(dict) --
Provides information about the results of sending a message directly to an endpoint address.

DeliveryStatus (string) --
The delivery status of the message. Possible values are:

DUPLICATE - The endpoint address is a duplicate of another endpoint address. Amazon Pinpoint won\'t attempt to send the message again.
OPT_OUT - The user who\'s associated with the endpoint address has opted out of receiving messages from you. Amazon Pinpoint won\'t attempt to send the message again.
PERMANENT_FAILURE - An error occurred when delivering the message to the endpoint address. Amazon Pinpoint won\'t attempt to send the message again.
SUCCESSFUL - The message was successfully delivered to the endpoint address.
TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint won\'t attempt to send the message again.
THROTTLED - Amazon Pinpoint throttled the operation to send the message to the endpoint address.
TIMEOUT - The message couldn\'t be sent within the timeout period.
UNKNOWN_FAILURE - An unknown error occurred.


MessageId (string) --
The unique identifier for the message that was sent.

StatusCode (integer) --
The downstream service status code for delivering the message.

StatusMessage (string) --
The status message for delivering the message.

UpdatedToken (string) --
For push notifications that are sent through the GCM channel, specifies whether the endpoint\'s device registration token was updated as part of delivering the message.















Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageResponse': {
            'ApplicationId': 'string',
            'EndpointResult': {
                'string': {
                    'Address': 'string',
                    'DeliveryStatus': 'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'|'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'|'DUPLICATE',
                    'MessageId': 'string',
                    'StatusCode': 123,
                    'StatusMessage': 'string',
                    'UpdatedToken': 'string'
                }
            },
            'RequestId': 'string',
            'Result': {
                'string': {
                    'DeliveryStatus': 'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'|'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'|'DUPLICATE',
                    'MessageId': 'string',
                    'StatusCode': 123,
                    'StatusMessage': 'string',
                    'UpdatedToken': 'string'
                }
            }
        }
    }
    
    
    :returns: 
    DUPLICATE - The endpoint address is a duplicate of another endpoint address. Amazon Pinpoint won\'t attempt to send the message again.
    OPT_OUT - The user who\'s associated with the endpoint has opted out of receiving messages from you. Amazon Pinpoint won\'t attempt to send the message again.
    PERMANENT_FAILURE - An error occurred when delivering the message to the endpoint. Amazon Pinpoint won\'t attempt to send the message again.
    SUCCESSFUL - The message was successfully delivered to the endpoint.
    TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint won\'t attempt to send the message again.
    THROTTLED - Amazon Pinpoint throttled the operation to send the message to the endpoint.
    TIMEOUT - The message couldn\'t be sent within the timeout period.
    UNKNOWN_FAILURE - An unknown error occurred.
    
    """
    pass

def send_users_messages(ApplicationId=None, SendUsersMessageRequest=None):
    """
    Creates and sends a message to a list of users.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.send_users_messages(
        ApplicationId='string',
        SendUsersMessageRequest={
            'Context': {
                'string': 'string'
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ConsolidationKey': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'ExpiresAfter': 'string',
                    'IconReference': 'string',
                    'ImageIconUrl': 'string',
                    'ImageUrl': 'string',
                    'MD5': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'SmallImageIconUrl': 'string',
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'APNSPushType': 'string',
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Badge': 123,
                    'Body': 'string',
                    'Category': 'string',
                    'CollapseId': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'MediaUrl': 'string',
                    'PreferredAuthenticationMethod': 'string',
                    'Priority': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'ThreadId': 'string',
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'IconReference': 'string',
                    'ImageIconUrl': 'string',
                    'ImageUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'SmallImageIconUrl': 'string',
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'DefaultMessage': {
                    'Body': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    }
                },
                'DefaultPushNotificationMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'SilentPush': True|False,
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FeedbackForwardingAddress': 'string',
                    'FromAddress': 'string',
                    'RawEmail': {
                        'Data': b'bytes'
                    },
                    'ReplyToAddresses': [
                        'string',
                    ],
                    'SimpleEmail': {
                        'HtmlPart': {
                            'Charset': 'string',
                            'Data': 'string'
                        },
                        'Subject': {
                            'Charset': 'string',
                            'Data': 'string'
                        },
                        'TextPart': {
                            'Charset': 'string',
                            'Data': 'string'
                        }
                    },
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    }
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'CollapseKey': 'string',
                    'Data': {
                        'string': 'string'
                    },
                    'IconReference': 'string',
                    'ImageIconUrl': 'string',
                    'ImageUrl': 'string',
                    'Priority': 'string',
                    'RawContent': 'string',
                    'RestrictedPackageName': 'string',
                    'SilentPush': True|False,
                    'SmallImageIconUrl': 'string',
                    'Sound': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'Keyword': 'string',
                    'MediaUrl': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'OriginationNumber': 'string',
                    'SenderId': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    }
                },
                'VoiceMessage': {
                    'Body': 'string',
                    'LanguageCode': 'string',
                    'OriginationNumber': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'VoiceId': 'string'
                }
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TraceId': 'string',
            'Users': {
                'string': {
                    'BodyOverride': 'string',
                    'Context': {
                        'string': 'string'
                    },
                    'RawContent': 'string',
                    'Substitutions': {
                        'string': [
                            'string',
                        ]
                    },
                    'TitleOverride': 'string'
                }
            }
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type SendUsersMessageRequest: dict
    :param SendUsersMessageRequest: [REQUIRED]\nSpecifies the configuration and other settings for a message to send to all the endpoints that are associated with a list of users.\n\nContext (dict) --A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds these attributes to the data.pinpoint object in the body of the notification payload. Amazon Pinpoint also provides these attributes in the events that it generates for users-messages deliveries.\n\n(string) --\n(string) --\n\n\n\n\nMessageConfiguration (dict) -- [REQUIRED]The settings and content for the default message and any default messages that you defined for specific channels.\n\nADMMessage (dict) --The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message.\n\nConsolidationKey (string) --An arbitrary string that indicates that multiple messages are logically the same and that Amazon Device Messaging (ADM) can drop previously enqueued messages in favor of this message.\n\nData (dict) --The JSON data payload to use for the push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nExpiresAfter (string) --The amount of time, in seconds, that ADM should store the message if the recipient\'s device is offline. Amazon Pinpoint specifies this value in the expiresAfter parameter when it sends the notification message to ADM.\n\nIconReference (string) --The icon image name of the asset saved in your app.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of the push notification.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nMD5 (string) --The base64-encoded, MD5 checksum of the value specified by the Data property. ADM uses the MD5 value to verify the integrity of the data.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or supporting phone home functionality.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of the push notification.\n\nSound (string) --The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nAPNSMessage (dict) --The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAPNSPushType (string) --The type of push notification to send. Valid values are:\n\nalert - For a standard notification that\'s displayed on recipients\' devices and prompts a recipient to interact with the notification.\nbackground - For a silent notification that delivers content in the background and isn\'t displayed on recipients\' devices.\ncomplication - For a notification that contains update information for an app\xe2\x80\x99s complication timeline.\nfileprovider - For a notification that signals changes to a File Provider extension.\nmdm - For a notification that tells managed devices to contact the MDM server.\nvoip - For a notification that provides information about an incoming VoIP call.\n\nAmazon Pinpoint specifies this value in the apns-push-type request header when it sends the notification message to APNs. If you don\'t specify a value for this property, Amazon Pinpoint sets the value to alert or background automatically, based on the value that you specify for the SilentPush or RawContent property of the message.\nFor more information about the apns-push-type request header, see Sending Notification Requests to APNs on the Apple Developer website.\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBadge (integer) --The key that indicates whether and how to modify the badge of your app\'s icon when the recipient receives the push notification. If this key isn\'t included in the dictionary, the badge doesn\'t change. To remove the badge, set this value to 0.\n\nBody (string) --The body of the notification message.\n\nCategory (string) --The key that indicates the notification type for the push notification. This key is a value that\'s defined by the identifier property of one of your app\'s registered categories.\n\nCollapseId (string) --An arbitrary identifier that, if assigned to multiple messages, APNs uses to coalesce the messages into a single push notification instead of delivering each message individually. This value can\'t exceed 64 bytes.\nAmazon Pinpoint specifies this value in the apns-collapse-id request header when it sends the notification message to APNs.\n\nData (dict) --The JSON payload to use for a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nMediaUrl (string) --The URL of an image or video to display in the push notification.\n\nPreferredAuthenticationMethod (string) --The authentication method that you want Amazon Pinpoint to use when authenticating with APNs, CERTIFICATE or TOKEN.\n\nPriority (string) --para>5 - Low priority, the notification might be delayed, delivered as part of a group, or throttled.\n/listitem>\n* 10 - High priority, the notification is sent immediately. This is the default value. A high priority notification should trigger an alert, play a sound, or badge your app\'s icon on the recipient\'s device.\n/para>\nAmazon Pinpoint specifies this value in the apns-priority request header when it sends the notification message to APNs.\nThe equivalent values for Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), are normal, for 5, and high, for 10. If you specify an FCM value for this property, Amazon Pinpoint accepts and converts the value to the corresponding APNs value.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nNote\nIf you specify the raw content of an APNs push notification, the message payload has to include the content-available key. The value of the content-available key has to be an integer, and can only be 0 or 1. If you\'re sending a standard notification, set the value of content-available to 0. If you\'re sending a silent (background) notification, set the value of content-available to 1. Additionally, silent notification payloads can\'t include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.\n\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification. A silent (or background) push notification isn\'t displayed on recipients\' devices. You can use silent push notifications to make small updates to your app, or to display messages in an in-app message center.\nAmazon Pinpoint uses this property to determine the correct value for the apns-push-type request header when it sends the notification message to APNs. If you specify a value of true for this property, Amazon Pinpoint sets the value for the apns-push-type header field to background.\n\nNote\nIf you specify the raw content of an APNs push notification, the message payload has to include the content-available key. For silent (background) notifications, set the value of content-available to 1. Additionally, the message payload for a silent notification can\'t include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.\nApple has indicated that they will throttle 'excessive' background notifications based on current traffic volumes. To prevent your notifications being throttled, Apple recommends that you send no more than 3 silent push notifications to each recipient per hour.\n\n\nSound (string) --The key for the sound to play when the recipient receives the push notification. The value for this key is the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override these default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nThreadId (string) --The key that represents your app-specific identifier for grouping notifications. If you provide a Notification Content app extension, you can use this value to group your notifications together.\n\nTimeToLive (integer) --The amount of time, in seconds, that APNs should store and attempt to deliver the push notification, if the service is unable to deliver the notification the first time. If this value is 0, APNs treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nAmazon Pinpoint specifies this value in the apns-expiration request header when it sends the notification message to APNs.\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nBaiduMessage (dict) --The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message.\n\nData (dict) --The JSON data payload to use for the push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nIconReference (string) --The icon image name of the asset saved in your app.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of the push notification.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or supporting phone home functionality.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of the push notification.\n\nSound (string) --The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTimeToLive (integer) --The amount of time, in seconds, that the Baidu Cloud Push service should store the message if the recipient\'s device is offline. The default value and maximum supported time is 604,800 seconds (7 days).\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nDefaultMessage (dict) --The default message for all channels.\n\nBody (string) --The default body of the message.\n\nSubstitutions (dict) --The default message variables to use in the message. You can override these default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\n\n\nDefaultPushNotificationMessage (dict) --The default push notification message for all push notification channels.\n\nAction (string) --The default action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The default body of the notification message.\n\nData (dict) --The JSON data payload to use for the default push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nSilentPush (boolean) --Specifies whether the default notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or delivering messages to an in-app notification center.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitle (string) --The default title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The default URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nEmailMessage (dict) --The default message for the email channel. This message overrides the default message (DefaultMessage).\n\nBody (string) --The body of the email message.\n\nFeedbackForwardingAddress (string) --The email address to forward bounces and complaints to, if feedback forwarding is enabled.\n\nFromAddress (string) --The verified email address to send the email message from. The default value is the FromAddress specified for the email channel.\n\nRawEmail (dict) --The email message, represented as a raw MIME message.\n\nData (bytes) --The email message, represented as a raw MIME message. The entire message must be base64 encoded.\n\n\n\nReplyToAddresses (list) --The reply-to email address(es) for the email message. If a recipient replies to the email, each reply-to address receives the reply.\n\n(string) --\n\n\nSimpleEmail (dict) --The email message, composed of a subject, a text part, and an HTML part.\n\nHtmlPart (dict) --The body of the email message, in HTML format. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.\n\nCharset (string) --The applicable character set for the message content.\n\nData (string) --The textual data of the message content.\n\n\n\nSubject (dict) --The subject line, or title, of the email.\n\nCharset (string) --The applicable character set for the message content.\n\nData (string) --The textual data of the message content.\n\n\n\nTextPart (dict) --The body of the email message, in plain text format. We recommend using plain text format for email clients that don\'t render HTML content and clients that are connected to high-latency networks, such as mobile devices.\n\nCharset (string) --The applicable character set for the message content.\n\nData (string) --The textual data of the message content.\n\n\n\n\n\nSubstitutions (dict) --The default message variables to use in the email message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\n\n\nGCMMessage (dict) --The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).\n\nAction (string) --The action to occur if the recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message.\n\nCollapseKey (string) --An arbitrary string that identifies a group of messages that can be collapsed to ensure that only the last message is sent when delivery can resume. This helps avoid sending too many instances of the same messages when the recipient\'s device comes online again or becomes active.\nAmazon Pinpoint specifies this value in the Firebase Cloud Messaging (FCM) collapse_key parameter when it sends the notification message to FCM.\n\nData (dict) --The JSON data payload to use for the push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.\n\n(string) --\n(string) --\n\n\n\n\nIconReference (string) --The icon image name of the asset saved in your app.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of the push notification.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nPriority (string) --para>normal - The notification might be delayed. Delivery is optimized for battery usage on the recipient\'s device. Use this value unless immediate delivery is required.\n/listitem>\n* high - The notification is sent immediately and might wake a sleeping device.\n/para>\nAmazon Pinpoint specifies this value in the FCM priority parameter when it sends the notification message to FCM.\nThe equivalent values for Apple Push Notification service (APNs) are 5, for normal, and 10, for high. If you specify an APNs value for this property, Amazon Pinpoint accepts and converts the value to the corresponding FCM value.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nRestrictedPackageName (string) --The package name of the application where registration tokens must match in order for the recipient to receive the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration or supporting phone home functionality.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of the push notification.\n\nSound (string) --The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nSubstitutions (dict) --The default message variables to use in the notification message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTimeToLive (integer) --The amount of time, in seconds, that FCM should store and attempt to deliver the push notification, if the service is unable to deliver the notification the first time. If you don\'t specify this value, FCM defaults to the maximum value, which is 2,419,200 seconds (28 days).\nAmazon Pinpoint specifies this value in the FCM time_to_live parameter when it sends the notification message to FCM.\n\nTitle (string) --The title to display above the notification message on the recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nSMSMessage (dict) --The default message for the SMS channel. This message overrides the default message (DefaultMessage).\n\nBody (string) --The body of the SMS message.\n\nKeyword (string) --The SMS program name that you provided to AWS Support when you requested your dedicated number.\n\nMediaUrl (string) --The URL of an image or video to display in the SMS message.\n\nMessageType (string) --The SMS message type. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message is not critical or time-sensitive, such as a marketing message.\n\nOriginationNumber (string) --The number to send the SMS message from. This value should be one of the dedicated long or short codes that\'s assigned to your AWS account. If you don\'t specify a long or short code, Amazon Pinpoint assigns a random long code to the SMS message and sends the message from that code.\n\nSenderId (string) --The sender ID to display as the sender of the message on a recipient\'s device. Support for sender IDs varies by country or region.\n\nSubstitutions (dict) --The message variables to use in the SMS message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\n\n\nVoiceMessage (dict) --The default message for the voice channel. This message overrides the default message (DefaultMessage).\n\nBody (string) --The text of the script to use for the voice message.\n\nLanguageCode (string) --The code for the language to use when synthesizing the text of the message script. For a list of supported languages and the code for each one, see the Amazon Polly Developer Guide .\n\nOriginationNumber (string) --The long code to send the voice message from. This value should be one of the dedicated long codes that\'s assigned to your AWS account. Although it isn\'t required, we recommend that you specify the long code in E.164 format, for example +12065550100, to ensure prompt and accurate delivery of the message.\n\nSubstitutions (dict) --The default message variables to use in the voice message. You can override the default variables with individual address variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nVoiceId (string) --The name of the voice to use when delivering the message. For a list of supported voices, see the Amazon Polly Developer Guide .\n\n\n\n\n\nTemplateConfiguration (dict) --The message template to use for the message.\n\nEmailTemplate (dict) --The email template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nPushTemplate (dict) --The push notification template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nSMSTemplate (dict) --The SMS template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nVoiceTemplate (dict) --The voice template to use for the message. This object isn\'t supported for campaigns.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\n\n\nTraceId (string) --The unique identifier for tracing the message. This identifier is visible to message recipients.\n\nUsers (dict) -- [REQUIRED]A map that associates user IDs with EndpointSendConfiguration objects. You can use an EndpointSendConfiguration object to tailor the message for a user by specifying settings such as content overrides and message variables.\n\n(string) --\n(dict) --Specifies the content, including message variables and attributes, to use in a message that\'s sent directly to an endpoint.\n\nBodyOverride (string) --The body of the message. If specified, this value overrides the default message body.\n\nContext (dict) --A map of custom attributes to attach to the message for the address. Attribute names are case sensitive.\nFor a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.\n\n(string) --\n(string) --\n\n\n\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.\n\nSubstitutions (dict) --A map of the message variables to merge with the variables specified for the default message (DefaultMessage.Substitutions). The variables specified in this map take precedence over all other variables.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nTitleOverride (string) --The title or subject line of the message. If specified, this value overrides the default message title or subject line.\n\n\n\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SendUsersMessageResponse': {
        'ApplicationId': 'string',
        'RequestId': 'string',
        'Result': {
            'string': {
                'string': {
                    'Address': 'string',
                    'DeliveryStatus': 'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'|'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'|'DUPLICATE',
                    'MessageId': 'string',
                    'StatusCode': 123,
                    'StatusMessage': 'string',
                    'UpdatedToken': 'string'
                }
            }
        }
    }
}


Response Structure

(dict) --
The request succeeded.

SendUsersMessageResponse (dict) --
Provides information about which users and endpoints a message was sent to.

ApplicationId (string) --
The unique identifier for the application that was used to send the message.

RequestId (string) --
The unique identifier that was assigned to the message request.

Result (dict) --
An object that indicates which endpoints the message was sent to, for each user. The object lists user IDs and, for each user ID, provides the endpoint IDs that the message was sent to. For each endpoint ID, it provides an EndpointMessageResult object.

(string) --

(dict) --

(string) --

(dict) --
Provides information about the delivery status and results of sending a message directly to an endpoint.

Address (string) --
The endpoint address that the message was delivered to.

DeliveryStatus (string) --
The delivery status of the message. Possible values are:

DUPLICATE - The endpoint address is a duplicate of another endpoint address. Amazon Pinpoint won\'t attempt to send the message again.
OPT_OUT - The user who\'s associated with the endpoint has opted out of receiving messages from you. Amazon Pinpoint won\'t attempt to send the message again.
PERMANENT_FAILURE - An error occurred when delivering the message to the endpoint. Amazon Pinpoint won\'t attempt to send the message again.
SUCCESSFUL - The message was successfully delivered to the endpoint.
TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint won\'t attempt to send the message again.
THROTTLED - Amazon Pinpoint throttled the operation to send the message to the endpoint.
TIMEOUT - The message couldn\'t be sent within the timeout period.
UNKNOWN_FAILURE - An unknown error occurred.


MessageId (string) --
The unique identifier for the message that was sent.

StatusCode (integer) --
The downstream service status code for delivering the message.

StatusMessage (string) --
The status message for delivering the message.

UpdatedToken (string) --
For push notifications that are sent through the GCM channel, specifies whether the endpoint\'s device registration token was updated as part of delivering the message.



















Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SendUsersMessageResponse': {
            'ApplicationId': 'string',
            'RequestId': 'string',
            'Result': {
                'string': {
                    'string': {
                        'Address': 'string',
                        'DeliveryStatus': 'SUCCESSFUL'|'THROTTLED'|'TEMPORARY_FAILURE'|'PERMANENT_FAILURE'|'UNKNOWN_FAILURE'|'OPT_OUT'|'DUPLICATE',
                        'MessageId': 'string',
                        'StatusCode': 123,
                        'StatusMessage': 'string',
                        'UpdatedToken': 'string'
                    }
                }
            }
        }
    }
    
    
    :returns: 
    DUPLICATE - The endpoint address is a duplicate of another endpoint address. Amazon Pinpoint won\'t attempt to send the message again.
    OPT_OUT - The user who\'s associated with the endpoint has opted out of receiving messages from you. Amazon Pinpoint won\'t attempt to send the message again.
    PERMANENT_FAILURE - An error occurred when delivering the message to the endpoint. Amazon Pinpoint won\'t attempt to send the message again.
    SUCCESSFUL - The message was successfully delivered to the endpoint.
    TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint won\'t attempt to send the message again.
    THROTTLED - Amazon Pinpoint throttled the operation to send the message to the endpoint.
    TIMEOUT - The message couldn\'t be sent within the timeout period.
    UNKNOWN_FAILURE - An unknown error occurred.
    
    """
    pass

def tag_resource(ResourceArn=None, TagsModel=None):
    """
    Adds one or more tags (keys and values) to an application, campaign, message template, or segment.
    See also: AWS API Documentation
    
    
    :example: response = client.tag_resource(
        ResourceArn='string',
        TagsModel={
            'tags': {
                'string': 'string'
            }
        }
    )
    
    
    :type ResourceArn: string
    :param ResourceArn: [REQUIRED]\nThe Amazon Resource Name (ARN) of the resource.\n

    :type TagsModel: dict
    :param TagsModel: [REQUIRED]\nSpecifies the tags (keys and values) for an application, campaign, message template, or segment.\n\ntags (dict) -- [REQUIRED]A string-to-string map of key-value pairs that defines the tags for an application, campaign, message template, or segment. Each of these resources can have a maximum of 50 tags.\nEach tag consists of a required tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.\n\n(string) --\n(string) --\n\n\n\n\n\n

    """
    pass

def untag_resource(ResourceArn=None, TagKeys=None):
    """
    Removes one or more tags (keys and values) from an application, campaign, message template, or segment.
    See also: AWS API Documentation
    
    
    :example: response = client.untag_resource(
        ResourceArn='string',
        TagKeys=[
            'string',
        ]
    )
    
    
    :type ResourceArn: string
    :param ResourceArn: [REQUIRED]\nThe Amazon Resource Name (ARN) of the resource.\n

    :type TagKeys: list
    :param TagKeys: [REQUIRED]\nThe key of the tag to remove from the resource. To remove multiple tags, append the tagKeys parameter and argument for each additional tag to remove, separated by an ampersand (&).\n\n(string) --\n\n

    """
    pass

def update_adm_channel(ADMChannelRequest=None, ApplicationId=None):
    """
    Enables the ADM channel for an application or updates the status and settings of the ADM channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_adm_channel(
        ADMChannelRequest={
            'ClientId': 'string',
            'ClientSecret': 'string',
            'Enabled': True|False
        },
        ApplicationId='string'
    )
    
    
    :type ADMChannelRequest: dict
    :param ADMChannelRequest: [REQUIRED]\nSpecifies the status and settings of the ADM (Amazon Device Messaging) channel for an application.\n\nClientId (string) -- [REQUIRED]The Client ID that you received from Amazon to send messages by using ADM.\n\nClientSecret (string) -- [REQUIRED]The Client Secret that you received from Amazon to send messages by using ADM.\n\nEnabled (boolean) --Specifies whether to enable the ADM channel for the application.\n\n\n

    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ADMChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

ADMChannelResponse (dict) --
Provides information about the status and settings of the ADM (Amazon Device Messaging) channel for an application.

ApplicationId (string) --
The unique identifier for the application that the ADM channel applies to.

CreationDate (string) --
The date and time when the ADM channel was enabled.

Enabled (boolean) --
Specifies whether the ADM channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

Id (string) --
(Deprecated) An identifier for the ADM channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the ADM channel is archived.

LastModifiedBy (string) --
The user who last modified the ADM channel.

LastModifiedDate (string) --
The date and time when the ADM channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the ADM channel, this value is ADM.

Version (integer) --
The current version of the ADM channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ADMChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_apns_channel(APNSChannelRequest=None, ApplicationId=None):
    """
    Enables the APNs channel for an application or updates the status and settings of the APNs channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_apns_channel(
        APNSChannelRequest={
            'BundleId': 'string',
            'Certificate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'PrivateKey': 'string',
            'TeamId': 'string',
            'TokenKey': 'string',
            'TokenKeyId': 'string'
        },
        ApplicationId='string'
    )
    
    
    :type APNSChannelRequest: dict
    :param APNSChannelRequest: [REQUIRED]\nSpecifies the status and settings of the APNs (Apple Push Notification service) channel for an application.\n\nBundleId (string) --The bundle identifier that\'s assigned to your iOS app. This identifier is used for APNs tokens.\n\nCertificate (string) --The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to communicate with APNs by using an APNs certificate.\n\nDefaultAuthenticationMethod (string) --The default authentication method that you want Amazon Pinpoint to use when authenticating with APNs, key or certificate.\n\nEnabled (boolean) --Specifies whether to enable the APNs channel for the application.\n\nPrivateKey (string) --The private key for the APNs client certificate that you want Amazon Pinpoint to use to communicate with APNs.\n\nTeamId (string) --The identifier that\'s assigned to your Apple developer account team. This identifier is used for APNs tokens.\n\nTokenKey (string) --The authentication key to use for APNs tokens.\n\nTokenKeyId (string) --The key identifier that\'s assigned to your APNs signing key, if you want Amazon Pinpoint to communicate with APNs by using APNs tokens.\n\n\n

    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'APNSChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

APNSChannelResponse (dict) --
Provides information about the status and settings of the APNs (Apple Push Notification service) channel for an application.

ApplicationId (string) --
The unique identifier for the application that the APNs channel applies to.

CreationDate (string) --
The date and time when the APNs channel was enabled.

DefaultAuthenticationMethod (string) --
The default authentication method that Amazon Pinpoint uses to authenticate with APNs for this channel, key or certificate.

Enabled (boolean) --
Specifies whether the APNs channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --
Specifies whether the APNs channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --
(Deprecated) An identifier for the APNs channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the APNs channel is archived.

LastModifiedBy (string) --
The user who last modified the APNs channel.

LastModifiedDate (string) --
The date and time when the APNs channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the APNs channel, this value is APNS.

Version (integer) --
The current version of the APNs channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_apns_sandbox_channel(APNSSandboxChannelRequest=None, ApplicationId=None):
    """
    Enables the APNs sandbox channel for an application or updates the status and settings of the APNs sandbox channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_apns_sandbox_channel(
        APNSSandboxChannelRequest={
            'BundleId': 'string',
            'Certificate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'PrivateKey': 'string',
            'TeamId': 'string',
            'TokenKey': 'string',
            'TokenKeyId': 'string'
        },
        ApplicationId='string'
    )
    
    
    :type APNSSandboxChannelRequest: dict
    :param APNSSandboxChannelRequest: [REQUIRED]\nSpecifies the status and settings of the APNs (Apple Push Notification service) sandbox channel for an application.\n\nBundleId (string) --The bundle identifier that\'s assigned to your iOS app. This identifier is used for APNs tokens.\n\nCertificate (string) --The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to communicate with the APNs sandbox environment by using an APNs certificate.\n\nDefaultAuthenticationMethod (string) --The default authentication method that you want Amazon Pinpoint to use when authenticating with the APNs sandbox environment, key or certificate.\n\nEnabled (boolean) --Specifies whether to enable the APNs sandbox channel for the application.\n\nPrivateKey (string) --The private key for the APNs client certificate that you want Amazon Pinpoint to use to communicate with the APNs sandbox environment.\n\nTeamId (string) --The identifier that\'s assigned to your Apple developer account team. This identifier is used for APNs tokens.\n\nTokenKey (string) --The authentication key to use for APNs tokens.\n\nTokenKeyId (string) --The key identifier that\'s assigned to your APNs signing key, if you want Amazon Pinpoint to communicate with the APNs sandbox environment by using APNs tokens.\n\n\n

    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'APNSSandboxChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

APNSSandboxChannelResponse (dict) --
Provides information about the status and settings of the APNs (Apple Push Notification service) sandbox channel for an application.

ApplicationId (string) --
The unique identifier for the application that the APNs sandbox channel applies to.

CreationDate (string) --
The date and time when the APNs sandbox channel was enabled.

DefaultAuthenticationMethod (string) --
The default authentication method that Amazon Pinpoint uses to authenticate with the APNs sandbox environment for this channel, key or certificate.

Enabled (boolean) --
Specifies whether the APNs sandbox channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --
Specifies whether the APNs sandbox channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --
(Deprecated) An identifier for the APNs sandbox channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the APNs sandbox channel is archived.

LastModifiedBy (string) --
The user who last modified the APNs sandbox channel.

LastModifiedDate (string) --
The date and time when the APNs sandbox channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the APNs sandbox channel, this value is APNS_SANDBOX.

Version (integer) --
The current version of the APNs sandbox channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSSandboxChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_apns_voip_channel(APNSVoipChannelRequest=None, ApplicationId=None):
    """
    Enables the APNs VoIP channel for an application or updates the status and settings of the APNs VoIP channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_apns_voip_channel(
        APNSVoipChannelRequest={
            'BundleId': 'string',
            'Certificate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'PrivateKey': 'string',
            'TeamId': 'string',
            'TokenKey': 'string',
            'TokenKeyId': 'string'
        },
        ApplicationId='string'
    )
    
    
    :type APNSVoipChannelRequest: dict
    :param APNSVoipChannelRequest: [REQUIRED]\nSpecifies the status and settings of the APNs (Apple Push Notification service) VoIP channel for an application.\n\nBundleId (string) --The bundle identifier that\'s assigned to your iOS app. This identifier is used for APNs tokens.\n\nCertificate (string) --The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to communicate with APNs by using an APNs certificate.\n\nDefaultAuthenticationMethod (string) --The default authentication method that you want Amazon Pinpoint to use when authenticating with APNs, key or certificate.\n\nEnabled (boolean) --Specifies whether to enable the APNs VoIP channel for the application.\n\nPrivateKey (string) --The private key for the APNs client certificate that you want Amazon Pinpoint to use to communicate with APNs.\n\nTeamId (string) --The identifier that\'s assigned to your Apple developer account team. This identifier is used for APNs tokens.\n\nTokenKey (string) --The authentication key to use for APNs tokens.\n\nTokenKeyId (string) --The key identifier that\'s assigned to your APNs signing key, if you want Amazon Pinpoint to communicate with APNs by using APNs tokens.\n\n\n

    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'APNSVoipChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

APNSVoipChannelResponse (dict) --
Provides information about the status and settings of the APNs (Apple Push Notification service) VoIP channel for an application.

ApplicationId (string) --
The unique identifier for the application that the APNs VoIP channel applies to.

CreationDate (string) --
The date and time when the APNs VoIP channel was enabled.

DefaultAuthenticationMethod (string) --
The default authentication method that Amazon Pinpoint uses to authenticate with APNs for this channel, key or certificate.

Enabled (boolean) --
Specifies whether the APNs VoIP channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --
Specifies whether the APNs VoIP channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --
(Deprecated) An identifier for the APNs VoIP channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the APNs VoIP channel is archived.

LastModifiedBy (string) --
The user who last modified the APNs VoIP channel.

LastModifiedDate (string) --
The date and time when the APNs VoIP channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the APNs VoIP channel, this value is APNS_VOIP.

Version (integer) --
The current version of the APNs VoIP channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSVoipChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_apns_voip_sandbox_channel(APNSVoipSandboxChannelRequest=None, ApplicationId=None):
    """
    Enables the APNs VoIP sandbox channel for an application or updates the status and settings of the APNs VoIP sandbox channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_apns_voip_sandbox_channel(
        APNSVoipSandboxChannelRequest={
            'BundleId': 'string',
            'Certificate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'PrivateKey': 'string',
            'TeamId': 'string',
            'TokenKey': 'string',
            'TokenKeyId': 'string'
        },
        ApplicationId='string'
    )
    
    
    :type APNSVoipSandboxChannelRequest: dict
    :param APNSVoipSandboxChannelRequest: [REQUIRED]\nSpecifies the status and settings of the APNs (Apple Push Notification service) VoIP sandbox channel for an application.\n\nBundleId (string) --The bundle identifier that\'s assigned to your iOS app. This identifier is used for APNs tokens.\n\nCertificate (string) --The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to communicate with the APNs sandbox environment by using an APNs certificate.\n\nDefaultAuthenticationMethod (string) --The default authentication method that you want Amazon Pinpoint to use when authenticating with the APNs sandbox environment for this channel, key or certificate.\n\nEnabled (boolean) --Specifies whether the APNs VoIP sandbox channel is enabled for the application.\n\nPrivateKey (string) --The private key for the APNs client certificate that you want Amazon Pinpoint to use to communicate with the APNs sandbox environment.\n\nTeamId (string) --The identifier that\'s assigned to your Apple developer account team. This identifier is used for APNs tokens.\n\nTokenKey (string) --The authentication key to use for APNs tokens.\n\nTokenKeyId (string) --The key identifier that\'s assigned to your APNs signing key, if you want Amazon Pinpoint to communicate with the APNs sandbox environment by using APNs tokens.\n\n\n

    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'APNSVoipSandboxChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'DefaultAuthenticationMethod': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'HasTokenKey': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

APNSVoipSandboxChannelResponse (dict) --
Provides information about the status and settings of the APNs (Apple Push Notification service) VoIP sandbox channel for an application.

ApplicationId (string) --
The unique identifier for the application that the APNs VoIP sandbox channel applies to.

CreationDate (string) --
The date and time when the APNs VoIP sandbox channel was enabled.

DefaultAuthenticationMethod (string) --
The default authentication method that Amazon Pinpoint uses to authenticate with the APNs sandbox environment for this channel, key or certificate.

Enabled (boolean) --
Specifies whether the APNs VoIP sandbox channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

HasTokenKey (boolean) --
Specifies whether the APNs VoIP sandbox channel is configured to communicate with APNs by using APNs tokens. To provide an authentication key for APNs tokens, set the TokenKey property of the channel.

Id (string) --
(Deprecated) An identifier for the APNs VoIP sandbox channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the APNs VoIP sandbox channel is archived.

LastModifiedBy (string) --
The user who last modified the APNs VoIP sandbox channel.

LastModifiedDate (string) --
The date and time when the APNs VoIP sandbox channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the APNs VoIP sandbox channel, this value is APNS_VOIP_SANDBOX.

Version (integer) --
The current version of the APNs VoIP sandbox channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'APNSVoipSandboxChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'DefaultAuthenticationMethod': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'HasTokenKey': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_application_settings(ApplicationId=None, WriteApplicationSettingsRequest=None):
    """
    Updates the settings for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_application_settings(
        ApplicationId='string',
        WriteApplicationSettingsRequest={
            'CampaignHook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'CloudWatchMetricsEnabled': True|False,
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            }
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type WriteApplicationSettingsRequest: dict
    :param WriteApplicationSettingsRequest: [REQUIRED]\nSpecifies the default settings for an application.\n\nCampaignHook (dict) --The settings for the AWS Lambda function to invoke by default as a code hook for campaigns in the application. You can use this hook to customize segments that are used by campaigns in the application.\nTo override these settings and define custom settings for a specific campaign, use the CampaignHook object of the Campaignresource.\n\nLambdaFunctionName (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.\n\nMode (string) --The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:\n\nFILTER - Invoke the function to customize the segment that\'s used by a campaign.\nDELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.\n\n\nWebUrl (string) --The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.\n\n\n\nCloudWatchMetricsEnabled (boolean) --Specifies whether to enable application-related alarms in Amazon CloudWatch.\n\nLimits (dict) --The default sending limits for campaigns and journeys in the application. To override these limits and define custom limits for a specific campaign or journey, use the Campaignresource or the Journeyresource, respectively.\n\nDaily (integer) --The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.\n\nMaximumDuration (integer) --The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.\n\nMessagesPerSecond (integer) --The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.\n\nTotal (integer) --The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.\n\n\n\nQuietTime (dict) --The default quiet time for campaigns and journeys in the application. Quiet time is a specific time range when messages aren\'t sent to endpoints, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint is set to a valid value.\nThe current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the application (or a campaign or journey that has custom quiet time settings).\nThe current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the application (or a campaign or journey that has custom quiet time settings).\n\nIf any of the preceding conditions isn\'t met, the endpoint will receive messages from a campaign or journey, even if quiet time is enabled.\nTo override the default quiet time settings for a specific campaign or journey, use the Campaignresource or the Journeyresource to define a custom quiet time for the campaign or journey.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationSettingsResource': {
        'ApplicationId': 'string',
        'CampaignHook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

ApplicationSettingsResource (dict) --
Provides information about an application, including the default settings for an application.

ApplicationId (string) --
The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

CampaignHook (dict) --
The settings for the AWS Lambda function to invoke by default as a code hook for campaigns in the application. You can use this hook to customize segments that are used by campaigns in the application.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



LastModifiedDate (string) --
The date and time, in ISO 8601 format, when the application\'s settings were last modified.

Limits (dict) --
The default sending limits for campaigns and journeys in the application.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



QuietTime (dict) --
The default quiet time for campaigns and journeys in the application. Quiet time is a specific time range when messages aren\'t sent to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the application (or a campaign or journey that has custom quiet time settings).
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the application (or a campaign or journey that has custom quiet time settings).

If any of the preceding conditions isn\'t met, the endpoint will receive messages from a campaign or journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.











Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'ApplicationSettingsResource': {
            'ApplicationId': 'string',
            'CampaignHook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            }
        }
    }
    
    
    :returns: 
    FILTER - Invoke the function to customize the segment that\'s used by a campaign.
    DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.
    
    """
    pass

def update_baidu_channel(ApplicationId=None, BaiduChannelRequest=None):
    """
    Enables the Baidu channel for an application or updates the status and settings of the Baidu channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_baidu_channel(
        ApplicationId='string',
        BaiduChannelRequest={
            'ApiKey': 'string',
            'Enabled': True|False,
            'SecretKey': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type BaiduChannelRequest: dict
    :param BaiduChannelRequest: [REQUIRED]\nSpecifies the status and settings of the Baidu (Baidu Cloud Push) channel for an application.\n\nApiKey (string) -- [REQUIRED]The API key that you received from the Baidu Cloud Push service to communicate with the service.\n\nEnabled (boolean) --Specifies whether to enable the Baidu channel for the application.\n\nSecretKey (string) -- [REQUIRED]The secret key that you received from the Baidu Cloud Push service to communicate with the service.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'BaiduChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Credential': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

BaiduChannelResponse (dict) --
Provides information about the status and settings of the Baidu (Baidu Cloud Push) channel for an application.

ApplicationId (string) --
The unique identifier for the application that the Baidu channel applies to.

CreationDate (string) --
The date and time when the Baidu channel was enabled.

Credential (string) --
The API key that you received from the Baidu Cloud Push service to communicate with the service.

Enabled (boolean) --
Specifies whether the Baidu channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

Id (string) --
(Deprecated) An identifier for the Baidu channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the Baidu channel is archived.

LastModifiedBy (string) --
The user who last modified the Baidu channel.

LastModifiedDate (string) --
The date and time when the Baidu channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the Baidu channel, this value is BAIDU.

Version (integer) --
The current version of the Baidu channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'BaiduChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Credential': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_campaign(ApplicationId=None, CampaignId=None, WriteCampaignRequest=None):
    """
    Updates the configuration and other settings for a campaign.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_campaign(
        ApplicationId='string',
        CampaignId='string',
        WriteCampaignRequest={
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'IsPaused': True|False,
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type CampaignId: string
    :param CampaignId: [REQUIRED]\nThe unique identifier for the campaign.\n

    :type WriteCampaignRequest: dict
    :param WriteCampaignRequest: [REQUIRED]\nSpecifies the configuration and other settings for a campaign.\n\nAdditionalTreatments (list) --An array of requests that defines additional treatments for the campaign, in addition to the default treatment for the campaign.\n\n(dict) --Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.\n\nCustomDeliveryConfiguration (dict) --The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.\n\nDeliveryUri (string) -- [REQUIRED]The destination to send the campaign or treatment to. This value can be one of the following:\n\nThe name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.\nThe URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.\n\n\nEndpointTypes (list) --The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.\n\n(string) --\n\n\n\n\nMessageConfiguration (dict) --The message configuration settings for the treatment.\n\nADMMessage (dict) --The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nAPNSMessage (dict) --The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nBaiduMessage (dict) --The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nCustomMessage (dict) --The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.\n\nData (string) --The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.\n\n\n\nDefaultMessage (dict) --The default message that the campaign sends through all the channels that are configured for the campaign.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nEmailMessage (dict) --The message that the campaign sends through the email channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the email for recipients whose email clients don\'t render HTML content.\n\nFromAddress (string) --The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.\n\nHtmlBody (string) --The body of the email, in HTML format, for recipients whose email clients render HTML content.\n\nTitle (string) --The subject line, or title, of the email.\n\n\n\nGCMMessage (dict) --The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nSMSMessage (dict) --The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the SMS message.\n\nMessageType (string) --The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.\n\nSenderId (string) --The sender ID to display on recipients\' devices when they receive the SMS message.\n\n\n\n\n\nSchedule (dict) --The schedule settings for the treatment.\n\nEndTime (string) --The scheduled time, in ISO 8601 format, when the campaign ended or will end.\n\nEventFilter (dict) --The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.\n\nDimensions (dict) -- [REQUIRED]The dimension settings of the event filter for the campaign.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nFilterType (string) -- [REQUIRED]The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.\n\n\n\nFrequency (string) --Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.\n\nIsLocalTime (boolean) --Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.\n\nQuietTime (dict) --The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint is set to a valid value.\nThe current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.\nThe current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.\n\nIf any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\nStartTime (string) -- [REQUIRED]The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.\n\nTimezone (string) --The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.\n\n\n\nSizePercent (integer) -- [REQUIRED]The allocated percentage of users (segment members) to send the treatment to.\n\nTemplateConfiguration (dict) --The message template to use for the treatment.\n\nEmailTemplate (dict) --The email template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nPushTemplate (dict) --The push notification template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nSMSTemplate (dict) --The SMS template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nVoiceTemplate (dict) --The voice template to use for the message. This object isn\'t supported for campaigns.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\n\n\nTreatmentDescription (string) --A custom description of the treatment.\n\nTreatmentName (string) --A custom name for the treatment.\n\n\n\n\n\nCustomDeliveryConfiguration (dict) --The delivery configuration settings for sending the campaign through a custom channel. This object is required if the MessageConfiguration object for the campaign specifies a CustomMessage object.\n\nDeliveryUri (string) -- [REQUIRED]The destination to send the campaign or treatment to. This value can be one of the following:\n\nThe name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.\nThe URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.\n\n\nEndpointTypes (list) --The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.\n\n(string) --\n\n\n\n\nDescription (string) --A custom description of the campaign.\n\nHoldoutPercent (integer) --The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.\n\nHook (dict) --The settings for the AWS Lambda function to invoke as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.\n\nLambdaFunctionName (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.\n\nMode (string) --The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:\n\nFILTER - Invoke the function to customize the segment that\'s used by a campaign.\nDELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.\n\n\nWebUrl (string) --The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.\n\n\n\nIsPaused (boolean) --Specifies whether to pause the campaign. A paused campaign doesn\'t run unless you resume it by changing this value to false.\n\nLimits (dict) --The messaging limits for the campaign.\n\nDaily (integer) --The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.\n\nMaximumDuration (integer) --The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.\n\nMessagesPerSecond (integer) --The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.\n\nTotal (integer) --The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.\n\n\n\nMessageConfiguration (dict) --The message configuration settings for the campaign.\n\nADMMessage (dict) --The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nAPNSMessage (dict) --The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nBaiduMessage (dict) --The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nCustomMessage (dict) --The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.\n\nData (string) --The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.\n\n\n\nDefaultMessage (dict) --The default message that the campaign sends through all the channels that are configured for the campaign.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nEmailMessage (dict) --The message that the campaign sends through the email channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the email for recipients whose email clients don\'t render HTML content.\n\nFromAddress (string) --The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.\n\nHtmlBody (string) --The body of the email, in HTML format, for recipients whose email clients render HTML content.\n\nTitle (string) --The subject line, or title, of the email.\n\n\n\nGCMMessage (dict) --The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.\n\nAction (string) --The action to occur if a recipient taps the push notification. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The body of the notification message. The maximum number of characters is 200.\n\nImageIconUrl (string) --The URL of the image to display as the push-notification icon, such as the icon for the app.\n\nImageSmallIconUrl (string) --The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.\n\nImageUrl (string) --The URL of an image to display in the push notification.\n\nJsonBody (string) --The JSON payload to use for a silent push notification.\n\nMediaUrl (string) --The URL of the image or video to display in the push notification.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.\n\nSilentPush (boolean) --Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.\n\nTimeToLive (integer) --The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.\nThis value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.\n\nTitle (string) --The title to display above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.\n\n\n\nSMSMessage (dict) --The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.\n\nBody (string) --The body of the SMS message.\n\nMessageType (string) --The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.\n\nSenderId (string) --The sender ID to display on recipients\' devices when they receive the SMS message.\n\n\n\n\n\nName (string) --A custom name for the campaign.\n\nSchedule (dict) --The schedule settings for the campaign.\n\nEndTime (string) --The scheduled time, in ISO 8601 format, when the campaign ended or will end.\n\nEventFilter (dict) --The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.\n\nDimensions (dict) -- [REQUIRED]The dimension settings of the event filter for the campaign.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nFilterType (string) -- [REQUIRED]The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.\n\n\n\nFrequency (string) --Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.\n\nIsLocalTime (boolean) --Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.\n\nQuietTime (dict) --The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint is set to a valid value.\nThe current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.\nThe current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.\n\nIf any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\nStartTime (string) -- [REQUIRED]The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.\n\nTimezone (string) --The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.\n\n\n\nSegmentId (string) --The unique identifier for the segment to associate with the campaign.\n\nSegmentVersion (integer) --The version of the segment to associate with the campaign.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the campaign. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateConfiguration (dict) --The message template to use for the campaign.\n\nEmailTemplate (dict) --The email template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nPushTemplate (dict) --The push notification template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nSMSTemplate (dict) --The SMS template to use for the message.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nVoiceTemplate (dict) --The voice template to use for the message. This object isn\'t supported for campaigns.\n\nName (string) --The name of the message template to use for the message. If specified, this value must match the name of an existing message template.\n\nVersion (string) --The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\n\n\nTreatmentDescription (string) --A custom description of the default treatment for the campaign.\n\nTreatmentName (string) --A custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'CampaignResponse': {
        'AdditionalTreatments': [
            {
                'CustomDeliveryConfiguration': {
                    'DeliveryUri': 'string',
                    'EndpointTypes': [
                        'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    ]
                },
                'Id': 'string',
                'MessageConfiguration': {
                    'ADMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'APNSMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'BaiduMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'CustomMessage': {
                        'Data': 'string'
                    },
                    'DefaultMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'EmailMessage': {
                        'Body': 'string',
                        'FromAddress': 'string',
                        'HtmlBody': 'string',
                        'Title': 'string'
                    },
                    'GCMMessage': {
                        'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                        'Body': 'string',
                        'ImageIconUrl': 'string',
                        'ImageSmallIconUrl': 'string',
                        'ImageUrl': 'string',
                        'JsonBody': 'string',
                        'MediaUrl': 'string',
                        'RawContent': 'string',
                        'SilentPush': True|False,
                        'TimeToLive': 123,
                        'Title': 'string',
                        'Url': 'string'
                    },
                    'SMSMessage': {
                        'Body': 'string',
                        'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                        'SenderId': 'string'
                    }
                },
                'Schedule': {
                    'EndTime': 'string',
                    'EventFilter': {
                        'Dimensions': {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'EventType': {
                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            }
                        },
                        'FilterType': 'SYSTEM'|'ENDPOINT'
                    },
                    'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                    'IsLocalTime': True|False,
                    'QuietTime': {
                        'End': 'string',
                        'Start': 'string'
                    },
                    'StartTime': 'string',
                    'Timezone': 'string'
                },
                'SizePercent': 123,
                'State': {
                    'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                },
                'TemplateConfiguration': {
                    'EmailTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'PushTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'SMSTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    },
                    'VoiceTemplate': {
                        'Name': 'string',
                        'Version': 'string'
                    }
                },
                'TreatmentDescription': 'string',
                'TreatmentName': 'string'
            },
        ],
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'CustomDeliveryConfiguration': {
            'DeliveryUri': 'string',
            'EndpointTypes': [
                'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            ]
        },
        'DefaultState': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'Description': 'string',
        'HoldoutPercent': 123,
        'Hook': {
            'LambdaFunctionName': 'string',
            'Mode': 'DELIVERY'|'FILTER',
            'WebUrl': 'string'
        },
        'Id': 'string',
        'IsPaused': True|False,
        'LastModifiedDate': 'string',
        'Limits': {
            'Daily': 123,
            'MaximumDuration': 123,
            'MessagesPerSecond': 123,
            'Total': 123
        },
        'MessageConfiguration': {
            'ADMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'APNSMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'BaiduMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'CustomMessage': {
                'Data': 'string'
            },
            'DefaultMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'EmailMessage': {
                'Body': 'string',
                'FromAddress': 'string',
                'HtmlBody': 'string',
                'Title': 'string'
            },
            'GCMMessage': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageSmallIconUrl': 'string',
                'ImageUrl': 'string',
                'JsonBody': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'SilentPush': True|False,
                'TimeToLive': 123,
                'Title': 'string',
                'Url': 'string'
            },
            'SMSMessage': {
                'Body': 'string',
                'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                'SenderId': 'string'
            }
        },
        'Name': 'string',
        'Schedule': {
            'EndTime': 'string',
            'EventFilter': {
                'Dimensions': {
                    'Attributes': {
                        'string': {
                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        }
                    },
                    'EventType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Metrics': {
                        'string': {
                            'ComparisonOperator': 'string',
                            'Value': 123.0
                        }
                    }
                },
                'FilterType': 'SYSTEM'|'ENDPOINT'
            },
            'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
            'IsLocalTime': True|False,
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'StartTime': 'string',
            'Timezone': 'string'
        },
        'SegmentId': 'string',
        'SegmentVersion': 123,
        'State': {
            'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
        },
        'tags': {
            'string': 'string'
        },
        'TemplateConfiguration': {
            'EmailTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'PushTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'SMSTemplate': {
                'Name': 'string',
                'Version': 'string'
            },
            'VoiceTemplate': {
                'Name': 'string',
                'Version': 'string'
            }
        },
        'TreatmentDescription': 'string',
        'TreatmentName': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

CampaignResponse (dict) --
Provides information about the status, configuration, and other settings for a campaign.

AdditionalTreatments (list) --
An array of responses, one for each treatment that you defined for the campaign, in addition to the default treatment.

(dict) --
Specifies the settings for a campaign treatment. A treatment is a variation of a campaign that\'s used for A/B testing of a campaign.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the treatment through a custom channel. This object is required if the MessageConfiguration object for the treatment specifies a CustomMessage object.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




Id (string) --
The unique identifier for the treatment.

MessageConfiguration (dict) --
The message configuration settings for the treatment.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Schedule (dict) --
The schedule settings for the treatment.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SizePercent (integer) --
The allocated percentage of users (segment members) that the treatment is sent to.

State (dict) --
The current status of the treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



TemplateConfiguration (dict) --
The message template to use for the treatment.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the treatment.

TreatmentName (string) --
The custom name of the treatment.





ApplicationId (string) --
The unique identifier for the application that the campaign applies to.

Arn (string) --
The Amazon Resource Name (ARN) of the campaign.

CreationDate (string) --
The date, in ISO 8601 format, when the campaign was created.

CustomDeliveryConfiguration (dict) --
The delivery configuration settings for sending the campaign through a custom channel.

DeliveryUri (string) --
The destination to send the campaign or treatment to. This value can be one of the following:

The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.


EndpointTypes (list) --
The types of endpoints to send the campaign or treatment to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.

(string) --




DefaultState (dict) --
The current status of the campaign\'s default treatment. This value exists only for campaigns that have more than one treatment.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



Description (string) --
The custom description of the campaign.

HoldoutPercent (integer) --
The allocated percentage of users (segment members) who shouldn\'t receive messages from the campaign.

Hook (dict) --
The settings for the AWS Lambda function to use as a code hook for the campaign. You can use this hook to customize the segment that\'s used by the campaign.

LambdaFunctionName (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to customize a segment for a campaign.

Mode (string) --
The mode that Amazon Pinpoint uses to invoke the AWS Lambda function. Possible values are:

FILTER - Invoke the function to customize the segment that\'s used by a campaign.
DELIVERY - (Deprecated) Previously, invoked the function to send a campaign through a custom channel. This functionality is not supported anymore. To send a campaign through a custom channel, use the CustomDeliveryConfiguration and CampaignCustomMessage objects of the campaign.


WebUrl (string) --
The web URL that Amazon Pinpoint calls to invoke the AWS Lambda function over HTTPS.



Id (string) --
The unique identifier for the campaign.

IsPaused (boolean) --
Specifies whether the campaign is paused. A paused campaign doesn\'t run unless you resume it by changing this value to false.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the campaign was last modified.

Limits (dict) --
The messaging limits for the campaign.

Daily (integer) --
The maximum number of messages that a campaign can send to a single endpoint during a 24-hour period. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send to a single endpoint during a 24-hour period. The maximum value is 100.

MaximumDuration (integer) --
The maximum amount of time, in seconds, that a campaign can attempt to deliver a message after the scheduled start time for the campaign. The minimum value is 60 seconds.

MessagesPerSecond (integer) --
The maximum number of messages that a campaign can send each second. For an application, this value specifies the default limit for the number of messages that campaigns and journeys can send each second. The minimum value is 50. The maximum value is 20,000.

Total (integer) --
The maximum number of messages that a campaign can send to a single endpoint during the course of the campaign. If a campaign recurs, this setting applies to all runs of the campaign. The maximum value is 100.



MessageConfiguration (dict) --
The message configuration settings for the campaign.

ADMMessage (dict) --
The message that the campaign sends through the ADM (Amazon Device Messaging) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



APNSMessage (dict) --
The message that the campaign sends through the APNs (Apple Push Notification service) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



BaiduMessage (dict) --
The message that the campaign sends through the Baidu (Baidu Cloud Push) channel. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



CustomMessage (dict) --
The message that the campaign sends through a custom channel, as specified by the delivery configuration (CustomDeliveryConfiguration) settings for the campaign. If specified, this message overrides the default message.

Data (string) --
The raw, JSON-formatted string to use as the payload for the message. The maximum size is 5 KB.



DefaultMessage (dict) --
The default message that the campaign sends through all the channels that are configured for the campaign.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



EmailMessage (dict) --
The message that the campaign sends through the email channel. If specified, this message overrides the default message.

Body (string) --
The body of the email for recipients whose email clients don\'t render HTML content.

FromAddress (string) --
The verified email address to send the email from. The default address is the FromAddress specified for the email channel for the application.

HtmlBody (string) --
The body of the email, in HTML format, for recipients whose email clients render HTML content.

Title (string) --
The subject line, or title, of the email.



GCMMessage (dict) --
The message that the campaign sends through the GCM channel, which enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. If specified, this message overrides the default message.

Action (string) --
The action to occur if a recipient taps the push notification. Valid values are:

OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of iOS and Android.
URL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.


Body (string) --
The body of the notification message. The maximum number of characters is 200.

ImageIconUrl (string) --
The URL of the image to display as the push-notification icon, such as the icon for the app.

ImageSmallIconUrl (string) --
The URL of the image to display as the small, push-notification icon, such as a small version of the icon for the app.

ImageUrl (string) --
The URL of an image to display in the push notification.

JsonBody (string) --
The JSON payload to use for a silent push notification.

MediaUrl (string) --
The URL of the image or video to display in the push notification.

RawContent (string) --
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

SilentPush (boolean) --
Specifies whether the notification is a silent push notification, which is a push notification that doesn\'t display on a recipient\'s device. Silent push notifications can be used for cases such as updating an app\'s configuration, displaying messages in an in-app message center, or supporting phone home functionality.

TimeToLive (integer) --
The number of seconds that the push-notification service should keep the message, if the service is unable to deliver the notification the first time. This value is converted to an expiration value when it\'s sent to a push-notification service. If this value is 0, the service treats the notification as if it expires immediately and the service doesn\'t store or try to deliver the notification again.
This value doesn\'t apply to messages that are sent through the Amazon Device Messaging (ADM) service.

Title (string) --
The title to display above the notification message on a recipient\'s device.

Url (string) --
The URL to open in a recipient\'s default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.



SMSMessage (dict) --
The message that the campaign sends through the SMS channel. If specified, this message overrides the default message.

Body (string) --
The body of the SMS message.

MessageType (string) --
The type of SMS message. Valid values are: TRANSACTIONAL, the message is critical or time-sensitive, such as a one-time password that supports a customer transaction; and, PROMOTIONAL, the message isn\'t critical or time-sensitive, such as a marketing message.

SenderId (string) --
The sender ID to display on recipients\' devices when they receive the SMS message.





Name (string) --
The name of the campaign.

Schedule (dict) --
The schedule settings for the campaign.

EndTime (string) --
The scheduled time, in ISO 8601 format, when the campaign ended or will end.

EventFilter (dict) --
The type of event that causes the campaign to be sent, if the value of the Frequency property is EVENT.

Dimensions (dict) --
The dimension settings of the event filter for the campaign.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









FilterType (string) --
The type of event that causes the campaign to be sent. Valid values are: SYSTEM, sends the campaign when a system event occurs; and, ENDPOINT, sends the campaign when an endpoint event (Eventsresource) occurs.



Frequency (string) --
Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

IsLocalTime (boolean) --
Specifies whether the start and end times for the campaign schedule use each recipient\'s local time. To base the schedule on each recipient\'s local time, set this value to true.

QuietTime (dict) --
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn\'t send messages to endpoints, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
The current time in the endpoint\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
The current time in the endpoint\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.

If any of the preceding conditions isn\'t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



StartTime (string) --
The scheduled time when the campaign began or will begin. Valid values are: IMMEDIATE, to start the campaign immediately; or, a specific time in ISO 8601 format.

Timezone (string) --
The starting UTC offset for the campaign schedule, if the value of the IsLocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+13, UTC-02, UTC-03, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-10, and UTC-11.



SegmentId (string) --
The unique identifier for the segment that\'s associated with the campaign.

SegmentVersion (integer) --
The version number of the segment that\'s associated with the campaign.

State (dict) --
The current status of the campaign.

CampaignStatus (string) --
The current status of the campaign, or the current status of a treatment that belongs to an A/B test campaign.
If a campaign uses A/B testing, the campaign has a status of COMPLETED only if all campaign treatments have a status of COMPLETED. If you delete the segment that\'s associated with a campaign, the campaign fails and has a status of DELETED.



tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the campaign. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




TemplateConfiguration (dict) --
The message template that\xe2\x80\x99s used for the campaign.

EmailTemplate (dict) --
The email template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



PushTemplate (dict) --
The push notification template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



SMSTemplate (dict) --
The SMS template to use for the message.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



VoiceTemplate (dict) --
The voice template to use for the message. This object isn\'t supported for campaigns.

Name (string) --
The name of the message template to use for the message. If specified, this value must match the name of an existing message template.

Version (string) --
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.





TreatmentDescription (string) --
The custom description of the default treatment for the campaign.

TreatmentName (string) --
The custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that\'s used for A/B testing.

Version (integer) --
The version number of the campaign.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'CampaignResponse': {
            'AdditionalTreatments': [
                {
                    'CustomDeliveryConfiguration': {
                        'DeliveryUri': 'string',
                        'EndpointTypes': [
                            'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                        ]
                    },
                    'Id': 'string',
                    'MessageConfiguration': {
                        'ADMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'APNSMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'BaiduMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'CustomMessage': {
                            'Data': 'string'
                        },
                        'DefaultMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'EmailMessage': {
                            'Body': 'string',
                            'FromAddress': 'string',
                            'HtmlBody': 'string',
                            'Title': 'string'
                        },
                        'GCMMessage': {
                            'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                            'Body': 'string',
                            'ImageIconUrl': 'string',
                            'ImageSmallIconUrl': 'string',
                            'ImageUrl': 'string',
                            'JsonBody': 'string',
                            'MediaUrl': 'string',
                            'RawContent': 'string',
                            'SilentPush': True|False,
                            'TimeToLive': 123,
                            'Title': 'string',
                            'Url': 'string'
                        },
                        'SMSMessage': {
                            'Body': 'string',
                            'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                            'SenderId': 'string'
                        }
                    },
                    'Schedule': {
                        'EndTime': 'string',
                        'EventFilter': {
                            'Dimensions': {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'EventType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                }
                            },
                            'FilterType': 'SYSTEM'|'ENDPOINT'
                        },
                        'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                        'IsLocalTime': True|False,
                        'QuietTime': {
                            'End': 'string',
                            'Start': 'string'
                        },
                        'StartTime': 'string',
                        'Timezone': 'string'
                    },
                    'SizePercent': 123,
                    'State': {
                        'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
                    },
                    'TemplateConfiguration': {
                        'EmailTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'PushTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'SMSTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        },
                        'VoiceTemplate': {
                            'Name': 'string',
                            'Version': 'string'
                        }
                    },
                    'TreatmentDescription': 'string',
                    'TreatmentName': 'string'
                },
            ],
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'CustomDeliveryConfiguration': {
                'DeliveryUri': 'string',
                'EndpointTypes': [
                    'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                ]
            },
            'DefaultState': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'Description': 'string',
            'HoldoutPercent': 123,
            'Hook': {
                'LambdaFunctionName': 'string',
                'Mode': 'DELIVERY'|'FILTER',
                'WebUrl': 'string'
            },
            'Id': 'string',
            'IsPaused': True|False,
            'LastModifiedDate': 'string',
            'Limits': {
                'Daily': 123,
                'MaximumDuration': 123,
                'MessagesPerSecond': 123,
                'Total': 123
            },
            'MessageConfiguration': {
                'ADMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'APNSMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'BaiduMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'CustomMessage': {
                    'Data': 'string'
                },
                'DefaultMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'EmailMessage': {
                    'Body': 'string',
                    'FromAddress': 'string',
                    'HtmlBody': 'string',
                    'Title': 'string'
                },
                'GCMMessage': {
                    'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                    'Body': 'string',
                    'ImageIconUrl': 'string',
                    'ImageSmallIconUrl': 'string',
                    'ImageUrl': 'string',
                    'JsonBody': 'string',
                    'MediaUrl': 'string',
                    'RawContent': 'string',
                    'SilentPush': True|False,
                    'TimeToLive': 123,
                    'Title': 'string',
                    'Url': 'string'
                },
                'SMSMessage': {
                    'Body': 'string',
                    'MessageType': 'TRANSACTIONAL'|'PROMOTIONAL',
                    'SenderId': 'string'
                }
            },
            'Name': 'string',
            'Schedule': {
                'EndTime': 'string',
                'EventFilter': {
                    'Dimensions': {
                        'Attributes': {
                            'string': {
                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                'Values': [
                                    'string',
                                ]
                            }
                        },
                        'EventType': {
                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                            'Values': [
                                'string',
                            ]
                        },
                        'Metrics': {
                            'string': {
                                'ComparisonOperator': 'string',
                                'Value': 123.0
                            }
                        }
                    },
                    'FilterType': 'SYSTEM'|'ENDPOINT'
                },
                'Frequency': 'ONCE'|'HOURLY'|'DAILY'|'WEEKLY'|'MONTHLY'|'EVENT',
                'IsLocalTime': True|False,
                'QuietTime': {
                    'End': 'string',
                    'Start': 'string'
                },
                'StartTime': 'string',
                'Timezone': 'string'
            },
            'SegmentId': 'string',
            'SegmentVersion': 123,
            'State': {
                'CampaignStatus': 'SCHEDULED'|'EXECUTING'|'PENDING_NEXT_RUN'|'COMPLETED'|'PAUSED'|'DELETED'
            },
            'tags': {
                'string': 'string'
            },
            'TemplateConfiguration': {
                'EmailTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'PushTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'SMSTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                },
                'VoiceTemplate': {
                    'Name': 'string',
                    'Version': 'string'
                }
            },
            'TreatmentDescription': 'string',
            'TreatmentName': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
    The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
    
    """
    pass

def update_email_channel(ApplicationId=None, EmailChannelRequest=None):
    """
    Enables the email channel for an application or updates the status and settings of the email channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_email_channel(
        ApplicationId='string',
        EmailChannelRequest={
            'ConfigurationSet': 'string',
            'Enabled': True|False,
            'FromAddress': 'string',
            'Identity': 'string',
            'RoleArn': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EmailChannelRequest: dict
    :param EmailChannelRequest: [REQUIRED]\nSpecifies the status and settings of the email channel for an application.\n\nConfigurationSet (string) --The Amazon SES configuration set that you want to apply to messages that you send through the channel.\n\nEnabled (boolean) --Specifies whether to enable the email channel for the application.\n\nFromAddress (string) -- [REQUIRED]The verified email address that you want to send email from when you send email through the channel.\n\nIdentity (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that you want to use when you send email through the channel.\n\nRoleArn (string) --The ARN of the AWS Identity and Access Management (IAM) role that you want Amazon Pinpoint to use when it submits email-related event data for the channel.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'EmailChannelResponse': {
        'ApplicationId': 'string',
        'ConfigurationSet': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'FromAddress': 'string',
        'HasCredential': True|False,
        'Id': 'string',
        'Identity': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'MessagesPerSecond': 123,
        'Platform': 'string',
        'RoleArn': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

EmailChannelResponse (dict) --
Provides information about the status and settings of the email channel for an application.

ApplicationId (string) --
The unique identifier for the application that the email channel applies to.

ConfigurationSet (string) --
The Amazon SES configuration set that\'s applied to messages that are sent through the channel.

CreationDate (string) --
The date and time, in ISO 8601 format, when the email channel was enabled.

Enabled (boolean) --
Specifies whether the email channel is enabled for the application.

FromAddress (string) --
The verified email address that email is sent from when you send email through the channel.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

Id (string) --
(Deprecated) An identifier for the email channel. This property is retained only for backward compatibility.

Identity (string) --
The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that\'s used when you send email through the channel.

IsArchived (boolean) --
Specifies whether the email channel is archived.

LastModifiedBy (string) --
The user who last modified the email channel.

LastModifiedDate (string) --
The date and time, in ISO 8601 format, when the email channel was last modified.

MessagesPerSecond (integer) --
The maximum number of emails that can be sent through the channel each second.

Platform (string) --
The type of messaging or notification platform for the channel. For the email channel, this value is EMAIL.

RoleArn (string) --
The ARN of the AWS Identity and Access Management (IAM) role that Amazon Pinpoint uses to submit email-related event data for the channel.

Version (integer) --
The current version of the email channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'EmailChannelResponse': {
            'ApplicationId': 'string',
            'ConfigurationSet': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'FromAddress': 'string',
            'HasCredential': True|False,
            'Id': 'string',
            'Identity': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'MessagesPerSecond': 123,
            'Platform': 'string',
            'RoleArn': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_email_template(CreateNewVersion=None, EmailTemplateRequest=None, TemplateName=None, Version=None):
    """
    Updates an existing message template for messages that are sent through the email channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_email_template(
        CreateNewVersion=True|False,
        EmailTemplateRequest={
            'DefaultSubstitutions': 'string',
            'HtmlPart': 'string',
            'RecommenderId': 'string',
            'Subject': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'TextPart': 'string'
        },
        TemplateName='string',
        Version='string'
    )
    
    
    :type CreateNewVersion: boolean
    :param CreateNewVersion: Specifies whether to save the updates as a new version of the message template. Valid values are: true, save the updates as a new version; and, false, save the updates to (overwrite) the latest existing version of the template.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint saves the updates to (overwrites) the latest existing version of the template. If you specify a value of true for this parameter, don\'t specify a value for the version parameter. Otherwise, an error will occur.\n

    :type EmailTemplateRequest: dict
    :param EmailTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in messages that are sent through the email channel.\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nHtmlPart (string) --The message body, in HTML format, to use in email messages that are based on the message template. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.\n\nRecommenderId (string) --The unique identifier for the recommender model to use for the message template. Amazon Pinpoint uses this value to determine how to retrieve and process data from a recommender model when it sends messages that use the template, if the template contains message variables for recommendation data.\n\nSubject (string) --The subject line, or title, to use in email messages that are based on the message template.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\nTextPart (string) --The message body, in plain text format, to use in email messages that are based on the message template. We recommend using plain text format for email clients that don\'t render HTML content and clients that are connected to high-latency networks, such as mobile devices.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_endpoint(ApplicationId=None, EndpointId=None, EndpointRequest=None):
    """
    Creates a new endpoint for an application or updates the settings and attributes of an existing endpoint for an application. You can also use this operation to define custom attributes for an endpoint. If an update includes one or more values for a custom attribute, Amazon Pinpoint replaces (overwrites) any existing values with the new values.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_endpoint(
        ApplicationId='string',
        EndpointId='string',
        EndpointRequest={
            'Address': 'string',
            'Attributes': {
                'string': [
                    'string',
                ]
            },
            'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
            'Demographic': {
                'AppVersion': 'string',
                'Locale': 'string',
                'Make': 'string',
                'Model': 'string',
                'ModelVersion': 'string',
                'Platform': 'string',
                'PlatformVersion': 'string',
                'Timezone': 'string'
            },
            'EffectiveDate': 'string',
            'EndpointStatus': 'string',
            'Location': {
                'City': 'string',
                'Country': 'string',
                'Latitude': 123.0,
                'Longitude': 123.0,
                'PostalCode': 'string',
                'Region': 'string'
            },
            'Metrics': {
                'string': 123.0
            },
            'OptOut': 'string',
            'RequestId': 'string',
            'User': {
                'UserAttributes': {
                    'string': [
                        'string',
                    ]
                },
                'UserId': 'string'
            }
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EndpointId: string
    :param EndpointId: [REQUIRED]\nThe unique identifier for the endpoint.\n

    :type EndpointRequest: dict
    :param EndpointRequest: [REQUIRED]\nSpecifies the channel type and other settings for an endpoint.\n\nAddress (string) --The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For a push-notification channel, use the token provided by the push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. For the SMS channel, use a phone number in E.164 format, such as +12065550100. For the email channel, use an email address.\n\nAttributes (dict) --One or more custom attributes that describe the endpoint by associating a name with an array of values. For example, the value of a custom attribute named Interests might be: ['Science', 'Music', 'Travel']. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.\nAn attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nChannelType (string) --The channel to use when sending messages or push notifications to the endpoint.\n\nDemographic (dict) --The demographic information for the endpoint, such as the time zone and platform.\n\nAppVersion (string) --The version of the app that\'s associated with the endpoint.\n\nLocale (string) --The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.\n\nMake (string) --The manufacturer of the endpoint device, such as apple or samsung.\n\nModel (string) --The model name or number of the endpoint device, such as iPhone or SM-G900F.\n\nModelVersion (string) --The model version of the endpoint device.\n\nPlatform (string) --The platform of the endpoint device, such as ios.\n\nPlatformVersion (string) --The platform version of the endpoint device.\n\nTimezone (string) --The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.\n\n\n\nEffectiveDate (string) --The date and time, in ISO 8601 format, when the endpoint is updated.\n\nEndpointStatus (string) --Specifies whether to send messages or push notifications to the endpoint. Valid values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.\nAmazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.\n\nLocation (dict) --The geographic information for the endpoint.\n\nCity (string) --The name of the city where the endpoint is located.\n\nCountry (string) --The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.\n\nLatitude (float) --The latitude coordinate of the endpoint location, rounded to one decimal place.\n\nLongitude (float) --The longitude coordinate of the endpoint location, rounded to one decimal place.\n\nPostalCode (string) --The postal or ZIP code for the area where the endpoint is located.\n\nRegion (string) --The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.\n\n\n\nMetrics (dict) --One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.\n\n(string) --\n(float) --\n\n\n\n\nOptOut (string) --Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.\n\nRequestId (string) --The unique identifier for the most recent request to update the endpoint.\n\nUser (dict) --One or more custom attributes that describe the user who\'s associated with the endpoint.\n\nUserAttributes (dict) --One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ['Science', 'Music', 'Travel']. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.\nAn attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nUserId (string) --The unique identifier for the user.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_endpoints_batch(ApplicationId=None, EndpointBatchRequest=None):
    """
    Creates a new batch of endpoints for an application or updates the settings and attributes of a batch of existing endpoints for an application. You can also use this operation to define custom attributes for a batch of endpoints. If an update includes one or more values for a custom attribute, Amazon Pinpoint replaces (overwrites) any existing values with the new values.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_endpoints_batch(
        ApplicationId='string',
        EndpointBatchRequest={
            'Item': [
                {
                    'Address': 'string',
                    'Attributes': {
                        'string': [
                            'string',
                        ]
                    },
                    'ChannelType': 'GCM'|'APNS'|'APNS_SANDBOX'|'APNS_VOIP'|'APNS_VOIP_SANDBOX'|'ADM'|'SMS'|'VOICE'|'EMAIL'|'BAIDU'|'CUSTOM',
                    'Demographic': {
                        'AppVersion': 'string',
                        'Locale': 'string',
                        'Make': 'string',
                        'Model': 'string',
                        'ModelVersion': 'string',
                        'Platform': 'string',
                        'PlatformVersion': 'string',
                        'Timezone': 'string'
                    },
                    'EffectiveDate': 'string',
                    'EndpointStatus': 'string',
                    'Id': 'string',
                    'Location': {
                        'City': 'string',
                        'Country': 'string',
                        'Latitude': 123.0,
                        'Longitude': 123.0,
                        'PostalCode': 'string',
                        'Region': 'string'
                    },
                    'Metrics': {
                        'string': 123.0
                    },
                    'OptOut': 'string',
                    'RequestId': 'string',
                    'User': {
                        'UserAttributes': {
                            'string': [
                                'string',
                            ]
                        },
                        'UserId': 'string'
                    }
                },
            ]
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type EndpointBatchRequest: dict
    :param EndpointBatchRequest: [REQUIRED]\nSpecifies a batch of endpoints to create or update and the settings and attributes to set or change for each endpoint.\n\nItem (list) -- [REQUIRED]An array that defines the endpoints to create or update and, for each endpoint, the property values to set or change. An array can contain a maximum of 100 items.\n\n(dict) --Specifies an endpoint to create or update and the settings and attributes to set or change for the endpoint.\n\nAddress (string) --The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For a push-notification channel, use the token provided by the push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. For the SMS channel, use a phone number in E.164 format, such as +12065550100. For the email channel, use an email address.\n\nAttributes (dict) --One or more custom attributes that describe the endpoint by associating a name with an array of values. For example, the value of a custom attribute named Interests might be: ['Science', 'Music', 'Travel']. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.\nAn attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nChannelType (string) --The channel to use when sending messages or push notifications to the endpoint.\n\nDemographic (dict) --The demographic information for the endpoint, such as the time zone and platform.\n\nAppVersion (string) --The version of the app that\'s associated with the endpoint.\n\nLocale (string) --The locale of the endpoint, in the following format: the ISO 639-1 alpha-2 code, followed by an underscore (_), followed by an ISO 3166-1 alpha-2 value.\n\nMake (string) --The manufacturer of the endpoint device, such as apple or samsung.\n\nModel (string) --The model name or number of the endpoint device, such as iPhone or SM-G900F.\n\nModelVersion (string) --The model version of the endpoint device.\n\nPlatform (string) --The platform of the endpoint device, such as ios.\n\nPlatformVersion (string) --The platform version of the endpoint device.\n\nTimezone (string) --The time zone of the endpoint, specified as a tz database name value, such as America/Los_Angeles.\n\n\n\nEffectiveDate (string) --The date and time, in ISO 8601 format, when the endpoint was created or updated.\n\nEndpointStatus (string) --Specifies whether to send messages or push notifications to the endpoint. Valid values are: ACTIVE, messages are sent to the endpoint; and, INACTIVE, messages aren\xe2\x80\x99t sent to the endpoint.\nAmazon Pinpoint automatically sets this value to ACTIVE when you create an endpoint or update an existing endpoint. Amazon Pinpoint automatically sets this value to INACTIVE if you update another endpoint that has the same address specified by the Address property.\n\nId (string) --The unique identifier for the endpoint in the context of the batch.\n\nLocation (dict) --The geographic information for the endpoint.\n\nCity (string) --The name of the city where the endpoint is located.\n\nCountry (string) --The two-character code, in ISO 3166-1 alpha-2 format, for the country or region where the endpoint is located. For example, US for the United States.\n\nLatitude (float) --The latitude coordinate of the endpoint location, rounded to one decimal place.\n\nLongitude (float) --The longitude coordinate of the endpoint location, rounded to one decimal place.\n\nPostalCode (string) --The postal or ZIP code for the area where the endpoint is located.\n\nRegion (string) --The name of the region where the endpoint is located. For locations in the United States, this value is the name of a state.\n\n\n\nMetrics (dict) --One or more custom metrics that your app reports to Amazon Pinpoint for the endpoint.\n\n(string) --\n(float) --\n\n\n\n\nOptOut (string) --Specifies whether the user who\'s associated with the endpoint has opted out of receiving messages and push notifications from you. Possible values are: ALL, the user has opted out and doesn\'t want to receive any messages or push notifications; and, NONE, the user hasn\'t opted out and wants to receive all messages and push notifications.\n\nRequestId (string) --The unique identifier for the request to create or update the endpoint.\n\nUser (dict) --One or more custom attributes that describe the user who\'s associated with the endpoint.\n\nUserAttributes (dict) --One or more custom attributes that describe the user by associating a name with an array of values. For example, the value of an attribute named Interests might be: ['Science', 'Music', 'Travel']. You can use these attributes as filter criteria when you create segments. Attribute names are case sensitive.\nAn attribute name can contain up to 50 characters. An attribute value can contain up to 100 characters. When you define the name of a custom attribute, avoid using the following characters: number sign (#), colon (:), question mark (?), backslash (), and slash (/). The Amazon Pinpoint console can\'t display attribute names that contain these characters. This restriction doesn\'t apply to attribute values.\n\n(string) --\n(list) --\n(string) --\n\n\n\n\n\n\nUserId (string) --The unique identifier for the user.\n\n\n\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_gcm_channel(ApplicationId=None, GCMChannelRequest=None):
    """
    Enables the GCM channel for an application or updates the status and settings of the GCM channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_gcm_channel(
        ApplicationId='string',
        GCMChannelRequest={
            'ApiKey': 'string',
            'Enabled': True|False
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type GCMChannelRequest: dict
    :param GCMChannelRequest: [REQUIRED]\nSpecifies the status and settings of the GCM channel for an application. This channel enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service.\n\nApiKey (string) -- [REQUIRED]The Web API Key, also referred to as an API_KEY or server key , that you received from Google to communicate with Google services.\n\nEnabled (boolean) --Specifies whether to enable the GCM channel for the application.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'GCMChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Credential': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

GCMChannelResponse (dict) --
Provides information about the status and settings of the GCM channel for an application. The GCM channel enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service.

ApplicationId (string) --
The unique identifier for the application that the GCM channel applies to.

CreationDate (string) --
The date and time when the GCM channel was enabled.

Credential (string) --
The Web API Key, also referred to as an API_KEY or server key , that you received from Google to communicate with Google services.

Enabled (boolean) --
Specifies whether the GCM channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

Id (string) --
(Deprecated) An identifier for the GCM channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the GCM channel is archived.

LastModifiedBy (string) --
The user who last modified the GCM channel.

LastModifiedDate (string) --
The date and time when the GCM channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the GCM channel, this value is GCM.

Version (integer) --
The current version of the GCM channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'GCMChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Credential': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_journey(ApplicationId=None, JourneyId=None, WriteJourneyRequest=None):
    """
    Updates the configuration and other settings for a journey.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_journey(
        ApplicationId='string',
        JourneyId='string',
        WriteJourneyRequest={
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'CreationDate': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :type WriteJourneyRequest: dict
    :param WriteJourneyRequest: [REQUIRED]\nSpecifies the configuration and other settings for a journey.\n\nActivities (dict) --A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity. An activity identifier can contain a maximum of 100 characters. The characters must be alphanumeric characters.\n\n(string) --\n(dict) --Specifies the configuration and other settings for an activity in a journey.\n\nConditionalSplit (dict) --The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.\n\nCondition (dict) --The conditions that define the paths for the activity, and the relationship between the conditions.\n\nConditions (list) --The conditions to evaluate for the activity.\n\n(dict) --Specifies a condition to evaluate for an activity in a journey.\n\nEventCondition (dict) --The dimension settings for the event that\'s associated with the activity.\n\nDimensions (dict) --The dimensions for the event filter to use for the activity.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nMessageActivity (string) --The message identifier (message_id) for the message to use when determining whether message events meet the condition.\n\n\n\nSegmentCondition (dict) --The segment that\'s associated with the activity.\n\nSegmentId (string) -- [REQUIRED]The unique identifier for the segment to associate with the activity.\n\n\n\nSegmentDimensions (dict) --The dimension settings for the segment that\'s associated with the activity.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nOperator (string) --Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.\n\n\n\nEvaluationWaitTime (dict) --The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.\n\nWaitFor (string) --The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.\n\nWaitUntil (string) --The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.\n\n\n\nFalseActivity (string) --The unique identifier for the activity to perform if the conditions aren\'t met.\n\nTrueActivity (string) --The unique identifier for the activity to perform if the conditions are met.\n\n\n\nDescription (string) --The custom description of the activity.\n\nEMAIL (dict) --The settings for an email activity. This type of activity sends an email message to participants.\n\nMessageConfig (dict) --The 'From' address to use for the message.\n\nFromAddress (string) --The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.\n\n\n\nNextActivity (string) --The unique identifier for the next activity to perform, after the message is sent.\n\nTemplateName (string) --The name of the email template to use for the message.\n\nTemplateVersion (string) --The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\nIf you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.\n\n\n\nHoldout (dict) --The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.\n\nNextActivity (string) --The unique identifier for the next activity to perform, after performing the holdout activity.\n\nPercentage (integer) -- [REQUIRED]The percentage of participants who shouldn\'t continue the journey.\nTo determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.\n\n\n\nMultiCondition (dict) --The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.\n\nBranches (list) --The paths for the activity, including the conditions for entering each path and the activity to perform for each path.\n\n(dict) --Specifies a condition to evaluate for an activity path in a journey.\n\nCondition (dict) --The condition to evaluate for the activity path.\n\nEventCondition (dict) --The dimension settings for the event that\'s associated with the activity.\n\nDimensions (dict) --The dimensions for the event filter to use for the activity.\n\nAttributes (dict) --One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nEventType (dict) --The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMetrics (dict) --One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\n\n\nMessageActivity (string) --The message identifier (message_id) for the message to use when determining whether message events meet the condition.\n\n\n\nSegmentCondition (dict) --The segment that\'s associated with the activity.\n\nSegmentId (string) -- [REQUIRED]The unique identifier for the segment to associate with the activity.\n\n\n\nSegmentDimensions (dict) --The dimension settings for the segment that\'s associated with the activity.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n\nNextActivity (string) --The unique identifier for the next activity to perform, after completing the activity for the path.\n\n\n\n\n\nDefaultActivity (string) --The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.\n\nEvaluationWaitTime (dict) --The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.\n\nWaitFor (string) --The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.\n\nWaitUntil (string) --The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.\n\n\n\n\n\nRandomSplit (dict) --The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.\n\nBranches (list) --The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.\n\n(dict) --Specifies the settings for a path in a random split activity in a journey.\n\nNextActivity (string) --The unique identifier for the next activity to perform, after completing the activity for the path.\n\nPercentage (integer) --The percentage of participants to send down the activity path.\nTo determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.\n\n\n\n\n\n\n\nWait (dict) --The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.\n\nNextActivity (string) --The unique identifier for the next activity to perform, after performing the wait activity.\n\nWaitTime (dict) --The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.\n\nWaitFor (string) --The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.\n\nWaitUntil (string) --The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.\n\n\n\n\n\n\n\n\n\n\n\nCreationDate (string) --The date, in ISO 8601 format, when the journey was created.\n\nLastModifiedDate (string) --The date, in ISO 8601 format, when the journey was last modified.\n\nLimits (dict) --The messaging and entry limits for the journey.\n\nDailyCap (integer) --The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.\n\nEndpointReentryCap (integer) --The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.\n\nMessagesPerSecond (integer) --The maximum number of messages that the journey can send each second.\n\n\n\nLocalTime (boolean) --Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. To base the schedule on each participant\'s local time, set this value to true.\n\nName (string) -- [REQUIRED]The name of the journey. A journey name can contain a maximum of 150 characters. The characters can be alphanumeric characters or symbols, such as underscores (_) or hyphens (-). A journey name can\'t contain any spaces.\n\nQuietTime (dict) --The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:\n\nThe EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.\nThe current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.\nThe current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.\n\nIf any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.\n\nEnd (string) --The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\nStart (string) --The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.\n\n\n\nRefreshFrequency (string) --The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.\n\nSchedule (dict) --The schedule settings for the journey.\n\nEndTime (datetime) --The scheduled time, in ISO 8601 format, when the journey ended or will end.\n\nStartTime (datetime) --The scheduled time, in ISO 8601 format, when the journey began or will begin.\n\nTimezone (string) --The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.\n\n\n\nStartActivity (string) --The unique identifier for the first activity in the journey. The identifier for this activity can contain a maximum of 128 characters. The characters must be alphanumeric characters.\n\nStartCondition (dict) --The segment that defines which users are participants in the journey.\n\nDescription (string) --The custom description of the condition.\n\nSegmentStartCondition (dict) --The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.\n\nSegmentId (string) -- [REQUIRED]The unique identifier for the segment to associate with the activity.\n\n\n\n\n\nState (string) --The status of the journey. Valid values are:\n\nDRAFT - Saves the journey and doesn\'t publish it.\nACTIVE - Saves and publishes the journey. Depending on the journey\'s schedule, the journey starts running immediately or at the scheduled start time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.\n\nThe CANCELLED, COMPLETED, and CLOSED values are not supported in requests to create or update a journey. To cancel a journey, use the Journey Stateresource.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyResponse': {
        'Activities': {
            'string': {
                'ConditionalSplit': {
                    'Condition': {
                        'Conditions': [
                            {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                        ],
                        'Operator': 'ALL'|'ANY'
                    },
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    },
                    'FalseActivity': 'string',
                    'TrueActivity': 'string'
                },
                'Description': 'string',
                'EMAIL': {
                    'MessageConfig': {
                        'FromAddress': 'string'
                    },
                    'NextActivity': 'string',
                    'TemplateName': 'string',
                    'TemplateVersion': 'string'
                },
                'Holdout': {
                    'NextActivity': 'string',
                    'Percentage': 123
                },
                'MultiCondition': {
                    'Branches': [
                        {
                            'Condition': {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                            'NextActivity': 'string'
                        },
                    ],
                    'DefaultActivity': 'string',
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                },
                'RandomSplit': {
                    'Branches': [
                        {
                            'NextActivity': 'string',
                            'Percentage': 123
                        },
                    ]
                },
                'Wait': {
                    'NextActivity': 'string',
                    'WaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                }
            }
        },
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Limits': {
            'DailyCap': 123,
            'EndpointReentryCap': 123,
            'MessagesPerSecond': 123
        },
        'LocalTime': True|False,
        'Name': 'string',
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        },
        'RefreshFrequency': 'string',
        'Schedule': {
            'EndTime': datetime(2015, 1, 1),
            'StartTime': datetime(2015, 1, 1),
            'Timezone': 'string'
        },
        'StartActivity': 'string',
        'StartCondition': {
            'Description': 'string',
            'SegmentStartCondition': {
                'SegmentId': 'string'
            }
        },
        'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyResponse (dict) --
Provides information about the status, configuration, and other settings for a journey.

Activities (dict) --
A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity.

(string) --

(dict) --
Specifies the configuration and other settings for an activity in a journey.

ConditionalSplit (dict) --
The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.

Condition (dict) --
The conditions that define the paths for the activity, and the relationship between the conditions.

Conditions (list) --
The conditions to evaluate for the activity.

(dict) --
Specifies a condition to evaluate for an activity in a journey.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --














Operator (string) --
Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.



EvaluationWaitTime (dict) --
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.



FalseActivity (string) --
The unique identifier for the activity to perform if the conditions aren\'t met.

TrueActivity (string) --
The unique identifier for the activity to perform if the conditions are met.



Description (string) --
The custom description of the activity.

EMAIL (dict) --
The settings for an email activity. This type of activity sends an email message to participants.

MessageConfig (dict) --
The "From" address to use for the message.

FromAddress (string) --
The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.



NextActivity (string) --
The unique identifier for the next activity to perform, after the message is sent.

TemplateName (string) --
The name of the email template to use for the message.

TemplateVersion (string) --
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



Holdout (dict) --
The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the holdout activity.

Percentage (integer) --
The percentage of participants who shouldn\'t continue the journey.
To determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.



MultiCondition (dict) --
The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.

(dict) --
Specifies a condition to evaluate for an activity path in a journey.

Condition (dict) --
The condition to evaluate for the activity path.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.





DefaultActivity (string) --
The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.

EvaluationWaitTime (dict) --
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.





RandomSplit (dict) --
The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.

(dict) --
Specifies the settings for a path in a random split activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.

Percentage (integer) --
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.







Wait (dict) --
The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the wait activity.

WaitTime (dict) --
The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.











ApplicationId (string) --
The unique identifier for the application that the journey applies to.

CreationDate (string) --
The date, in ISO 8601 format, when the journey was created.

Id (string) --
The unique identifier for the journey.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the journey was last modified.

Limits (dict) --
The messaging and entry limits for the journey.

DailyCap (integer) --
The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.

EndpointReentryCap (integer) --
The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.

MessagesPerSecond (integer) --
The maximum number of messages that the journey can send each second.



LocalTime (boolean) --
Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. If this value is true, the schedule uses each participant\'s local time.

Name (string) --
The name of the journey.

QuietTime (dict) --
The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.
The current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.
The current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.

If any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



RefreshFrequency (string) --
The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.

Schedule (dict) --
The schedule settings for the journey.

EndTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey ended or will end.

StartTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey began or will begin.

Timezone (string) --
The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.



StartActivity (string) --
The unique identifier for the first activity in the journey.

StartCondition (dict) --
The segment that defines which users are participants in the journey.

Description (string) --
The custom description of the condition.

SegmentStartCondition (dict) --
The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.





State (string) --
The current status of the journey. Possible values are:

DRAFT - The journey is being developed and hasn\'t been published yet.
ACTIVE - The journey has been developed and published. Depending on the journey\'s schedule, the journey may currently be running or scheduled to start running at a later time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.
COMPLETED - The journey has been published and has finished running. All participants have entered the journey and no participants are waiting to complete the journey or any activities in the journey.
CANCELLED - The journey has been stopped. If a journey\'s status is CANCELLED, you can\'t add, change, or remove activities or segment settings from the journey.
CLOSED - The journey has been published and has started running. It may have also passed its scheduled end time, or passed its scheduled start time and a refresh frequency hasn\'t been specified for it. If a journey\'s status is CLOSED, you can\'t add participants to it, and no existing participants can enter the journey for the first time. However, any existing participants who are currently waiting to start an activity may continue the journey.


tags (dict) --
This object is not used or supported.

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyResponse': {
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def update_journey_state(ApplicationId=None, JourneyId=None, JourneyStateRequest=None):
    """
    Cancels (stops) an active journey.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_journey_state(
        ApplicationId='string',
        JourneyId='string',
        JourneyStateRequest={
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type JourneyId: string
    :param JourneyId: [REQUIRED]\nThe unique identifier for the journey.\n

    :type JourneyStateRequest: dict
    :param JourneyStateRequest: [REQUIRED]\nChanges the status of a journey.\n\nState (string) --The status of the journey. Currently, the only supported value is CANCELLED.\nIf you cancel a journey, Amazon Pinpoint continues to perform activities that are currently in progress, until those activities are complete. Amazon Pinpoint also continues to collect and aggregate analytics data for those activities, until they are complete, and any activities that were complete when you cancelled the journey.\nAfter you cancel a journey, you can\'t add, change, or remove any activities from the journey. In addition, Amazon Pinpoint stops evaluating the journey and doesn\'t perform any activities that haven\'t started.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'JourneyResponse': {
        'Activities': {
            'string': {
                'ConditionalSplit': {
                    'Condition': {
                        'Conditions': [
                            {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                        ],
                        'Operator': 'ALL'|'ANY'
                    },
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    },
                    'FalseActivity': 'string',
                    'TrueActivity': 'string'
                },
                'Description': 'string',
                'EMAIL': {
                    'MessageConfig': {
                        'FromAddress': 'string'
                    },
                    'NextActivity': 'string',
                    'TemplateName': 'string',
                    'TemplateVersion': 'string'
                },
                'Holdout': {
                    'NextActivity': 'string',
                    'Percentage': 123
                },
                'MultiCondition': {
                    'Branches': [
                        {
                            'Condition': {
                                'EventCondition': {
                                    'Dimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'EventType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        }
                                    },
                                    'MessageActivity': 'string'
                                },
                                'SegmentCondition': {
                                    'SegmentId': 'string'
                                },
                                'SegmentDimensions': {
                                    'Attributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Behavior': {
                                        'Recency': {
                                            'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                            'RecencyType': 'ACTIVE'|'INACTIVE'
                                        }
                                    },
                                    'Demographic': {
                                        'AppVersion': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Channel': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'DeviceType': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Make': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Model': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'Platform': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    },
                                    'Location': {
                                        'Country': {
                                            'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        },
                                        'GPSPoint': {
                                            'Coordinates': {
                                                'Latitude': 123.0,
                                                'Longitude': 123.0
                                            },
                                            'RangeInKilometers': 123.0
                                        }
                                    },
                                    'Metrics': {
                                        'string': {
                                            'ComparisonOperator': 'string',
                                            'Value': 123.0
                                        }
                                    },
                                    'UserAttributes': {
                                        'string': {
                                            'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                            'Values': [
                                                'string',
                                            ]
                                        }
                                    }
                                }
                            },
                            'NextActivity': 'string'
                        },
                    ],
                    'DefaultActivity': 'string',
                    'EvaluationWaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                },
                'RandomSplit': {
                    'Branches': [
                        {
                            'NextActivity': 'string',
                            'Percentage': 123
                        },
                    ]
                },
                'Wait': {
                    'NextActivity': 'string',
                    'WaitTime': {
                        'WaitFor': 'string',
                        'WaitUntil': 'string'
                    }
                }
            }
        },
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Limits': {
            'DailyCap': 123,
            'EndpointReentryCap': 123,
            'MessagesPerSecond': 123
        },
        'LocalTime': True|False,
        'Name': 'string',
        'QuietTime': {
            'End': 'string',
            'Start': 'string'
        },
        'RefreshFrequency': 'string',
        'Schedule': {
            'EndTime': datetime(2015, 1, 1),
            'StartTime': datetime(2015, 1, 1),
            'Timezone': 'string'
        },
        'StartActivity': 'string',
        'StartCondition': {
            'Description': 'string',
            'SegmentStartCondition': {
                'SegmentId': 'string'
            }
        },
        'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
The request succeeded.

JourneyResponse (dict) --
Provides information about the status, configuration, and other settings for a journey.

Activities (dict) --
A map that contains a set of Activity objects, one object for each activity in the journey. For each Activity object, the key is the unique identifier (string) for an activity and the value is the settings for the activity.

(string) --

(dict) --
Specifies the configuration and other settings for an activity in a journey.

ConditionalSplit (dict) --
The settings for a yes/no split activity. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.

Condition (dict) --
The conditions that define the paths for the activity, and the relationship between the conditions.

Conditions (list) --
The conditions to evaluate for the activity.

(dict) --
Specifies a condition to evaluate for an activity in a journey.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --














Operator (string) --
Specifies how to handle multiple conditions for the activity. For example, if you specify two conditions for an activity, whether both or only one of the conditions must be met for the activity to be performed.



EvaluationWaitTime (dict) --
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.



FalseActivity (string) --
The unique identifier for the activity to perform if the conditions aren\'t met.

TrueActivity (string) --
The unique identifier for the activity to perform if the conditions are met.



Description (string) --
The custom description of the activity.

EMAIL (dict) --
The settings for an email activity. This type of activity sends an email message to participants.

MessageConfig (dict) --
The "From" address to use for the message.

FromAddress (string) --
The verified email address to send the email message from. The default address is the FromAddress specified for the email channel for the application.



NextActivity (string) --
The unique identifier for the next activity to perform, after the message is sent.

TemplateName (string) --
The name of the email template to use for the message.

TemplateVersion (string) --
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.
If you don\'t specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that\'s been most recently reviewed and approved for use, depending on your workflow. It isn\'t necessarily the latest version of a template.



Holdout (dict) --
The settings for a holdout activity. This type of activity stops a journey for a specified percentage of participants.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the holdout activity.

Percentage (integer) --
The percentage of participants who shouldn\'t continue the journey.
To determine which participants are held out, Amazon Pinpoint applies a probability-based algorithm to the percentage that you specify. Therefore, the actual percentage of participants who are held out may not be equal to the percentage that you specify.



MultiCondition (dict) --
The settings for a multivariate split activity. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.

(dict) --
Specifies a condition to evaluate for an activity path in a journey.

Condition (dict) --
The condition to evaluate for the activity path.

EventCondition (dict) --
The dimension settings for the event that\'s associated with the activity.

Dimensions (dict) --
The dimensions for the event filter to use for the activity.

Attributes (dict) --
One or more custom attributes that your application reports to Amazon Pinpoint. You can use these attributes as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








EventType (dict) --
The name of the event that causes the campaign to be sent or the journey activity to be performed. This can be a standard event that Amazon Pinpoint generates, such as _email.delivered. For campaigns, this can also be a custom event that\'s specific to your application. For information about standard events, see Streaming Amazon Pinpoint Events in the Amazon Pinpoint Developer Guide .

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Metrics (dict) --
One or more custom metrics that your application reports to Amazon Pinpoint. You can use these metrics as selection criteria when you create an event filter.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.









MessageActivity (string) --
The message identifier (message_id) for the message to use when determining whether message events meet the condition.



SegmentCondition (dict) --
The segment that\'s associated with the activity.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.



SegmentDimensions (dict) --
The dimension settings for the segment that\'s associated with the activity.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.





DefaultActivity (string) --
The unique identifier for the activity to perform for participants who don\'t meet any of the conditions specified for other paths in the activity.

EvaluationWaitTime (dict) --
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.





RandomSplit (dict) --
The settings for a random split activity. This type of activity randomly sends specified percentages of participants down one of as many as five paths in a journey, based on conditions that you specify.

Branches (list) --
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.

(dict) --
Specifies the settings for a path in a random split activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after completing the activity for the path.

Percentage (integer) --
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.







Wait (dict) --
The settings for a wait activity. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.

NextActivity (string) --
The unique identifier for the next activity to perform, after performing the wait activity.

WaitTime (dict) --
The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.

WaitFor (string) --
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity\'s conditions have been met or moving participants to the next activity in the journey.

WaitUntil (string) --
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity\'s conditions have been met or the activity moves participants to the next activity in the journey.











ApplicationId (string) --
The unique identifier for the application that the journey applies to.

CreationDate (string) --
The date, in ISO 8601 format, when the journey was created.

Id (string) --
The unique identifier for the journey.

LastModifiedDate (string) --
The date, in ISO 8601 format, when the journey was last modified.

Limits (dict) --
The messaging and entry limits for the journey.

DailyCap (integer) --
The maximum number of messages that the journey can send to a single participant during a 24-hour period. The maximum value is 100.

EndpointReentryCap (integer) --
The maximum number of times that a participant can enter the journey. The maximum value is 100. To allow participants to enter the journey an unlimited number of times, set this value to 0.

MessagesPerSecond (integer) --
The maximum number of messages that the journey can send each second.



LocalTime (boolean) --
Specifies whether the journey\'s scheduled start and end times use each participant\'s local time. If this value is true, the schedule uses each participant\'s local time.

Name (string) --
The name of the journey.

QuietTime (dict) --
The quiet time settings for the journey. Quiet time is a specific time range when a journey doesn\'t send messages to participants, if all the following conditions are met:

The EndpointDemographic.Timezone property of the endpoint for the participant is set to a valid value.
The current time in the participant\'s time zone is later than or equal to the time specified by the QuietTime.Start property for the journey.
The current time in the participant\'s time zone is earlier than or equal to the time specified by the QuietTime.End property for the journey.

If any of the preceding conditions isn\'t met, the participant will receive messages from the journey, even if quiet time is enabled.

End (string) --
The specific time when quiet time ends. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.

Start (string) --
The specific time when quiet time begins. This value has to use 24-hour notation and be in HH:MM format, where HH is the hour (with a leading zero, if applicable) and MM is the minutes. For example, use 02:30 to represent 2:30 AM, or 14:30 to represent 2:30 PM.



RefreshFrequency (string) --
The frequency with which Amazon Pinpoint evaluates segment and event data for the journey, as a duration in ISO 8601 format.

Schedule (dict) --
The schedule settings for the journey.

EndTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey ended or will end.

StartTime (datetime) --
The scheduled time, in ISO 8601 format, when the journey began or will begin.

Timezone (string) --
The starting UTC offset for the journey schedule, if the value of the journey\'s LocalTime property is true. Valid values are: UTC, UTC+01, UTC+02, UTC+03, UTC+03:30, UTC+04, UTC+04:30, UTC+05, UTC+05:30, UTC+05:45, UTC+06, UTC+06:30, UTC+07, UTC+08, UTC+08:45, UTC+09, UTC+09:30, UTC+10, UTC+10:30, UTC+11, UTC+12, UTC+12:45, UTC+13, UTC+13:45, UTC-02, UTC-02:30, UTC-03, UTC-03:30, UTC-04, UTC-05, UTC-06, UTC-07, UTC-08, UTC-09, UTC-09:30, UTC-10, and UTC-11.



StartActivity (string) --
The unique identifier for the first activity in the journey.

StartCondition (dict) --
The segment that defines which users are participants in the journey.

Description (string) --
The custom description of the condition.

SegmentStartCondition (dict) --
The segment that\'s associated with the first activity in the journey. This segment determines which users are participants in the journey.

SegmentId (string) --
The unique identifier for the segment to associate with the activity.





State (string) --
The current status of the journey. Possible values are:

DRAFT - The journey is being developed and hasn\'t been published yet.
ACTIVE - The journey has been developed and published. Depending on the journey\'s schedule, the journey may currently be running or scheduled to start running at a later time. If a journey\'s status is ACTIVE, you can\'t add, change, or remove activities from it.
COMPLETED - The journey has been published and has finished running. All participants have entered the journey and no participants are waiting to complete the journey or any activities in the journey.
CANCELLED - The journey has been stopped. If a journey\'s status is CANCELLED, you can\'t add, change, or remove activities or segment settings from the journey.
CLOSED - The journey has been published and has started running. It may have also passed its scheduled end time, or passed its scheduled start time and a refresh frequency hasn\'t been specified for it. If a journey\'s status is CLOSED, you can\'t add participants to it, and no existing participants can enter the journey for the first time. However, any existing participants who are currently waiting to start an activity may continue the journey.


tags (dict) --
This object is not used or supported.

(string) --
(string) --












Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'JourneyResponse': {
            'Activities': {
                'string': {
                    'ConditionalSplit': {
                        'Condition': {
                            'Conditions': [
                                {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                            ],
                            'Operator': 'ALL'|'ANY'
                        },
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        },
                        'FalseActivity': 'string',
                        'TrueActivity': 'string'
                    },
                    'Description': 'string',
                    'EMAIL': {
                        'MessageConfig': {
                            'FromAddress': 'string'
                        },
                        'NextActivity': 'string',
                        'TemplateName': 'string',
                        'TemplateVersion': 'string'
                    },
                    'Holdout': {
                        'NextActivity': 'string',
                        'Percentage': 123
                    },
                    'MultiCondition': {
                        'Branches': [
                            {
                                'Condition': {
                                    'EventCondition': {
                                        'Dimensions': {
                                            'Attributes': {
                                                'string': {
                                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                    'Values': [
                                                        'string',
                                                    ]
                                                }
                                            },
                                            'EventType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Metrics': {
                                                'string': {
                                                    'ComparisonOperator': 'string',
                                                    'Value': 123.0
                                                }
                                            }
                                        },
                                        'MessageActivity': 'string'
                                    },
                                    'SegmentCondition': {
                                        'SegmentId': 'string'
                                    },
                                    'SegmentDimensions': {
                                        'Attributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Behavior': {
                                            'Recency': {
                                                'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                                'RecencyType': 'ACTIVE'|'INACTIVE'
                                            }
                                        },
                                        'Demographic': {
                                            'AppVersion': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Channel': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'DeviceType': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Make': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Model': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'Platform': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        },
                                        'Location': {
                                            'Country': {
                                                'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            },
                                            'GPSPoint': {
                                                'Coordinates': {
                                                    'Latitude': 123.0,
                                                    'Longitude': 123.0
                                                },
                                                'RangeInKilometers': 123.0
                                            }
                                        },
                                        'Metrics': {
                                            'string': {
                                                'ComparisonOperator': 'string',
                                                'Value': 123.0
                                            }
                                        },
                                        'UserAttributes': {
                                            'string': {
                                                'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                                'Values': [
                                                    'string',
                                                ]
                                            }
                                        }
                                    }
                                },
                                'NextActivity': 'string'
                            },
                        ],
                        'DefaultActivity': 'string',
                        'EvaluationWaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    },
                    'RandomSplit': {
                        'Branches': [
                            {
                                'NextActivity': 'string',
                                'Percentage': 123
                            },
                        ]
                    },
                    'Wait': {
                        'NextActivity': 'string',
                        'WaitTime': {
                            'WaitFor': 'string',
                            'WaitUntil': 'string'
                        }
                    }
                }
            },
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Limits': {
                'DailyCap': 123,
                'EndpointReentryCap': 123,
                'MessagesPerSecond': 123
            },
            'LocalTime': True|False,
            'Name': 'string',
            'QuietTime': {
                'End': 'string',
                'Start': 'string'
            },
            'RefreshFrequency': 'string',
            'Schedule': {
                'EndTime': datetime(2015, 1, 1),
                'StartTime': datetime(2015, 1, 1),
                'Timezone': 'string'
            },
            'StartActivity': 'string',
            'StartCondition': {
                'Description': 'string',
                'SegmentStartCondition': {
                    'SegmentId': 'string'
                }
            },
            'State': 'DRAFT'|'ACTIVE'|'COMPLETED'|'CANCELLED'|'CLOSED',
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def update_push_template(CreateNewVersion=None, PushNotificationTemplateRequest=None, TemplateName=None, Version=None):
    """
    Updates an existing message template for messages that are sent through a push notification channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_push_template(
        CreateNewVersion=True|False,
        PushNotificationTemplateRequest={
            'ADM': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'APNS': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'MediaUrl': 'string',
                'RawContent': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'Baidu': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'Default': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'DefaultSubstitutions': 'string',
            'GCM': {
                'Action': 'OPEN_APP'|'DEEP_LINK'|'URL',
                'Body': 'string',
                'ImageIconUrl': 'string',
                'ImageUrl': 'string',
                'RawContent': 'string',
                'SmallImageIconUrl': 'string',
                'Sound': 'string',
                'Title': 'string',
                'Url': 'string'
            },
            'RecommenderId': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string'
        },
        TemplateName='string',
        Version='string'
    )
    
    
    :type CreateNewVersion: boolean
    :param CreateNewVersion: Specifies whether to save the updates as a new version of the message template. Valid values are: true, save the updates as a new version; and, false, save the updates to (overwrite) the latest existing version of the template.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint saves the updates to (overwrites) the latest existing version of the template. If you specify a value of true for this parameter, don\'t specify a value for the version parameter. Otherwise, an error will occur.\n

    :type PushNotificationTemplateRequest: dict
    :param PushNotificationTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in messages that are sent through a push notification channel.\n\nADM (dict) --The message template to use for the ADM (Amazon Device Messaging) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in a push notification that\'s based on the message template.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.\n\nImageUrl (string) --The URL of an image to display in a push notification that\'s based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nTitle (string) --The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nAPNS (dict) --The message template to use for the APNs (Apple Push Notification service) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in push notifications that are based on the message template.\n\nMediaUrl (string) --The URL of an image or video to display in push notifications that are based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for push notifications that are based on the message template. If specified, this value overrides all other content for the message template.\n\nSound (string) --The key for the sound to play when the recipient receives a push notification that\'s based on the message template. The value for this key is the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.\n\nTitle (string) --The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in the recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nBaidu (dict) --The message template to use for the Baidu (Baidu Cloud Push) channel. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in a push notification that\'s based on the message template.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.\n\nImageUrl (string) --The URL of an image to display in a push notification that\'s based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nTitle (string) --The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nDefault (dict) --The default message template to use for push notification channels.\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in push notifications that are based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\nFor an iOS platform, this value is the key for the name of a sound file in your app\'s main bundle or the Library/Sounds folder in your app\'s data container. If the sound file can\'t be found or you specify default for the value, the system plays the default alert sound.\n\nTitle (string) --The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nGCM (dict) --The message template to use for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message template overrides the default template for push notification channels (DefaultPushNotificationTemplate).\n\nAction (string) --The action to occur if a recipient taps a push notification that\'s based on the message template. Valid values are:\n\nOPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.\nDEEP_LINK - Your app opens and displays a designated user interface in the app. This action uses the deep-linking features of the Android platform.\nURL - The default mobile browser on the recipient\'s device opens and loads the web page at a URL that you specify.\n\n\nBody (string) --The message body to use in a push notification that\'s based on the message template.\n\nImageIconUrl (string) --The URL of the large icon image to display in the content view of a push notification that\'s based on the message template.\n\nImageUrl (string) --The URL of an image to display in a push notification that\'s based on the message template.\n\nRawContent (string) --The raw, JSON-formatted string to use as the payload for a push notification that\'s based on the message template. If specified, this value overrides all other content for the message template.\n\nSmallImageIconUrl (string) --The URL of the small icon image to display in the status bar and the content view of a push notification that\'s based on the message template.\n\nSound (string) --The sound to play when a recipient receives a push notification that\'s based on the message template. You can use the default stream or specify the file name of a sound resource that\'s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.\n\nTitle (string) --The title to use in a push notification that\'s based on the message template. This title appears above the notification message on a recipient\'s device.\n\nUrl (string) --The URL to open in a recipient\'s default mobile browser, if a recipient taps a push notification that\'s based on the message template and the value of the Action property is URL.\n\n\n\nRecommenderId (string) --The unique identifier for the recommender model to use for the message template. Amazon Pinpoint uses this value to determine how to retrieve and process data from a recommender model when it sends messages that use the template, if the template contains message variables for recommendation data.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_recommender_configuration(RecommenderId=None, UpdateRecommenderConfiguration=None):
    """
    Updates an Amazon Pinpoint configuration for a recommender model.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_recommender_configuration(
        RecommenderId='string',
        UpdateRecommenderConfiguration={
            'Attributes': {
                'string': 'string'
            },
            'Description': 'string',
            'Name': 'string',
            'RecommendationProviderIdType': 'string',
            'RecommendationProviderRoleArn': 'string',
            'RecommendationProviderUri': 'string',
            'RecommendationTransformerUri': 'string',
            'RecommendationsDisplayName': 'string',
            'RecommendationsPerMessage': 123
        }
    )
    
    
    :type RecommenderId: string
    :param RecommenderId: [REQUIRED]\nThe unique identifier for the recommender model configuration. This identifier is displayed as the Recommender ID on the Amazon Pinpoint console.\n

    :type UpdateRecommenderConfiguration: dict
    :param UpdateRecommenderConfiguration: [REQUIRED]\nSpecifies Amazon Pinpoint configuration settings for retrieving and processing recommendation data from a recommender model.\n\nAttributes (dict) --A map of key-value pairs that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.\nIn the map, the key is the name of a custom attribute and the value is a custom display name for that attribute. The display name appears in the Attribute finder of the template editor on the Amazon Pinpoint console. The following restrictions apply to these names:\n\nAn attribute name must start with a letter or number and it can contain up to 50 characters. The characters can be letters, numbers, underscores (_), or hyphens (-). Attribute names are case sensitive and must be unique.\nAn attribute display name must start with a letter or number and it can contain up to 25 characters. The characters can be letters, numbers, spaces, underscores (_), or hyphens (-).\n\nThis object is required if the configuration invokes an AWS Lambda function (RecommendationTransformerUri) to process recommendation data. Otherwise, don\'t include this object in your request.\n\n(string) --\n(string) --\n\n\n\n\nDescription (string) --A custom description of the configuration for the recommender model. The description can contain up to 128 characters. The characters can be letters, numbers, spaces, or the following symbols: _ ; () , \xe2\x80\x90.\n\nName (string) --A custom name of the configuration for the recommender model. The name must start with a letter or number and it can contain up to 128 characters. The characters can be letters, numbers, spaces, underscores (_), or hyphens (-).\n\nRecommendationProviderIdType (string) --The type of Amazon Pinpoint ID to associate with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Valid values are:\n\nPINPOINT_ENDPOINT_ID - Associate each user in the model with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.\nPINPOINT_USER_ID - Associate each user in the model with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If you specify this value, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.\n\n\nRecommendationProviderRoleArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.\n\nRecommendationProviderUri (string) -- [REQUIRED]The Amazon Resource Name (ARN) of the recommender model to retrieve recommendation data from. This value must match the ARN of an Amazon Personalize campaign.\n\nRecommendationTransformerUri (string) --The name or Amazon Resource Name (ARN) of the AWS Lambda function to invoke for additional processing of recommendation data that\'s retrieved from the recommender model.\n\nRecommendationsDisplayName (string) --A custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This value is required if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.\nThis name appears in the Attribute finder of the template editor on the Amazon Pinpoint console. The name can contain up to 25 characters. The characters can be letters, numbers, spaces, underscores (_), or hyphens (-). These restrictions don\'t apply to attribute values.\n\nRecommendationsPerMessage (integer) --The number of recommended items to retrieve from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables. The minimum value is 1. The maximum value is 5. The default value is 5.\nTo use multiple recommended items and custom attributes with message variables, you have to use an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'RecommenderConfigurationResponse': {
        'Attributes': {
            'string': 'string'
        },
        'CreationDate': 'string',
        'Description': 'string',
        'Id': 'string',
        'LastModifiedDate': 'string',
        'Name': 'string',
        'RecommendationProviderIdType': 'string',
        'RecommendationProviderRoleArn': 'string',
        'RecommendationProviderUri': 'string',
        'RecommendationTransformerUri': 'string',
        'RecommendationsDisplayName': 'string',
        'RecommendationsPerMessage': 123
    }
}


Response Structure

(dict) --
The request succeeded.

RecommenderConfigurationResponse (dict) --
Provides information about Amazon Pinpoint configuration settings for retrieving and processing data from a recommender model.

Attributes (dict) --
A map that defines 1-10 custom endpoint or user attributes, depending on the value for the RecommendationProviderIdType property. Each of these attributes temporarily stores a recommended item that\'s retrieved from the recommender model and sent to an AWS Lambda function for additional processing. Each attribute can be used as a message variable in a message template.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

(string) --
(string) --




CreationDate (string) --
The date, in extended ISO 8601 format, when the configuration was created for the recommender model.

Description (string) --
The custom description of the configuration for the recommender model.

Id (string) --
The unique identifier for the recommender model configuration.

LastModifiedDate (string) --
The date, in extended ISO 8601 format, when the configuration for the recommender model was last modified.

Name (string) --
The custom name of the configuration for the recommender model.

RecommendationProviderIdType (string) --
The type of Amazon Pinpoint ID that\'s associated with unique user IDs in the recommender model. This value enables the model to use attribute and event data that\xe2\x80\x99s specific to a particular endpoint or user in an Amazon Pinpoint application. Possible values are:

PINPOINT_ENDPOINT_ID - Each user in the model is associated with a particular endpoint in Amazon Pinpoint. The data is correlated based on endpoint IDs in Amazon Pinpoint. This is the default value.
PINPOINT_USER_ID - Each user in the model is associated with a particular user and endpoint in Amazon Pinpoint. The data is correlated based on user IDs in Amazon Pinpoint. If this value is specified, an endpoint definition in Amazon Pinpoint has to specify both a user ID (UserId) and an endpoint ID. Otherwise, messages won\xe2\x80\x99t be sent to the user\'s endpoint.


RecommendationProviderRoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to retrieve recommendation data from the recommender model.

RecommendationProviderUri (string) --
The Amazon Resource Name (ARN) of the recommender model that Amazon Pinpoint retrieves the recommendation data from. This value is the ARN of an Amazon Personalize campaign.

RecommendationTransformerUri (string) --
The name or Amazon Resource Name (ARN) of the AWS Lambda function that Amazon Pinpoint invokes to perform additional processing of recommendation data that it retrieves from the recommender model.

RecommendationsDisplayName (string) --
The custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This name appears in the Attribute finder of the template editor on the Amazon Pinpoint console.
This value is null if the configuration doesn\'t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.

RecommendationsPerMessage (integer) --
The number of recommended items that are retrieved from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'RecommenderConfigurationResponse': {
            'Attributes': {
                'string': 'string'
            },
            'CreationDate': 'string',
            'Description': 'string',
            'Id': 'string',
            'LastModifiedDate': 'string',
            'Name': 'string',
            'RecommendationProviderIdType': 'string',
            'RecommendationProviderRoleArn': 'string',
            'RecommendationProviderUri': 'string',
            'RecommendationTransformerUri': 'string',
            'RecommendationsDisplayName': 'string',
            'RecommendationsPerMessage': 123
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def update_segment(ApplicationId=None, SegmentId=None, WriteSegmentRequest=None):
    """
    Creates a new segment for an application or updates the configuration, dimension, and other settings for an existing segment that\'s associated with an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_segment(
        ApplicationId='string',
        SegmentId='string',
        WriteSegmentRequest={
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'tags': {
                'string': 'string'
            }
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type SegmentId: string
    :param SegmentId: [REQUIRED]\nThe unique identifier for the segment.\n

    :type WriteSegmentRequest: dict
    :param WriteSegmentRequest: [REQUIRED]\nSpecifies the configuration, dimension, and other settings for a segment. A WriteSegmentRequest object can include a Dimensions object or a SegmentGroups object, but not both.\n\nDimensions (dict) --The criteria that define the dimensions for the segment.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\nName (string) --The name of the segment.\n\nSegmentGroups (dict) --The segment group to use and the dimensions to apply to the group\'s base segments in order to build the segment. A segment group can consist of zero or more base segments. Your request can include only one segment group.\n\nGroups (list) --An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.\n\n(dict) --Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.\n\nDimensions (list) --An array that defines the dimensions for the segment.\n\n(dict) --Specifies the dimension settings for a segment.\n\nAttributes (dict) --One or more custom attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\nBehavior (dict) --The behavior-based criteria, such as how recently users have used your app, for the segment.\n\nRecency (dict) --The dimension settings that are based on how recently an endpoint was active.\n\nDuration (string) -- [REQUIRED]The duration to use when determining whether an endpoint is active or inactive.\n\nRecencyType (string) -- [REQUIRED]The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.\n\n\n\n\n\nDemographic (dict) --The demographic-based criteria, such as device platform, for the segment.\n\nAppVersion (dict) --The app version criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nChannel (dict) --The channel criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nDeviceType (dict) --The device type criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nMake (dict) --The device make criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nModel (dict) --The device model criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nPlatform (dict) --The device platform criteria for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\n\n\nLocation (dict) --The location-based criteria, such as region or GPS coordinates, for the segment.\n\nCountry (dict) --The country or region code, in ISO 3166-1 alpha-2 format, for the segment.\n\nDimensionType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.\n\n(string) --\n\n\n\n\nGPSPoint (dict) --The GPS location and range for the segment.\n\nCoordinates (dict) -- [REQUIRED]The GPS coordinates to measure distance from.\n\nLatitude (float) -- [REQUIRED]The latitude coordinate of the location.\n\nLongitude (float) -- [REQUIRED]The longitude coordinate of the location.\n\n\n\nRangeInKilometers (float) --The range, in kilometers, from the GPS coordinates.\n\n\n\n\n\nMetrics (dict) --One or more custom metrics to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.\n\nComparisonOperator (string) -- [REQUIRED]The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.\n\nValue (float) -- [REQUIRED]The value to compare.\n\n\n\n\n\n\n\nUserAttributes (dict) --One or more custom user attributes to use as criteria for the segment.\n\n(string) --\n(dict) --Specifies attribute-based criteria for including or excluding endpoints from a segment.\n\nAttributeType (string) --The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.\n\nValues (list) -- [REQUIRED]The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.\n\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n\nSourceSegments (list) --The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.\nYou can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.\n\n(dict) --Specifies the segment identifier and version of a segment.\n\nId (string) -- [REQUIRED]The unique identifier for the segment.\n\nVersion (integer) --The version number of the segment.\n\n\n\n\n\nSourceType (string) --Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.\n\nType (string) --Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.\n\n\n\n\n\nInclude (string) --Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.\n\n\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the segment. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SegmentResponse': {
        'ApplicationId': 'string',
        'Arn': 'string',
        'CreationDate': 'string',
        'Dimensions': {
            'Attributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Behavior': {
                'Recency': {
                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                    'RecencyType': 'ACTIVE'|'INACTIVE'
                }
            },
            'Demographic': {
                'AppVersion': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Channel': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'DeviceType': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Make': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Model': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'Platform': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            },
            'Location': {
                'Country': {
                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                },
                'GPSPoint': {
                    'Coordinates': {
                        'Latitude': 123.0,
                        'Longitude': 123.0
                    },
                    'RangeInKilometers': 123.0
                }
            },
            'Metrics': {
                'string': {
                    'ComparisonOperator': 'string',
                    'Value': 123.0
                }
            },
            'UserAttributes': {
                'string': {
                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                    'Values': [
                        'string',
                    ]
                }
            }
        },
        'Id': 'string',
        'ImportDefinition': {
            'ChannelCounts': {
                'string': 123
            },
            'ExternalId': 'string',
            'Format': 'CSV'|'JSON',
            'RoleArn': 'string',
            'S3Url': 'string',
            'Size': 123
        },
        'LastModifiedDate': 'string',
        'Name': 'string',
        'SegmentGroups': {
            'Groups': [
                {
                    'Dimensions': [
                        {
                            'Attributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Behavior': {
                                'Recency': {
                                    'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                    'RecencyType': 'ACTIVE'|'INACTIVE'
                                }
                            },
                            'Demographic': {
                                'AppVersion': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Channel': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'DeviceType': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Make': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Model': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'Platform': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            },
                            'Location': {
                                'Country': {
                                    'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                },
                                'GPSPoint': {
                                    'Coordinates': {
                                        'Latitude': 123.0,
                                        'Longitude': 123.0
                                    },
                                    'RangeInKilometers': 123.0
                                }
                            },
                            'Metrics': {
                                'string': {
                                    'ComparisonOperator': 'string',
                                    'Value': 123.0
                                }
                            },
                            'UserAttributes': {
                                'string': {
                                    'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                    'Values': [
                                        'string',
                                    ]
                                }
                            }
                        },
                    ],
                    'SourceSegments': [
                        {
                            'Id': 'string',
                            'Version': 123
                        },
                    ],
                    'SourceType': 'ALL'|'ANY'|'NONE',
                    'Type': 'ALL'|'ANY'|'NONE'
                },
            ],
            'Include': 'ALL'|'ANY'|'NONE'
        },
        'SegmentType': 'DIMENSIONAL'|'IMPORT',
        'tags': {
            'string': 'string'
        },
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

SegmentResponse (dict) --
Provides information about the configuration, dimension, and other settings for a segment.

ApplicationId (string) --
The unique identifier for the application that the segment is associated with.

Arn (string) --
The Amazon Resource Name (ARN) of the segment.

CreationDate (string) --
The date and time when the segment was created.

Dimensions (dict) --
The dimension settings for the segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --










Id (string) --
The unique identifier for the segment.

ImportDefinition (dict) --
The settings for the import job that\'s associated with the segment.

ChannelCounts (dict) --
The number of channel types in the endpoint definitions that were imported to create the segment.

(string) --
(integer) --




ExternalId (string) --
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don\'t recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.

Format (string) --
The format of the files that were imported to create the segment. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format.

RoleArn (string) --
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorized Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.

S3Url (string) --
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that the endpoint definitions were imported from to create the segment.

Size (integer) --
The number of endpoint definitions that were imported successfully to create the segment.



LastModifiedDate (string) --
The date and time when the segment was last modified.

Name (string) --
The name of the segment.

SegmentGroups (dict) --
A list of one or more segment groups that apply to the segment. Each segment group consists of zero or more base segments and the dimensions that are applied to those base segments.

Groups (list) --
An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.

(dict) --
Specifies the base segments and dimensions for a segment, and the relationships between these base segments and dimensions.

Dimensions (list) --
An array that defines the dimensions for the segment.

(dict) --
Specifies the dimension settings for a segment.

Attributes (dict) --
One or more custom attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --








Behavior (dict) --
The behavior-based criteria, such as how recently users have used your app, for the segment.

Recency (dict) --
The dimension settings that are based on how recently an endpoint was active.

Duration (string) --
The duration to use when determining whether an endpoint is active or inactive.

RecencyType (string) --
The type of recency dimension to use for the segment. Valid values are: ACTIVE, endpoints that were active within the specified duration are included in the segment; and, INACTIVE, endpoints that weren\'t active within the specified duration are included in the segment.





Demographic (dict) --
The demographic-based criteria, such as device platform, for the segment.

AppVersion (dict) --
The app version criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Channel (dict) --
The channel criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




DeviceType (dict) --
The device type criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Make (dict) --
The device make criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Model (dict) --
The device model criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




Platform (dict) --
The device platform criteria for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --






Location (dict) --
The location-based criteria, such as region or GPS coordinates, for the segment.

Country (dict) --
The country or region code, in ISO 3166-1 alpha-2 format, for the segment.

DimensionType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.

(string) --




GPSPoint (dict) --
The GPS location and range for the segment.

Coordinates (dict) --
The GPS coordinates to measure distance from.

Latitude (float) --
The latitude coordinate of the location.

Longitude (float) --
The longitude coordinate of the location.



RangeInKilometers (float) --
The range, in kilometers, from the GPS coordinates.





Metrics (dict) --
One or more custom metrics to use as criteria for the segment.

(string) --

(dict) --
Specifies metric-based criteria for including or excluding endpoints from a segment. These criteria derive from custom metrics that you define for endpoints.

ComparisonOperator (string) --
The operator to use when comparing metric values. Valid values are: GREATER_THAN, LESS_THAN, GREATER_THAN_OR_EQUAL, LESS_THAN_OR_EQUAL, and EQUAL.

Value (float) --
The value to compare.







UserAttributes (dict) --
One or more custom user attributes to use as criteria for the segment.

(string) --

(dict) --
Specifies attribute-based criteria for including or excluding endpoints from a segment.

AttributeType (string) --
The type of segment dimension to use. Valid values are: INCLUSIVE, endpoints that match the criteria are included in the segment; and, EXCLUSIVE, endpoints that match the criteria are excluded from the segment.

Values (list) --
The criteria values to use for the segment dimension. Depending on the value of the AttributeType property, endpoints are included or excluded from the segment if their attribute values match the criteria values.

(string) --












SourceSegments (list) --
The base segment to build the segment on. A base segment, also referred to as a source segment , defines the initial population of endpoints for a segment. When you add dimensions to a segment, Amazon Pinpoint filters the base segment by using the dimensions that you specify.
You can specify more than one dimensional segment or only one imported segment. If you specify an imported segment, the Amazon Pinpoint console displays a segment size estimate that indicates the size of the imported segment without any filters applied to it.

(dict) --
Specifies the segment identifier and version of a segment.

Id (string) --
The unique identifier for the segment.

Version (integer) --
The version number of the segment.





SourceType (string) --
Specifies how to handle multiple base segments for the segment. For example, if you specify three base segments for the segment, whether the resulting segment is based on all, any, or none of the base segments.

Type (string) --
Specifies how to handle multiple dimensions for the segment. For example, if you specify three dimensions for the segment, whether the resulting segment includes endpoints that match all, any, or none of the dimensions.





Include (string) --
Specifies how to handle multiple segment groups for the segment. For example, if the segment includes three segment groups, whether the resulting segment includes endpoints that match all, any, or none of the segment groups.



SegmentType (string) --
The segment type. Valid values are:

DIMENSIONAL - A dynamic segment, which is a segment that uses selection criteria that you specify and is based on endpoint data that\'s reported by your app. Dynamic segments can change over time.
IMPORT - A static segment, which is a segment that uses selection criteria that you specify and is based on endpoint definitions that you import from a file. Imported segments are static; they don\'t change over time.


tags (dict) --
A string-to-string map of key-value pairs that identifies the tags that are associated with the segment. Each tag consists of a required tag key and an associated tag value.

(string) --
(string) --




Version (integer) --
The version number of the segment.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SegmentResponse': {
            'ApplicationId': 'string',
            'Arn': 'string',
            'CreationDate': 'string',
            'Dimensions': {
                'Attributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Behavior': {
                    'Recency': {
                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                        'RecencyType': 'ACTIVE'|'INACTIVE'
                    }
                },
                'Demographic': {
                    'AppVersion': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Channel': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'DeviceType': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Make': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Model': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'Platform': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                },
                'Location': {
                    'Country': {
                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    },
                    'GPSPoint': {
                        'Coordinates': {
                            'Latitude': 123.0,
                            'Longitude': 123.0
                        },
                        'RangeInKilometers': 123.0
                    }
                },
                'Metrics': {
                    'string': {
                        'ComparisonOperator': 'string',
                        'Value': 123.0
                    }
                },
                'UserAttributes': {
                    'string': {
                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                        'Values': [
                            'string',
                        ]
                    }
                }
            },
            'Id': 'string',
            'ImportDefinition': {
                'ChannelCounts': {
                    'string': 123
                },
                'ExternalId': 'string',
                'Format': 'CSV'|'JSON',
                'RoleArn': 'string',
                'S3Url': 'string',
                'Size': 123
            },
            'LastModifiedDate': 'string',
            'Name': 'string',
            'SegmentGroups': {
                'Groups': [
                    {
                        'Dimensions': [
                            {
                                'Attributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Behavior': {
                                    'Recency': {
                                        'Duration': 'HR_24'|'DAY_7'|'DAY_14'|'DAY_30',
                                        'RecencyType': 'ACTIVE'|'INACTIVE'
                                    }
                                },
                                'Demographic': {
                                    'AppVersion': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Channel': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'DeviceType': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Make': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Model': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'Platform': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                },
                                'Location': {
                                    'Country': {
                                        'DimensionType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    },
                                    'GPSPoint': {
                                        'Coordinates': {
                                            'Latitude': 123.0,
                                            'Longitude': 123.0
                                        },
                                        'RangeInKilometers': 123.0
                                    }
                                },
                                'Metrics': {
                                    'string': {
                                        'ComparisonOperator': 'string',
                                        'Value': 123.0
                                    }
                                },
                                'UserAttributes': {
                                    'string': {
                                        'AttributeType': 'INCLUSIVE'|'EXCLUSIVE',
                                        'Values': [
                                            'string',
                                        ]
                                    }
                                }
                            },
                        ],
                        'SourceSegments': [
                            {
                                'Id': 'string',
                                'Version': 123
                            },
                        ],
                        'SourceType': 'ALL'|'ANY'|'NONE',
                        'Type': 'ALL'|'ANY'|'NONE'
                    },
                ],
                'Include': 'ALL'|'ANY'|'NONE'
            },
            'SegmentType': 'DIMENSIONAL'|'IMPORT',
            'tags': {
                'string': 'string'
            },
            'Version': 123
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def update_sms_channel(ApplicationId=None, SMSChannelRequest=None):
    """
    Enables the SMS channel for an application or updates the status and settings of the SMS channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_sms_channel(
        ApplicationId='string',
        SMSChannelRequest={
            'Enabled': True|False,
            'SenderId': 'string',
            'ShortCode': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type SMSChannelRequest: dict
    :param SMSChannelRequest: [REQUIRED]\nSpecifies the status and settings of the SMS channel for an application.\n\nEnabled (boolean) --Specifies whether to enable the SMS channel for the application.\n\nSenderId (string) --The identity that you want to display on recipients\' devices when they receive messages from the SMS channel.\n\nShortCode (string) --The registered short code that you want to use when you send messages through the SMS channel.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'SMSChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'PromotionalMessagesPerSecond': 123,
        'SenderId': 'string',
        'ShortCode': 'string',
        'TransactionalMessagesPerSecond': 123,
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

SMSChannelResponse (dict) --
Provides information about the status and settings of the SMS channel for an application.

ApplicationId (string) --
The unique identifier for the application that the SMS channel applies to.

CreationDate (string) --
The date and time, in ISO 8601 format, when the SMS channel was enabled.

Enabled (boolean) --
Specifies whether the SMS channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

Id (string) --
(Deprecated) An identifier for the SMS channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the SMS channel is archived.

LastModifiedBy (string) --
The user who last modified the SMS channel.

LastModifiedDate (string) --
The date and time, in ISO 8601 format, when the SMS channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the SMS channel, this value is SMS.

PromotionalMessagesPerSecond (integer) --
The maximum number of promotional messages that you can send through the SMS channel each second.

SenderId (string) --
The identity that displays on recipients\' devices when they receive messages from the SMS channel.

ShortCode (string) --
The registered short code to use when you send messages through the SMS channel.

TransactionalMessagesPerSecond (integer) --
The maximum number of transactional messages that you can send through the SMS channel each second.

Version (integer) --
The current version of the SMS channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'SMSChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'PromotionalMessagesPerSecond': 123,
            'SenderId': 'string',
            'ShortCode': 'string',
            'TransactionalMessagesPerSecond': 123,
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_sms_template(CreateNewVersion=None, SMSTemplateRequest=None, TemplateName=None, Version=None):
    """
    Updates an existing message template for messages that are sent through the SMS channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_sms_template(
        CreateNewVersion=True|False,
        SMSTemplateRequest={
            'Body': 'string',
            'DefaultSubstitutions': 'string',
            'RecommenderId': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string'
        },
        TemplateName='string',
        Version='string'
    )
    
    
    :type CreateNewVersion: boolean
    :param CreateNewVersion: Specifies whether to save the updates as a new version of the message template. Valid values are: true, save the updates as a new version; and, false, save the updates to (overwrite) the latest existing version of the template.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint saves the updates to (overwrites) the latest existing version of the template. If you specify a value of true for this parameter, don\'t specify a value for the version parameter. Otherwise, an error will occur.\n

    :type SMSTemplateRequest: dict
    :param SMSTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in text messages that are sent through the SMS channel.\n\nBody (string) --The message body to use in text messages that are based on the message template.\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nRecommenderId (string) --The unique identifier for the recommender model to use for the message template. Amazon Pinpoint uses this value to determine how to retrieve and process data from a recommender model when it sends messages that use the template, if the template contains message variables for recommendation data.\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_template_active_version(TemplateActiveVersionRequest=None, TemplateName=None, TemplateType=None):
    """
    Changes the status of a specific version of a message template to active .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_template_active_version(
        TemplateActiveVersionRequest={
            'Version': 'string'
        },
        TemplateName='string',
        TemplateType='string'
    )
    
    
    :type TemplateActiveVersionRequest: dict
    :param TemplateActiveVersionRequest: [REQUIRED]\nSpecifies which version of a message template to use as the active version of the template.\n\nVersion (string) --The version of the message template to use as the active version of the template. Valid values are: latest, for the most recent version of the template; or, the unique identifier for any existing version of the template. If you specify an identifier, the value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versionsresource.\n\n\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type TemplateType: string
    :param TemplateType: [REQUIRED]\nThe type of channel that the message template is designed for. Valid values are: EMAIL, PUSH, SMS, and VOICE.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request succeeded.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_voice_channel(ApplicationId=None, VoiceChannelRequest=None):
    """
    Enables the voice channel for an application or updates the status and settings of the voice channel for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_voice_channel(
        ApplicationId='string',
        VoiceChannelRequest={
            'Enabled': True|False
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.\n

    :type VoiceChannelRequest: dict
    :param VoiceChannelRequest: [REQUIRED]\nSpecifies the status and settings of the voice channel for an application.\n\nEnabled (boolean) --Specifies whether to enable the voice channel for the application.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'VoiceChannelResponse': {
        'ApplicationId': 'string',
        'CreationDate': 'string',
        'Enabled': True|False,
        'HasCredential': True|False,
        'Id': 'string',
        'IsArchived': True|False,
        'LastModifiedBy': 'string',
        'LastModifiedDate': 'string',
        'Platform': 'string',
        'Version': 123
    }
}


Response Structure

(dict) --
The request succeeded.

VoiceChannelResponse (dict) --
Provides information about the status and settings of the voice channel for an application.

ApplicationId (string) --
The unique identifier for the application that the voice channel applies to.

CreationDate (string) --
The date and time, in ISO 8601 format, when the voice channel was enabled.

Enabled (boolean) --
Specifies whether the voice channel is enabled for the application.

HasCredential (boolean) --
(Not used) This property is retained only for backward compatibility.

Id (string) --
(Deprecated) An identifier for the voice channel. This property is retained only for backward compatibility.

IsArchived (boolean) --
Specifies whether the voice channel is archived.

LastModifiedBy (string) --
The user who last modified the voice channel.

LastModifiedDate (string) --
The date and time, in ISO 8601 format, when the voice channel was last modified.

Platform (string) --
The type of messaging or notification platform for the channel. For the voice channel, this value is VOICE.

Version (integer) --
The current version of the voice channel.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'VoiceChannelResponse': {
            'ApplicationId': 'string',
            'CreationDate': 'string',
            'Enabled': True|False,
            'HasCredential': True|False,
            'Id': 'string',
            'IsArchived': True|False,
            'LastModifiedBy': 'string',
            'LastModifiedDate': 'string',
            'Platform': 'string',
            'Version': 123
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

def update_voice_template(CreateNewVersion=None, TemplateName=None, Version=None, VoiceTemplateRequest=None):
    """
    Updates an existing message template for messages that are sent through the voice channel.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_voice_template(
        CreateNewVersion=True|False,
        TemplateName='string',
        Version='string',
        VoiceTemplateRequest={
            'Body': 'string',
            'DefaultSubstitutions': 'string',
            'LanguageCode': 'string',
            'tags': {
                'string': 'string'
            },
            'TemplateDescription': 'string',
            'VoiceId': 'string'
        }
    )
    
    
    :type CreateNewVersion: boolean
    :param CreateNewVersion: Specifies whether to save the updates as a new version of the message template. Valid values are: true, save the updates as a new version; and, false, save the updates to (overwrite) the latest existing version of the template.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint saves the updates to (overwrites) the latest existing version of the template. If you specify a value of true for this parameter, don\'t specify a value for the version parameter. Otherwise, an error will occur.\n

    :type TemplateName: string
    :param TemplateName: [REQUIRED]\nThe name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.\n

    :type Version: string
    :param Version: The unique identifier for the version of the message template to update, retrieve information about, or delete. To retrieve identifiers and other information for all the versions of a template, use the Template Versionsresource.\nIf specified, this value must match the identifier for an existing template version. If specified for an update operation, this value must match the identifier for the latest existing version of the template. This restriction helps ensure that race conditions don\'t occur.\nIf you don\'t specify a value for this parameter, Amazon Pinpoint does the following:\n\nFor a get operation, retrieves information about the active version of the template.\nFor an update operation, saves the updates to (overwrites) the latest existing version of the template, if the create-new-version parameter isn\'t used or is set to false.\nFor a delete operation, deletes the template, including all versions of the template.\n\n

    :type VoiceTemplateRequest: dict
    :param VoiceTemplateRequest: [REQUIRED]\nSpecifies the content and settings for a message template that can be used in messages that are sent through the voice channel.\n\nBody (string) --The text of the script to use in messages that are based on the message template, in plain text format.\n\nDefaultSubstitutions (string) --A JSON object that specifies the default values to use for message variables in the message template. This object is a set of key-value pairs. Each key defines a message variable in the template. The corresponding value defines the default value for that variable. When you create a message that\'s based on the template, you can override these defaults with message-specific and address-specific variables and values.\n\nLanguageCode (string) --The code for the language to use when synthesizing the text of the script in messages that are based on the message template. For a list of supported languages and the code for each one, see the Amazon Polly Developer Guide .\n\ntags (dict) --A string-to-string map of key-value pairs that defines the tags to associate with the message template. Each tag consists of a required tag key and an associated tag value.\n\n(string) --\n(string) --\n\n\n\n\nTemplateDescription (string) --A custom description of the message template.\n\nVoiceId (string) --The name of the voice to use when delivering messages that are based on the message template. For a list of supported voices, see the Amazon Polly Developer Guide .\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MessageBody': {
        'Message': 'string',
        'RequestID': 'string'
    }
}


Response Structure

(dict) --
The request was accepted for processing. Processing may not be complete.

MessageBody (dict) --
Provides information about an API request or response.

Message (string) --
The message that\'s returned from the API.

RequestID (string) --
The unique identifier for the request or response.









Exceptions

Pinpoint.Client.exceptions.BadRequestException
Pinpoint.Client.exceptions.InternalServerErrorException
Pinpoint.Client.exceptions.PayloadTooLargeException
Pinpoint.Client.exceptions.ForbiddenException
Pinpoint.Client.exceptions.NotFoundException
Pinpoint.Client.exceptions.MethodNotAllowedException
Pinpoint.Client.exceptions.TooManyRequestsException


    :return: {
        'MessageBody': {
            'Message': 'string',
            'RequestID': 'string'
        }
    }
    
    
    :returns: 
    Pinpoint.Client.exceptions.BadRequestException
    Pinpoint.Client.exceptions.InternalServerErrorException
    Pinpoint.Client.exceptions.PayloadTooLargeException
    Pinpoint.Client.exceptions.ForbiddenException
    Pinpoint.Client.exceptions.NotFoundException
    Pinpoint.Client.exceptions.MethodNotAllowedException
    Pinpoint.Client.exceptions.TooManyRequestsException
    
    """
    pass

